/*global device:false */

'use strict';

angular.module('cocaColaCordovaApp', [
  'vcRecaptcha',
  'ionic',
  'LocalStorageModule',
  'ngResource',
  'uiGmapgoogle-maps',
  'ngCordova',
  'pascalprecht.translate',
  'uiGmapgoogle-maps',
  'ion-autocomplete',
  'angularMoment'
]);

angular.module('cocaColaCordovaApp')
  .config(function ($stateProvider, $urlRouterProvider, localStorageServiceProvider, $httpProvider, $logProvider,
                    $translateProvider, $translatePartialLoaderProvider, $ionicConfigProvider, MERCHANT_CONFIG) {
    $urlRouterProvider.otherwise('/loading');

    $stateProvider
      .state('loading', {
        url: '/loading?merchant_id=',
        templateUrl: 'scripts/core/loading/loading.html',
        controller: 'LoadingController'
      })
      .state('login', {
        url: '/login',
        templateUrl: 'scripts/core/login/login.html',
        controller: 'LoginController'
      })
      .state('login_social', {
        url: '/login_social',
        templateUrl: 'scripts/core/login_social/login-social.html',
        controller: 'LoginSocialController'
      })
      .state('logout', {
        url: '/logout',
        templateUrl: 'scripts/core/logout/logout.html',
        controller: 'LogoutController'
      })
      .state('confirm', {
        url: '/confirm',
        templateUrl: 'scripts/core/confirm/confirm.html',
        controller: 'ConfirmController'
      })
      .state('remind', {
        url: '/remind',
        templateUrl: 'scripts/core/password_remind/password-remind.html',
        controller: 'PasswordRemindController'
      })
      .state('categories', {
        url: '/categories?rebuild=',
        templateUrl: 'scripts/core/categories/categories.html',
        controller: 'CategoriesController'
      })
      .state('cart', {
        url: '/cart',
        templateUrl: 'scripts/core/cart/cart.html',
        controller: 'CartController'
      })
      .state('select_distributor', {
        url: '/select_distributor',
        templateUrl: 'scripts/core/select_distributor/select-distributor.html',
        controller: 'SelectDistributorController'
      })
      .state('select_distributor_map', {
        url: '/select_distributor_map',
        templateUrl: 'scripts/core/select_distributor_map/select-distributor-map.html',
        controller: 'SelectDistributorMapController'
      })
      .state('category', {
        url: '/category/:category_id',
        templateUrl: 'scripts/core/category/category.html',
        controller: 'CategoryController'
      })
      .state('product', {
        url: '/product/:product_id',
        templateUrl: 'scripts/core/product/product.html',
        controller: 'ProductController'
      })
      .state('order_completed', {
        url: '/order_completed/:order_id',
        templateUrl: 'scripts/core/order_completed/order-completed.html',
        controller: 'OrderCompletedController'
      })
      .state('register', {
        url: '/register/:edit',
        templateUrl: 'scripts/core/register/register.html',
        controller: 'RegisterController'
      })
      .state('rating', {
        url: '/rating',
        templateUrl: 'scripts/core/rating/rating.html',
        controller: 'RatingController'
      })
      .state('history', {
        url: '/history',
        templateUrl: 'scripts/core/history/history.html',
        controller: 'HistoryController'
      })
      .state('order_details', {
        url: '/order_details/:order_id',
        templateUrl: 'scripts/core/history/order-details.html',
        controller: 'OrderDetailsController'
      }).state('credit_card', {
        url: '/credit_card',
        templateUrl: 'scripts/core/credit_card/credit-card.html',
        controller: 'CreditCardController'
      }).state('ui_configuration', {
        url: '/ui_configuration',
        templateUrl: 'scripts/core/ui_configuration/ui-configuration.html',
        controller: 'UiConfigurationController'
      }).state('no_service', {
        url: '/no_service',
        templateUrl: 'scripts/core/no_service/no-service.html',
        controller: 'NoServiceController'
      }).state('ongoing_orders', {
        url: '/ongoing_orders',
        templateUrl: 'scripts/core/ongoing_orders/ongoing-orders.html',
        controller: 'OngoingOrdersController'
      }).state('maintenance_ticket', {
        url: '/maintenance_ticket',
        templateUrl: 'scripts/core/maintenance_ticket/maintenance-ticket.html',
        controller: 'MaintenanceTicketController'
      });

    localStorageServiceProvider.setPrefix(MERCHANT_CONFIG.LOCAL_STORAGE_PREFIX);

    $httpProvider.interceptors.push('SecurityInterceptor');
    $httpProvider.interceptors.push('NoConnectionInterceptor');

    $translateProvider.useLoader('$translatePartialLoader', {urlTemplate: 'i18n/{lang}.json'})
      .preferredLanguage('en')
      .fallbackLanguage('en');

    $translateProvider.useSanitizeValueStrategy('escape');
    $translatePartialLoaderProvider.addPart('main');

    $ionicConfigProvider.views.swipeBackEnabled(false);

  }).run(function ($log, CountryCodeExtractor, localStorageService, PushService, DBService,
                   $location, $rootScope, APP_DEFAULTS, DynamicHostService, $ionicHistory, $ionicPlatform,
                   NavigationHelper, AuthenticationService, PushHandlerService, NetworkHelper, $translate, $http) {

    $rootScope.appName = APP_DEFAULTS.DEFAULT_APP_NAME;

    var last_env = localStorageService.get('last_env');
    $rootScope.isProduction = _.isNull(last_env) || _.isUndefined(last_env) || 'production' ===  last_env;
    $rootScope.isDebug = false;
    $rootScope.isGlobalDemo = false;
    $rootScope.isLocalDemo = false;

    DynamicHostService.init();

    //save the current path and then
    $rootScope.savedPath = $location.path();
    $location.path('/loading');

    $ionicPlatform.registerBackButtonAction(function (event) {
      event.preventDefault();
      NavigationHelper.handleBackPress($ionicHistory.viewHistory());
    }, 100);

    // wait for device ready event
    document.addEventListener('deviceready', function () {
      $log.debug('device ready');

      try{
        $rootScope.platform = device.platform;
      } catch(error){
        $log.error(error);
      }

      $ionicPlatform.ready(function () {
        ionic.Platform.fullScreen();
      });

      document.addEventListener('pause', function () {
        $log.debug('application onPause');
        $rootScope.inForeground = false;
      }, false);

      document.addEventListener('resume', function () {
        $log.debug('application onResume');
        $rootScope.inForeground = true;
      }, false);

      // ============================================
      // network availability
      // ============================================

      NetworkHelper.init();

      //==================================================================
      // Read incoming SMS messages
      //==================================================================
      var smsInboxPlugin = cordova.require('cordova/plugin/smsinboxplugin');
      smsInboxPlugin.isSupported(function(supported) {
        ga_storage._trackEvent('smsInboxPlugin', 'isSupported', supported ? 'true' : 'false');
        if (supported){
          $log.debug('SMS supported');
        } else {
          $log.debug('SMS NOT supported');
        }
        $rootScope.smsSupported = supported;
      }, function() {
        ga_storage._trackEvent('smsInboxPlugin', 'isSupported', 'false');
        $rootScope.smsSupported = false;
      });
      //==================================================================
      //  country code info
      //==================================================================
      window.plugins.carrier.getCarrierInfo(function (data) {
        if (data) {
          if (data.countryCode && data.countryCode.length) {
            if (data.countryCodeOrigin) {
              $log.debug('obtained country code from ' + data.countryCodeOrigin);
            } else {
              $log.debug('unknown country code origin');
            }
            CountryCodeExtractor.setCountryCode(data.countryCode);
          } else {
            $log.error('failed to obtain country code');
            navigator.geolocation.getCurrentPosition(function (position) {
              geocodeCountryCode(position);
            }, function (error) {
              $log.error(error.message);
            });
          }
        } else {
          $log.error('failed to obtain carrier data');
          navigator.geolocation.getCurrentPosition(function (position) {
            geocodeCountryCode(position);
          }, function (error) {
            $log.error(error.message);
          });
        }
      }, false);

      function geocodeCountryCode(position) {
        if (position) {
          var lat = position.coords.latitude;
          var lng = position.coords.longitude;
          if (lat && lng) {
            $log.debug('obtaining country code for ' + lat + ', ' + lng);
            window.plugins.carrier.geocodeCountryCode([lat, lng], function (data) {
              if (data) {
                $log.debug(JSON.stringify(data));
                if (data.countryCode && data.countryCode.length) {
                  if (data.countryCodeOrigin) {
                    $log.debug('obtained country code from ' + data.countryCodeOrigin);
                  } else {
                    $log.debug('unknown country code origin');
                  }
                  CountryCodeExtractor.setCountryCode(data.countryCode);
                } else {
                  $log.error('failed to obtain country code from geocode');
                }
              } else {
                $log.error('failed to geocode location');
              }
            }, false);
          } else {
            $log.error('no lat-lng for geocode country');
          }
        } else {
          $log.error('no position for geocoding country code');
        }
      }

      //==================================================================
      //  device language
      //==================================================================

      navigator.globalization.getPreferredLanguage(
        function (language) {
          var lang = language.value.substring(0, 2);
          $log.debug('Device lang found:' + lang);
          $translate.use(lang);
        },
        function () {
          $log.error('Could not get the device language');
        }
      );

      //==================================================================
      //  app version info
      //==================================================================

      cordova.getAppVersion.getVersionNumber().then(function (version) {
        $log.debug('app version ' + version);
        $rootScope.appVersion = version;
        $http.defaults.headers.common['Client-Version'] = version;
        ga_storage._setCustomVar(1, 'appVersion', version);

        // we pass the version as a good practice so we can later register only when version changes
        // (currently unavailable by the plugin)
        initPush(version);
      });

      cordova.getAppVersion.getAppName().then(function (appName) {
        $log.debug('app name ' + appName);
        $rootScope.appName = appName;
      });

      $ionicPlatform.ready(function () {
        ionic.Platform.fullScreen();
      });

      //==================================================================
      //  db initialization
      //==================================================================

      DBService.init();


    }, false);


    //==================================================================
    //  PUSH NOTIFICATIONS
    //==================================================================

    function initPush() {
      var push = PushNotification.init({
        'android': {'senderID': APP_DEFAULTS.NOTIFICATIONS_ANDROID_SENDER_ID},
        'ios': {'alert': 'true', 'badge': 'true', 'sound': 'true'}, 'windows': {}
      });

      if (!_.isUndefined(push)) {
        setPushHandler(push);
      } else {
        $log.error('failed to initialize push');
      }
    }

    function setPushHandler(push) {
      push.on('registration', function (data) {
        var regId = data.registrationId;
        if (regId && regId.length > 0) {
          $log.debug('registration ID = ' + regId);

          // set push id only if user is logged in already.
          if (AuthenticationService.isLoggedIn) {
            var oldPushId = PushService.getPushId($rootScope.appVersion);
            // update server only we we have a new push token
            if (!oldPushId || oldPushId !== regId) {
              PushService.setPushId(regId, $rootScope.appVersion);
            } else {
              $log.debug('push token already exists');
            }
          } else {
            PushService.storePushIdLocally(regId, $rootScope.appVersion);
          }
        }
      });

      push.on('notification', function (data) {
        if (!AuthenticationService.isLoggedIn) {
          $log.info('not logged in - ignoring push');
          return;
        }
        PushHandlerService.handlePush(data);
      });

      push.on('error', function (e) {
        $log.error('GCM error = ' + e.message);
      });
    }

  });



'use strict';
/* jshint ignore:start */
angular.module('cocaColaCordovaApp')
  .constant('REALTIME_END_POINT', 'https://realtime2-api.bringg.com')
  .constant('REALTIME_STAGING_END_POINT', 'https://staging-realtime.bringg.com')
  .constant('ENV', 'production')
  .constant('RECAPTCHA_SITE_KEY', '6LeM6xMTAAAAAMEGgcuJAMoY6M15suMaQl8-t1JC')
  .config(function ($logProvider) {
    //Disable debug logs in production
    $logProvider.debugEnabled(false);
  });

/* jshint ignore:end */

/*global crashlyticsPlugin:false */

'use strict';

angular.module('cocaColaCordovaApp')
  .config(function ($provide) {
    $provide.decorator('$exceptionHandler', function ($delegate, $window) {
      return function (exception, cause) {
        $delegate(exception, cause);
        try {
          console.log('There is a crash' + exception + ' cause ' + cause);
          if(exception.stack){
            crashlyticsPlugin.addLog('ERROR: ' + exception.stack);
          }else{
            crashlyticsPlugin.addLog('ERROR: ' + exception);
          }

          crashlyticsPlugin.setStringValueForKey('href', $window.location.href);

          if ($window.user_id) {
            crashlyticsPlugin.setUserIdentifier($window.user_id);
            //crashlyticsPlugin.setUserName($window.user_name);
          }

          crashlyticsPlugin.sendCrash();
        }
        catch (err) {

        }
      };
    });
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .config(function ($httpProvider) {
    $httpProvider.defaults.withCredentials = true;
    $httpProvider.defaults.useXDomain = true;
    $httpProvider.defaults.headers.common.Client = 'Coca Cola cordova';
    $httpProvider.defaults.timeout = 10000;
    delete $httpProvider.defaults.headers.common['X-Requested-With'];
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('DistributorsService', function (LocationUtil, $rootScope, $log, RealTimeWebService, DynamicLocationService) {
    var DistributorsService = {};

    DistributorsService._distributors = [];
    DistributorsService._distance_calculated = false;
    DistributorsService._isFetching = false;

    DistributorsService.hasDistributors = function () {
      return DistributorsService._distributors.length !== 0;
    };

    DistributorsService.getDistributors = function (callback, pivotLocation, force) {
      // in case we already fetched the distributors
      if (!force && DistributorsService._distributors.length) {
        if (callback) {
          callback(DistributorsService._distributors);
          return;
        } else {
          return DistributorsService._distributors;
        }
      }

      var params = {};
      var currentLocation = DynamicLocationService.getCurrentLocation();
      if (currentLocation){
        params.lat = currentLocation.lat;
        params.lng = currentLocation.lng;
      }

      RealTimeWebService.getDistributors(params).then(function(result){
        if (result && result.success) {
          $log.debug('DistributorService.getDistributors success');
          if (result.teams) {
            DistributorsService._distributors = result.teams;
            DistributorsService._distance_calculated = false;

            // make sure to recalculate the distance
            if (!pivotLocation && $rootScope._currentUser.lat && $rootScope._currentUser.lng){
              pivotLocation = {lat : $rootScope._currentUser.lat, lng : $rootScope._currentUser.lng};
            }

            if (pivotLocation) {
              DistributorsService._sortByDistance(pivotLocation);
            }

            if (callback) {
              callback(DistributorsService._distributors);
            }
          } else if (callback) {
            callback(result.message);
          }
        } else if (callback) {
          callback(null);
        }
      }, function(){
        if (callback) {
          callback(null);
        }
      });
    };

    DistributorsService.getDistributorByExternalId = function (externalId) {
      return _.find(DistributorsService._distributors, function (distributor) {
        return distributor.external_id === externalId;
      });
    };

    DistributorsService.getNearestDistributor = function (location, callback) {
      if (!DistributorsService._distributors.length) {
        DistributorsService.getDistributors(function () {
          DistributorsService._sortByDistance(location);
          callback(DistributorsService._distributors[0]);
        });
      } else {
        DistributorsService._sortByDistance(location);
        callback(DistributorsService._distributors[0]);
      }
    };

    DistributorsService._sortByDistance = function (location) {
      DistributorsService._calculateDistanceFromCustomer(location);
      DistributorsService._distributors = _.sortBy(DistributorsService._distributors, 'distance');
    };

    DistributorsService._calculateDistanceFromCustomer = function (location) {
      if (!location){
        $log.debug('DistributorService._calculateDistanceFromCustomer: no location provided');
        return;
      }

      if (!DistributorsService._distance_calculated) {
        $log.debug('DistributorService._calculateDistanceFromCustomer: calculating distance to ' + JSON.stringify(location));

        _.each(DistributorsService._distributors, function (distributor) {
          distributor.distance = LocationUtil.getDistanceBetween(location.lat, location.lng, distributor.lat, distributor.lng);
        });

        DistributorsService._distance_calculated = true;
      } else {
        $log.debug('DistributorService._calculateDistanceFromCustomer: already calculated');
      }
    };

    DistributorsService.clearAll = function () {
      DistributorsService._distributors = [];
      DistributorsService._distance_calculated = false;
    };

    return DistributorsService;
  });



'use strict';

angular.module('cocaColaCordovaApp')
  .factory('SecurityInterceptor', function ($q, $location, $log) {
    return {
      'response': function (response) {
        return response;
      },
      'responseError': function (rejection) {
        if (rejection.status === 401) {
          $log.error('SecurityInterceptor got 401');
          if ($location.path() !== '/login') {
            //$location.path('/logout');
            $log.debug('got 401');
          }
          return $q.reject(rejection);
        }
        return $q.reject(rejection);
      }
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('NoConnectionInterceptor', function () {
    return {
      'request': function (config) {
        if (navigator.connection && navigator.connection.type === 'none'){
          // we still give a chance for the network to connect though we want to stop the request from using the whole
          // global timeout interval
          config.timeout = 2000;
        }

        return config;
      }
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('MERCHANT_CONFIG', {
    'LOCAL_STORAGE_PREFIX': 'BRINGG_COCA_COLA',
    'APP_TOKEN': 'cocacola'
  })
  .constant('APP_DEFAULTS', {
    DEFAULT_APP_NAME: 'coca cola mobile',
    NOTIFICATIONS_ANDROID_SENDER_ID : '1074125053721',
    NOTIFICATIONS_PROMOTION : 1,
    NOTIFICATIONS_TASK_UPDATE : 2
  });


console.log('ga_storage._setAccount');
ga_storage._setAccount('UA-49969775-10'); //Replace with your own

'use strict';

angular.module('cocaColaCordovaApp')
  .directive('cartButton', function ($state, $rootScope, CartService) {
    return {
      restrict: 'E',
      transclude: true,
      scope: {
        link: '@',
        dark: '='
      },
      template: '<button class="button button-icon icon ion-ios-cart-outline cart-button" ng-click="handleCartButtonClick($event)"><span class="count" ng-if="count">{{count}}</span></button>',
      link: function (scope) {
        scope.count = CartService.currentCart().length;
        scope.$on('cartCountUpdated', function (event, count) {
          scope.count = count;
        });

        scope.handleCartButtonClick = function () {
          ga_storage._trackEvent('cartButton', 'handleCartButtonClick', 'click');
          $state.go('cart');
        };
      }
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('AuthenticationService', function ($q, RealTimeWebService, localStorageService, $state,
                                              $http, $rootScope, $log, CartService, CategoriesService,
                                              ConfigurationService, DistributorsService, PushService,
                                              DBService, MERCHANT_CONFIG, $window, CipherUtil) {

    var AuthenticationService = {};

    AuthenticationService.lastUsedPhone = null;

    AuthenticationService.signInWithPhone = function (phone, confirmationCode, merchantId, cb) {
      if (phone && !_.isUndefined(phone) && confirmationCode && !_.isUndefined(confirmationCode) && merchantId) {
        return RealTimeWebService.signInWithPhone(phone, confirmationCode, merchantId).then(function (result) {
          if (result && result.status === 'ok') {
            if (result.customer && !_.isUndefined(result.customer)) {

              AuthenticationService.lastUsedPhone = phone;

              AuthenticationService.saveCustomer(result.customer);

              if (cb && !_.isUndefined(cb)) {
                cb(result);
              }
            } else if (cb) {
              cb('undefined customer');
            }
          } else if (result) {
            if (cb && !_.isUndefined(cb)) {
              cb(result.message);
            }
          } else if (cb && !_.isUndefined(cb)) {
            cb(null);
          }
        }, function (reason) {
          if (cb && !_.isUndefined(cb)) {
            cb(reason);
          }
        });
      }
    };

    AuthenticationService.currentUser = function () {
      return $rootScope._currentUser;
    };

    AuthenticationService.signInWithCredentials = function (email, password, merchantId, cb) {
      if (email && password && merchantId) {
        return RealTimeWebService.signInWithCredentials(email, password, merchantId).then(function (result) {
          AuthenticationService._onSignInWithCredentialsSuccess(result, cb);
        }, function (reason) {
          if (cb && !_.isUndefined(cb)) {
            cb(reason);
          }
        });
      } else if (cb){
        cb('invalid params');
      }
    };

    AuthenticationService.signInWithFacebook = function(userData){
      if (userData){
        userData.merchant_id = ConfigurationService.getCurrentMerchantId();
        return RealTimeWebService.signInWithSocial(userData);
      }
    };

    AuthenticationService.savePreLoginCustomer = function(customer){
      localStorageService.set('pre_login_user', customer);
    };

    AuthenticationService.getPreLoginCustomer = function(){
      return localStorageService.get('pre_login_user');
    };

    AuthenticationService._onSignInWithCredentialsSuccess = function(result, cb){
      if (result && result.status === 'ok') {
        if (result.customer && !_.isUndefined(result.customer)) {
          AuthenticationService.saveCustomer(result.customer);

          if (cb) {
            cb(result);
          }
        } else if (cb) {
          cb('undefined customer');
        }
      } else if (result) {
        cb(result.message);
      } else {
        cb(null);
      }
    };

    AuthenticationService.updateUserLocation = function (lat, lng) {
      AuthenticationService._currentUser.lat = lat;
      AuthenticationService._currentUser.lng = lng;

      AuthenticationService._storeUserSecurely(AuthenticationService._currentUser);
      localStorageService.set('location', {lat: lat, lng: lng});
    };

    AuthenticationService.getLastUserLocation = function () {
      var location = localStorageService.get('location');

      if (location) {
        return location;
      }

      if(AuthenticationService._currentUser){
        return {lat: AuthenticationService._currentUser.lat, lng: AuthenticationService._currentUser.lng};
      }

      return null;
    };


    AuthenticationService.signUp = function (userParams, cb) {
      if (userParams) {
        var merchantId = ConfigurationService.getCurrentMerchantId();
        return RealTimeWebService.signUp(userParams, merchantId).then(function (signUpResult) {
          AuthenticationService._onSignUpSuccess(signUpResult, userParams, merchantId, cb);
        }, function (signUpResult) {
          if (cb) {
            cb(signUpResult);
          }
        });
      }
    };

    AuthenticationService._onSignUpSuccess = function(signUpResult, userParams, merchantId, cb){
      if (signUpResult.status === 'ok') {

        if (userParams.phone){
          AuthenticationService.lastUsedPhone = userParams.phone;
          RealTimeWebService.confirm(userParams.phone, merchantId).then(function (confirmResult) {

            if (cb){
              cb(confirmResult);
            }
            if (confirmResult.status === 'ok') {
              $state.go('confirm');
            }
          }, function (confirmReason) {
            if (cb) {
              cb(confirmReason);
            }
          });
        } else if (userParams.email && userParams.password){
          RealTimeWebService.signInWithCredentials(userParams.email, userParams.password, merchantId).then(function (result) {
            AuthenticationService._onSignInWithCredentialsSuccess(result, cb);

            if (result && result.status === 'ok' && result.customer) {
              AuthenticationService.onLoginDone();
            }
          }, function (reason) {
            if (cb && !_.isUndefined(cb)) {
              cb(reason);
            }
          });
        }
      }
    };

    AuthenticationService.onLoginDone = function(){
      var merchant_id = AuthenticationService.currentUser() ? AuthenticationService.currentUser().merchant_id : null;
      if(merchant_id){
        DistributorsService.getDistributors(null, AuthenticationService.getLastUserLocation(), true);
        ConfigurationService.getConfigurationForMerchant(AuthenticationService.currentUser().merchant_id, function (configuration) {
          if (configuration) {
            if (ConfigurationService.enableLocationBasedCatalog()){
              $state.go('loading');
            } else {
              $log.debug('AuthenticationService config loaded for ' + AuthenticationService.currentUser().merchant_id);
              $rootScope.$broadcast('config updated');
              $state.go('categories', {rebuild: true});
            }
          } else {
            $log.error('AuthenticationService error loading configuration for ' + AuthenticationService.currentUser().merchant_id);
            $state.go('categories', {rebuild: true});
          }
        });
      }else{
        $log.error('AuthenticationService.onLoginDone: no merchant id');
      }
    };

    AuthenticationService.updateProfile = function (params) {
      return RealTimeWebService.updateProfile(_.merge(params, {merchant_id: ConfigurationService.getCurrentMerchantId()}), AuthenticationService._currentUser).then(function (result) {
        if (result.status === 'ok' && result.customer) {
          // merge important params if we do not receive them from server
          if (!result.customer.id){
            result.customer.id = AuthenticationService._currentUser.id;
          }
          if (!result.customer.access_token){
            result.customer.access_token = AuthenticationService._currentUser.access_token;
          }
          // store the user
          AuthenticationService.saveCustomer(result.customer);

          return result;
        } else {
          return result;
        }
      }, function () {
        return null;
      });
    };

    AuthenticationService.createStripeCustomer = function(params){
      return RealTimeWebService.createStripeCustomer(params, MERCHANT_CONFIG.MERCHANT_ID, MERCHANT_CONFIG.BRINGG_AUTH_TOKEN);
    };

    AuthenticationService.confirm = function (phone, merchantId) {
      AuthenticationService.lastUsedPhone = phone;
      return RealTimeWebService.confirm(phone, merchantId);
    };

    AuthenticationService.remind = function (email, appName, merchantId, captcha) {
      return RealTimeWebService.remind(email, appName, merchantId, captcha);
    };

    AuthenticationService.logOut = function (cb) {
      $log.debug('AuthenticationService.logOut');
      // set null push token in server to stop getting pushes
      PushService.setPushIdInServer('').then(function(){
        // clear any local data
        localStorageService.clearAll();
        CartService.clearAll();
        CategoriesService.clearAll();
        DistributorsService.clearAll();
        DBService.delete();

        AuthenticationService.clearNonce();
        AuthenticationService.lastUsedPhone = null;
        AuthenticationService._currentUser = null;
        AuthenticationService.isLoggedIn = false;
        $rootScope._currentUser = null;

        $log.debug('AuthenticationService. cleared data');
        if (cb) {
          cb();
        }
      });
    };

    AuthenticationService.saveCustomer = function (customer, updated) {
      AuthenticationService.isLoggedIn = true;
      AuthenticationService._currentUser = angular.copy(customer);
      $rootScope._currentUser = AuthenticationService._currentUser;

      AuthenticationService._storeUserSecurely(customer);

      // set the push token to server after login
      if (!updated){
        AuthenticationService.setPushToken();
      }
    };

    AuthenticationService.setPushToken = function () {
      // se if push token exists regardless of version
      var push_token = PushService.getPushId();

      // if token exists then update the server about it
      if (push_token) {
        PushService.setPushId(push_token, $rootScope.appVersion);
      } else {
        $log.debug('no push token yet');
      }
    };
    AuthenticationService._temporarlyStoredUser = null;
    AuthenticationService.storeUserTemporarly = function(user){
      AuthenticationService._temporarlyStoredUser = user;
    };

    AuthenticationService.getTemporarlyStoredUser = function(){
      return AuthenticationService._temporarlyStoredUser;
    };

    AuthenticationService._nonce = null;
    AuthenticationService._nonceDate = null;
    AuthenticationService.requestNonce = function(){
      var deferred = $q.defer();

      if (AuthenticationService._nonce){
        deferred.resolve(AuthenticationService._nonce);
      } else {
        RealTimeWebService.getNonce().then(function(result){
          if (result.status === 'ok'){
            $log.debug('AuthenticationService get nonce success');
            AuthenticationService._nonce = result.nonce;
            AuthenticationService._nonceDate = new Date();
            deferred.resolve(result.nonce);
          } else {
            if (result.message){
              $log.debug('AuthenticationService get nonce failed. error: ' + result.message);
            } else {
              $log.debug('AuthenticationService get nonce failed. unknown error');
            }
            deferred.reject();
          }
        }, function(){
          $log.debug('AuthenticationService get nonce failed. unknown error');
          deferred.reject();
        });
      }

      return deferred.promise;
    };

    AuthenticationService.clearNonce = function(){
      AuthenticationService._nonce = null;
      AuthenticationService._nonceDate = null;
    };

    AuthenticationService._storeUserSecurely = function(user){
      var sensitive = AuthenticationService._stripSensitiveData(user);
      var securedData = CipherUtil.r(JSON.stringify(sensitive), CipherUtil.t(user.id.toString(16)));
      localStorageService.set('erYL', securedData);

      localStorageService.set('user_id', user.id);
      localStorageService.set('user', user);
    };

    AuthenticationService._stripSensitiveData = function(user){

      var result = {};
      if (user.email){
        result.email = user.email;
        user.email = null;
      }

      if (user.phone){
        result.phone = user.phone;
        user.phone = null;
      }

      if (user.access_token){
        result.access_token = user.access_token;
        user.access_token = null;
      }

      if (user.name){
        result.name = user.name;
        user.name = null;
      }

      if (user.extras && user.extras.device_id){
        result.device_id = user.extras.device_id;
        user.extras.device_id = null;
      }

      return result;
    };

    AuthenticationService._loadUser = function(){
      var userId = localStorageService.get('user_id');
      var user = localStorageService.get('user');

      var suser = localStorageService.get('erYL');
      if (suser) {
        suser = JSON.parse(CipherUtil.s(suser, CipherUtil.t(userId.toString(16))));

        user.phone = suser.phone;
        user.access_token = suser.access_token;
        user.email = suser.email;
        user.name = suser.name;

        if (!user.extras){
          user.extras = {};
        }
        user.extras.device_id = suser.device_id;
      }
      return user;
    };

    AuthenticationService.getAlternativeMerchantId = function(){
      var alternativeMerchantId;
      if (AuthenticationService._currentUser){
        alternativeMerchantId = AuthenticationService.isProductionMerchant() ?
          AuthenticationService._currentUser.alternative_test_merchant_id :
          AuthenticationService._currentUser.alternative_production_merchant_id;
      }
      return alternativeMerchantId;
    };

    AuthenticationService.isProductionMerchant = function(){
      return AuthenticationService._currentUser &&
        AuthenticationService._currentUser.merchant_id !== AuthenticationService._currentUser.alternative_test_merchant_id;
    };

    try {
      $rootScope._currentUser = AuthenticationService._loadUser();

      if (_.isUndefined($rootScope._currentUser) || _.isNull($rootScope._currentUser)) {
        $log.debug('AuthenticationService.load found no user found in local storage');
        AuthenticationService.isLoggedIn = false;
      } else {
        $log.debug('AuthenticationService.load found user : ' + $rootScope._currentUser.id);
        AuthenticationService.isLoggedIn = true;
        AuthenticationService._currentUser = $rootScope._currentUser;
        if (_.isUndefined($rootScope._currentUser.id)) {
          $rootScope._currentUser = undefined;
          AuthenticationService.canLogin = false;
          AuthenticationService.isLoggedIn = false;
          localStorageService.remove('user');
          localStorageService.remove('user_id');
          localStorageService.remove('erYL');
        } else {
          $window.user_id = $rootScope._currentUser.id;
          $window.user_name = $rootScope._currentUser.name;
        }
      }
    } catch (e) {
      $log.error('AuthenticationService: ' + JSON.stringify(e));
      $rootScope._currentUser = null;
      AuthenticationService.canLogin = false;
      AuthenticationService.isLoggedIn = false;
      localStorageService.remove('user');
      localStorageService.remove('user_id');
      localStorageService.remove('erYL');
    }

    return AuthenticationService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('WEB_SERVICE_PATHS', {
    'SIGN_IN': '/api/customer/sign_in',
    'SIGN_UP': '/api/customer/sign_up',
    'CONFIRM': '/api/customer/confirmation/request',
    'REMIND': '/api/customer/reset_password',
    'CREATE_ORDER': '/api/customer/task/create',
    'CREATE_MAINTENANCE_TICKET': '/api/consumer/task/create_ticket',
    'CANCEL_ORDER': '/api/customer/task/cancel',
    'GET_ORDER': '/api/customer/task/',
    'UPDATE_CUSTOMER': '/api/customer',
    'SET_PUSH_TOKEN': '/api/customer/push_token',
    'GET_SHARED_FOR_ORDER': '/shared/orders/',
    'WATCH_ORDER': '/watch/shared/',
    'CUSTOMER_CONFIG' : '/api/consumer/configuration',
    'CREATE_STRIPE_CUSTOMER': '/api/customer/stripe/create',
    'CREATE_CHARGE': '/api/customer/charge/create',
    'GET_NONCE': '/api/nonce',
    'PRODUCTS': '/api/inventory',
    'CATEGORIES': '/api/categories',
    'CUSTOMER_CONFIG_UNSECURED': '/api/consumer/configuration_unsecured',
    'PROMOTIONS': '/api/consumer/promotions',
    'DISTRIBUTION_TEAMS': '/api/consumer/teams',
    'MERCHANTS_BY_COUNTRY_CODE': '/api/consumer/merchants/',
    'CALCULATE_PRICE': '/api/consumer/task/price'
  })
  .factory('RealTimeWebService', function ($http, $log, $q, $rootScope,
                                           WEB_SERVICE_PATHS, DynamicHostService, MERCHANT_CONFIG) {

    var RealTimeWebService = {};

    RealTimeWebService.access_token = null;

    RealTimeWebService._noCacheHeaders = {
      'Cache-Control': 'no-cache, no-store',
      'Pragma': 'no-cache',
      'Expires': 0
    };

    // ==================================================================
    // =========================== api calls ============================

    RealTimeWebService.signUp = function (user, merchantId) {
      var params = {
        name: user.name,
        address: user.address,
        email: user.email,
        phone: user.phone,
        password: user.password,
        country_code: user.country_code,
        merchant_id: merchantId,
        extras : {
          lat: user.lat,
          lng: user.lng
        }
      };

      // add optional params
      if (user.activation_code){
        params.activation_code = user.activation_code;
      }
      if (user.stripe_id){
        params.stripe_id = user.stripe_id;
      }
      if (user.extras && user.extras.company_name){
        params.extras.company_name = user.extras.company_name;
      }

      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.SIGN_UP, 'POST', params,
        RealTimeWebService._noCacheHeaders);
    };

    RealTimeWebService.signInWithPhone = function (phone, confirmationCode, merchantId) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.SIGN_IN, 'POST', {
        phone: phone,
        confirmation_code: confirmationCode,
        merchant_id: merchantId
      }, RealTimeWebService._noCacheHeaders);
    };

    RealTimeWebService.signInWithCredentials = function (email, password, merchantId) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.SIGN_IN, 'POST', {
        email: email,
        password: password,
        merchant_id: merchantId
      }, RealTimeWebService._noCacheHeaders);
    };

    RealTimeWebService.signInWithSocial = function(userData){
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.SIGN_IN, 'POST', userData
        , RealTimeWebService._noCacheHeaders);
    };

    RealTimeWebService.confirm = function (phone, merchantId) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CONFIRM, 'POST', {
        phone: phone,
        merchant_id: merchantId
      });
    };

    RealTimeWebService.remind = function (email, appName, merchantId) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.REMIND, 'POST', {
        email: email,
        app_name: appName,
        merchant_id: merchantId
        //recaptcha: captcha
      });
    };

    RealTimeWebService.createStripeCustomer = function(params){
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CREATE_STRIPE_CUSTOMER, 'POST', params);
    };

    RealTimeWebService.createCharge = function(params){
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CREATE_CHARGE, 'POST', params);
    };


    RealTimeWebService.createOrder = function (order, nonce) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CREATE_ORDER, 'POST', _.merge(order, {nonce: nonce}));
    };

    RealTimeWebService.calculatePrice = function (order) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CALCULATE_PRICE, 'POST', order);
    };


    RealTimeWebService.cancelOrder = function (order_id) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CANCEL_ORDER, 'POST', {task_id: order_id});
    };

    RealTimeWebService.setPushId = function (token) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.SET_PUSH_TOKEN, 'POST', {push_token: token});
    };

    RealTimeWebService.updateProfile = function (updateParams) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.UPDATE_CUSTOMER, 'PATCH', updateParams);
    };

    RealTimeWebService.getOrder = function (orderId) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.GET_ORDER + orderId, 'GET', {});
    };

    RealTimeWebService.getSharedForOrder = function (orderUuid) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.GET_SHARED_FOR_ORDER + orderUuid + '?order_uuid='+ orderUuid, 'GET', {});
    };

    RealTimeWebService.getCustomerConfig = function(params) {
      if($rootScope._currentUser){
        return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CUSTOMER_CONFIG + '?merchant_id=' + params.merchant_id, 'GET', {});
      }else{
        return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CUSTOMER_CONFIG_UNSECURED + '?merchant_id=' + params.merchant_id, 'GET', {});
      }
    };

    RealTimeWebService.getProducts = function(params) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.PRODUCTS, 'GET', params ? params : {});
    };

    RealTimeWebService.getCategories = function(params) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CATEGORIES, 'GET', params ? params : {});
    };

    RealTimeWebService.getPromotions = function() {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.PROMOTIONS, 'GET', {});
    };

    RealTimeWebService.getDistributors = function(params) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.DISTRIBUTION_TEAMS, 'GET', params);
    };

    RealTimeWebService.getMerchantsByCountryCode = function(params) {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.MERCHANTS_BY_COUNTRY_CODE + params.country_code, 'GET', {});
    };

    RealTimeWebService.getNonce = function() {
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.GET_NONCE, 'GET', {});
    };

    RealTimeWebService.createMaintenanceTicket = function(ticket){
      return RealTimeWebService._call(DynamicHostService.realTimeHost + WEB_SERVICE_PATHS.CREATE_MAINTENANCE_TICKET, 'POST', ticket);
    };

    // ===================================================================

    RealTimeWebService._call = function (path, type, params, headers) {
      $log.debug('WebService._call: path = ' + path + ' type = ' + type + ' params = ' + JSON.stringify(params));

      var req = RealTimeWebService._generateRequestConfig(path, type, params, headers);
      return RealTimeWebService._sendRequest(req);
    };

    RealTimeWebService._generateRequestConfig = function(path, type, params, headers){
      var req = {
        method: type,
        url: path
      };

      if (headers){
        req.headers = headers;
      }

      var authParams = {
        params: {
          app_token: MERCHANT_CONFIG.APP_TOKEN
        }
      };

      if(MERCHANT_CONFIG.MERCHANT_ID && MERCHANT_CONFIG.BRINGG_AUTH_TOKEN){
        _.merge(req, {params: {merchant_id: MERCHANT_CONFIG.MERCHANT_ID, developer_access_token:MERCHANT_CONFIG.BRINGG_AUTH_TOKEN}}); //auth for request with realtime
        _.merge(authParams, {merchant_id: MERCHANT_CONFIG.MERCHANT_ID, developer_access_token:MERCHANT_CONFIG.BRINGG_AUTH_TOKEN}); //auth for request with realtime where developer token is needed
      }

      if ($rootScope._currentUser) {
        authParams.params.merchant_id = $rootScope._currentUser.merchant_id;
        authParams.params.access_token = $rootScope._currentUser.access_token;

        if ($rootScope._currentUser.phone) {
          authParams.params.phone = $rootScope._currentUser.phone;
        } else {
          authParams.params.phone = $rootScope._currentUser.email;
        }
      }

      if (type === 'GET'){
        _.merge(authParams.params, params);
        _.merge(req, authParams);
      } else {
        _.merge(params, authParams.params);
        _.merge(req, {data: params});
      }

      return req;
    };

    RealTimeWebService._sendRequest = function(req){
      var deferred = $q.defer();
      $http(req).then(function (result) {
        if (result.data && result.data.status === 'error') {
          deferred.reject(result.data);
        } else {
          deferred.resolve(result.data);
        }
      }, function (reason) {
        if (reason.message) {
          $log.error('ERROR: ' + reason.message);
        } else {
          $log.error(reason);
        }
        deferred.reject(reason);
      });

      return deferred.promise;
    };

    // ============================================================

    return RealTimeWebService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('MainController', function ($scope, $state, $log, $ionicSideMenuDelegate, $rootScope, $ionicPopup, $translate,
                                          AuthenticationService, OrderService, ConfigurationService, ORDER_STATUS,
                                          MaintenanceTicketService, DistributorsService) {

    $scope.allowMultipleOrders = ConfigurationService.allowMultipleOrders();
    $scope.allowMaintenanceTickets = ConfigurationService.allowMaintenanceTickets();
    $scope.customerSupportPhone = ConfigurationService.getMerchantPhone();
    $scope.termsAndConditionsLink = ConfigurationService.getTermsAndConditionsLink();
    $scope.privacyPolicyLink = ConfigurationService.getPrivacyPolicyLink();
    $scope.allowRedeemCoupon = false;
    $scope.alternativeMerchantId = AuthenticationService.getAlternativeMerchantId();

    $scope.showHeader = function () {
      if ($state.includes('login') || $state.includes('login_social')) {
        return false;
      } else if ($state.includes('remind')) {
        return false;
      } else if ($state.includes('register')) {
        return false;
      } else if ($state.includes('confirm')) {
        return false;
      } else if ($state.includes('logout')) {
        return false;
      } else if ($state.includes('loading')) {
        return false;
      } else if ($state.includes('rating')) {
        return false;
      } else if ($state.includes('credit_card')) {
        return false;
      } else if ($state.includes('no_service')) {
        return false;
      }
      return true;
    };

    $scope.handleSendFeedback = function () {
      ga_storage._trackEvent('MainController', 'handleSendFeedback', 'click');
      $log.debug('MainController.handleSendFeedback');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      var link = 'mailto:mycokesupport@bringg.com?' +
        'subject=' + encodeURIComponent('My Coke App Feedback') +
        '&body=' + encodeURIComponent(
          'User Id: ' + AuthenticationService.currentUser().id +
          '\nApp Version: ' + $rootScope.appVersion +
          '\nMerchant Id: ' + AuthenticationService.currentUser().merchant_id);

      window.location.href = link;
    };

    $scope.handleAboutButtonClick = function (showMerchantId) {
      ga_storage._trackEvent('MainController', 'handleAboutButtonClick', 'click');
      $log.debug('MainController.handleAboutButtonClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      var appVersion = $rootScope.appVersion;

      var user = AuthenticationService.currentUser();
      var userName;
      var merchantId;
      if (user){
        userName = AuthenticationService.currentUser().name;
        merchantId = AuthenticationService.currentUser().merchant_id;
      }

      var showEnv = !_.isUndefined(AuthenticationService.getAlternativeMerchantId()) && !_.isNull(AuthenticationService.getAlternativeMerchantId());
      var env = AuthenticationService.isProductionMerchant() ? $translate.instant('production') : $translate.instant('test');

      $ionicPopup.show({
        title: $translate.instant('action_about'),
        buttons: [{text: $translate.instant('close')}],
        template: '<ion-list can-swipe="false">' +
        '<ion-item> {{:: "user" | translate }} : ' + userName + '</ion-item>' +
        '<ion-item> {{:: "app_version" | translate }} : ' + appVersion + '</ion-item>' +
        (showMerchantId ? '<ion-item> {{:: "merchant_id" | translate }} : ' + merchantId + '</ion-item>'  : '') +
        (showEnv ? '<ion-item> {{:: "env" | translate }} : ' + env + '</ion-item>'  : '') +
        '</ion-list>'
      });
    };

    $scope.handleUiConfigurationButtonClick = function(){
      ga_storage._trackEvent('MainController', 'handleUiConfigurationButtonClick', 'click');
      $log.debug('MainController.handleUiConfigurationButtonClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      $state.go('ui_configuration');
    };

    $scope.handleEditProfileClick = function () {
      ga_storage._trackEvent('MainController', 'handleEditProfileClick', 'click');
      $log.debug('MainController.handleEditProfileClick');
      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      $state.go('register', {edit: true});
    };

    $scope.handleLogoutClick = function () {
      ga_storage._trackEvent('MainController', 'handleLogoutClick', 'click');
      $log.debug('MainController.handleLogoutClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      $state.go('logout');
    };

    $scope.handleHistoryButtonClick = function(){
      $log.debug('MainController.handleHistoryClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      $state.go('history');
    };

    $scope.handleOngoingOrdersButtonClick = function(){
      $log.debug('MainController.handleOngoingOrdersClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      var ongoing = OrderService.getOngoingOrders();
      if (!ongoing || ongoing.length === 0){
        $ionicPopup.alert({
          template: $translate.instant('no_ongoing_orders'), okText: $translate.instant('ok')
        });
      } else {
        $state.go('ongoing_orders');
      }
    };

    $scope.handleRedeemCoupon = function () {
      $log.debug('MainController.handleRedeemCouponClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

    };

    $scope.handleCallCustomerSupportClick = function(){
      $log.debug('MainController.handleRedeemCouponClick');
      document.location.href = 'tel:' + ConfigurationService.getMerchantPhone();
    };

    $scope._showingAlert = false;
    $scope._goToCategories = function(){
      // make sure we redirect and show the alert only once since the updates can arrive multiple at once.
      if (!$scope._showingAlert) {
        $scope._showingAlert = true;
        $ionicPopup.alert({
          template: $translate.instant('notification_delivery_finished'), okText: $translate.instant('ok')
        }).then(function(){
          $scope._showingAlert = false;
        });
        OrderService.clearSaved(true);

        // if location based catalog go back to loading screen
        if (ConfigurationService.enableLocationBasedCatalog()){
          DistributorsService.clearAll();
          $state.go('loading');
        } else {
          $state.go('categories', {rebuild: true});
        }
      }
    };

    $scope.onOrderDone = function () {
      var existingOrder = OrderService.getSavedOrder();
      var sharedLocationConfig = OrderService.getSharedLocationConfig();

      if (existingOrder && sharedLocationConfig) {
        $log.debug('MainController.onOrderDone: redirecting to rating');
        $state.go('rating');
      } else {
        var ticket = MaintenanceTicketService.getTicket();
        if (ticket){
          $log.debug('MainController.onOrderDone: ticket order done with id ' + ticket.id);
          MaintenanceTicketService.clearTicket();
        } else {
          $log.debug('MainController.onOrderDone: no order or shared location config');
        }

        $scope._goToCategories();
      }
    };

    $scope.onOrderCancelled = function(event, params){
      $log.debug('MainController.onOrderCanceled: ' + JSON.stringify(params));
      var ticket = MaintenanceTicketService.getTicket();
      if (ticket && ticket.id === params.id){
        MaintenanceTicketService.clearTicket();
      }
    };

    $scope.handleMaintenanceTicketButtonClick = function () {
      $log.debug('MainController.handleMaintenanceClick');

      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      $state.go('maintenance_ticket');
    };

    $scope.handleTermsAndConditionsClick = function () {
      $scope._openExternalLink(ConfigurationService.getTermsAndConditionsLink());
    };

    $scope.handlePrivacyPolicyClick = function () {
      $scope._openExternalLink(ConfigurationService.getPrivacyPolicyLink());
    };

    $scope._openExternalLink = function(url) {
      if (device && device.platform.toUpperCase() === 'ANDROID') {
        navigator.app.loadUrl(url, { openExternal: true });
      }
      else if (device && device.platform.toUpperCase() === 'IOS') {
        window.open(url, '_system');
      } else {
        window.location.href = url;
      }
    };

    $scope.handleSwitchMerchantClick = function () {
      if ($ionicSideMenuDelegate.isOpenLeft()) {
        $ionicSideMenuDelegate.toggleLeft();
      }

      AuthenticationService.logOut(function(){
        $state.go('loading', {merchant_id: $scope.alternativeMerchantId});
      });
    };

    $scope.onConfigUpdated = function(){
      $log.debug('MainController. config updated');
      $scope.allowMultipleOrders = ConfigurationService.allowMultipleOrders();
      $scope.allowMaintenanceTickets = ConfigurationService.allowMaintenanceTickets();
      $scope.customerSupportPhone = ConfigurationService.getMerchantPhone();
      $scope.termsAndConditionsLink = ConfigurationService.getTermsAndConditionsLink();
      $scope.privacyPolicyLink = ConfigurationService.getPrivacyPolicyLink();
      $scope.allowRedeemCoupon = false;
      $scope.alternativeMerchantId = AuthenticationService.getAlternativeMerchantId();
    };

    $scope.$on('order done', $scope.onOrderDone);
    $scope.$on('order cancelled', $scope.onOrderCancelled);
    $scope.$on('config updated', $scope.onConfigUpdated);
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('LoginController', function ($scope, $rootScope, $state, $translate, $ionicPopup, $ionicLoading, $log,
                                           AuthenticationService, ConfigurationService, NetworkHelper,
                                           CountryCodeExtractor) {

    ga_storage._trackPageview('Login');
    $scope.withCredentials = false;
    $scope.user = {};
    $scope.sending = false;

    $scope.$on('$ionicView.enter', function () {
      $scope.user = {};
      $scope.sending = false;
      $log.debug('LoginController.$ionicView.enter called');
    });

    $scope.handleLoginWithUsernameClick = function () {
      ga_storage._trackEvent('LoginController', 'handleLoginWithUsernameClick', 'click');
      $log.debug('LoginController.handleLoginWithUsernameClick');
      $scope.withCredentials = true;
    };

    $scope.handleLoginWithPhone = function () {
      ga_storage._trackEvent('LoginController', 'handleLoginWithPhone', 'click');
      $log.debug('LoginController.handleLoginWithPhone');
      $scope.withCredentials = false;
    };

    $scope.handleLoginClicked = function () {
      ga_storage._trackEvent('LoginController', 'handleLoginClicked', 'click');
      $log.debug('LoginController.handleLoginClicked');

      if (!NetworkHelper.validateNetwork()){
        return;
      }

      // login with phone
      if (!$scope.withCredentials) {
        $log.debug('LoginController.handleLoginClicked with phone');

        var countryCode = CountryCodeExtractor.getCountryCode();
        var phone = $scope.user.phone;

        // validate phone
        if (isValidNumber(phone, countryCode)) {
          phone = formatE164(countryCode, phone);
          $ionicLoading.show();
          $scope.sending = true;
          AuthenticationService.confirm(phone, ConfigurationService.getCurrentMerchantId()).then(function (result) {
            $ionicLoading.hide();
            if (result && result.status === 'ok') {
              $log.debug('LoginController.confirm succeeded going to confirm');
              $state.go('confirm');
            } else {
              $log.error('LoginController.confirm failed');
              $scope.handleErrorResponse(result);
            }
          }, function (result) {
            $ionicLoading.hide();
            $scope.handleErrorResponse(result);
          });
        } else { // phone not valid
          $scope.sending = false;
          $log.error('LoginController.handleLoginClicked invalid phone');
          $ionicPopup.alert({title: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
        }
      } else { // login with email password
        if (!$scope.user.email) {
          $ionicPopup.alert({title: $translate.instant('error_invalid_email'), okText: $translate.instant('ok')});
        } else if (!$scope.user.password) {
          $ionicPopup.alert({title: $translate.instant('error_invalid_password'), okText: $translate.instant('ok')});
        }
        else {
          $ionicLoading.show();
          $scope.sending = true;
          if ($scope.user.email === 'appstore@bringg.com') {
            ConfigurationService.getConfigurationForMerchant(8250, function () {
              AuthenticationService.signInWithCredentials($scope.user.email, $scope.user.password, ConfigurationService.getCurrentMerchantId(), function (result) {
                $ionicLoading.hide();
                $scope.sending = false;
                if (result && result.status === 'ok') {
                  AuthenticationService.onLoginDone();
                } else {
                  $scope.handleErrorResponse(result);
                }
              }, function (reason) {
                $scope.handleErrorResponse(reason);
              });
            });
          } else {
            AuthenticationService.signInWithCredentials($scope.user.email, $scope.user.password, ConfigurationService.getCurrentMerchantId(), function (result) {
              $ionicLoading.hide();
              $scope.sending = false;
              if (result && result.status === 'ok') {
                AuthenticationService.onLoginDone();
              } else {
                $scope.handleErrorResponse(result);
              }
            }, function (reason) {
              $scope.handleErrorResponse(reason);
            });
          }
        }
      }
    };

    $scope.handleLoginWithSocialAccount = function() {
      ga_storage._trackEvent('LoginController', 'handleSocialLoginClicked', 'click');
      $log.debug('LoginController.confirm handleSocialLoginClicked');
      $state.go('login_social');
    };

    $scope.forgotPasswordClick = function () {
      ga_storage._trackEvent('LoginController', 'forgotPasswordClick', 'click');
      $log.debug('LoginController.confirm forgotPasswordClick');
      $state.go('remind');
    };

    $scope.handleRegisterClicked = function () {
      ga_storage._trackEvent('LoginController', 'handleRegisterClicked', 'click');
      $log.debug('LoginController.confirm handleRegisterClicked');
      $state.go('register');
    };

    $scope.$watch(AuthenticationService.isLoggedIn, function () {
      if (AuthenticationService.isLoggedIn) {
        $state.go('categories', {rebuild: true});
      }
    });

    $scope.handleErrorResponse = function (result) {
      $scope.sending = false;
      if (result && result.message) {
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: result.message, okText: $translate.instant('ok')});
      } else if (result && result.status && result.status === 429){
        var message = result.data ? result.data : $translate.instant('error_too_many_requests');
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: message, okText: $translate.instant('ok')});
      } else if (result && result.status){
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: $translate.instant('invalid_credentials'), okText: $translate.instant('ok')});
      }
      else {
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), okText: $translate.instant('ok')});
      }
    };


    // ============================================
    // ============================================

    $scope.debug = {
      text: null,
      countryCode: null,
      enabled: $rootScope.isDebug
    };

    // ==========================================

    $scope.dtCount = 0;
    $scope.magicTapNumber = 5;
    $scope.doubleTap = function () {
      $log.debug('double tap');
      $scope.dtCount++;
      if ($scope.dtCount % $scope.magicTapNumber === 0) {
        ga_storage._trackEvent('LoginController', 'doubleTapDEBUG', 'click');
        $ionicPopup.confirm({
          title: 'Enter Code',
          template: '<label class="item item-input"><input type="text" autocapitalize="off" ng-model="debug.text"></label>',
          scope: $scope,
          cancelText: $translate.instant('cancel'),
          okText: $translate.instant('ok')
        }).then(function (res) {
          if (res) {
            if ($scope.debug.text === 'wantafanta') {
              $rootScope.isDebug = true;
              $scope.debug.enabled = true;
            } else if ($scope.debug.text === 'ccdemo') {
              $rootScope.isGlobalDemo = true;
              $rootScope.isLocalDemo = false;
              $state.go('loading');
            } else if ($scope.debug.text && $scope.debug.text.startsWith('bg')){
              $rootScope.isGlobalDemo = false;
              $rootScope.isLocalDemo = true;
              CountryCodeExtractor.setCountryCode($scope.debug.text);
              $state.go('loading');
            }
          }
        });
      }
    };

    $scope.handleSetCountryCode = function () {
      $ionicPopup.confirm({
        title: 'Set Country Code',
        template: '<label class="item item-input"><input type="text" autocapitalize="off" ng-model="debug.countryCode"></label>',
        scope: $scope,
        cancelText: $translate.instant('cancel'),
        okText: $translate.instant('ok')
      }).then(function (res) {
        if (res) {
          if ($scope.debug.countryCode === 'staging' && $rootScope.isProduction) {
            $rootScope.isProduction = false;
            $rootScope.isGlobalDemo = false;
            $rootScope.isLocalDemo = false;
            ConfigurationService.setEnv('staging');
          } else if ($scope.debug.countryCode === 'production' && !$rootScope.isProduction) {
            $rootScope.isProduction = true;
            $rootScope.isGlobalDemo = false;
            $rootScope.isLocalDemo = false;
            ConfigurationService.setEnv('production');
          } else if ($scope.debug.text === 'ccdemo') { // allow moving to demo from here also
            $rootScope.isGlobalDemo = true;
            $rootScope.isLocalDemo = false;
          } else if ($scope.debug.countryCode && $scope.debug.countryCode.length === 2) {
            $log.debug('setting cc to ' + $scope.debug.countryCode);
            CountryCodeExtractor.setCountryCode($scope.debug.countryCode);
          }
          $state.go('loading');
        }
      });
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('LoginSocialController', function ($scope, $rootScope, $state, $translate, $ionicPopup, $ionicLoading, $log,
                                           AuthenticationService, ConfigurationService, SocialLoginAdditionalParamsService,
                                           NetworkHelper, CountryCodeExtractor, $q) {

    ga_storage._trackPageview('Login-Social');
    $scope.user = {};
    $scope.sending = false;

    $scope.$on('$ionicView.enter', function () {
      $scope.user = {};
      $scope.sending = false;
      $log.debug('LoginSocialController.$ionicView.enter called');
    });

    $scope.handleLoginWithUsernameClick = function () {
      $log.debug('LoginSocialController.handleLoginWithUsernameClick');
      $state.go('login');
    };

    $scope.handleLoginWithPhone = function () {
      $log.debug('LoginSocialController.handleLoginWithPhone');
      $state.go('login');
    };

    $scope.handleRegisterClicked = function () {
      ga_storage._trackEvent('LoginSocialController', 'handleRegisterClicked', 'click');
      $log.debug('LoginSocialController.confirm handleRegisterClicked');
      $state.go('register');
    };

    // =======================================

    $scope.handleLoginClicked = function () {
      if (!NetworkHelper.validateNetwork()){
        $log.debug('LoginSocialController. handle login no network');
        return;
      }

      $log.debug('LoginSocialController.handleLogin');

      var countryCode = CountryCodeExtractor.getCountryCode();
      var phone = $scope.user.phone;

      // validate phone
      if (isValidNumber(phone, countryCode)) {
        phone = formatE164(countryCode, phone);
        $scope.sending = true;
      } else { // phone not valid
        $scope.sending = false;
        $log.error('LoginSocialController.handleLoginClicked invalid phone');
        $ionicPopup.alert({title: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
      }
    };

    // ============================================
    // ============================================

    // This is the fail callback from the login method
    var fbLoginError = function(error){
      $log.error('fbLoginError', error);
      $ionicLoading.hide();
      $ionicPopup.alert({
        template: JSON.stringify(error),
        okText: $translate.instant('ok')
      });
    };

    // This is the success callback from the login method
    var fbLoginSuccess = function(response) {
      if (!response.authResponse){
        fbLoginError('Cannot find the authResponse');
        return;
      }

      var authResponse = response.authResponse;

      $scope.getFacebookProfileInfo(authResponse)
        .then(function(profileInfo){
          $scope._onFBLoginSuccess(profileInfo, authResponse);
        },$scope._onFBLoginFailed);
    };

    // This method is to get the user profile info from the facebook api
    $scope.getFacebookProfileInfo = function (authResponse) {
      var info = $q.defer();

      facebookConnectPlugin.api('/me?fields=email,name&access_token=' + authResponse.accessToken, null,
        function (response) {
          $log.debug(response);
          info.resolve(response);
        },
        function (response) {
          $log.error(response);
          info.reject(response);
        }
      );
      return info.promise;
    };

    //This method is executed when the user press the "Login with facebook" button
    $scope.handleLoginWithFacebook = function() {
      facebookConnectPlugin.getLoginStatus($scope._onFBLoginStatusRetrieved);
    };

    $scope._onFBLoginStatusRetrieved = function(success){
      if(success.status === 'connected'){
        // The user is logged in and has authenticated your app, and response.authResponse supplies
        // the user's ID, a valid access token, a signed request, and the time the access token
        // and signed request each expire
        $log.debug('getLoginStatus', success.status);

        // Check if we have our user saved
        var user = AuthenticationService.getPreLoginCustomer();

        if(_.isUndefined(user) || _.isNull(user) || !user.facebook_id){
          $scope.getFacebookProfileInfo(success.authResponse)
            .then(function(profileInfo){
              $scope._onFBLoginSuccess(profileInfo, success.authResponse);
            },$scope._onFBLoginFailed);
        } else {
          user.facebook_access_token = success.authResponse.accessToken;
          $scope._tryCustomerSignInWithFB(user);
        }
      } else {
        // If (success.status === 'not_authorized') the user is logged in to Facebook,
        // but has not authenticated your app
        // Else the person is not logged into Facebook,
        // so we're not sure if they are logged into this app or not.

        $log.debug('getLoginStatus', success.status);

        $ionicLoading.show({
          template: 'Logging in...'
        });

        // Ask the permissions you need. You can learn more about
        // FB permissions here: https://developers.facebook.com/docs/facebook-login/permissions/v2.4
        facebookConnectPlugin.login(['email', 'public_profile'], fbLoginSuccess, fbLoginError);
      }
    };

    $scope._onFBLoginSuccess = function(profileInfo, authResponse) {
      $log.debug('SocialLoginController: fb login success with ' + JSON.stringify(profileInfo));
      $ionicLoading.hide();

      var user = {
        fbAuthResponse: authResponse,
        facebook_access_token: authResponse.accessToken,
        facebook_id: profileInfo.id,
        name: profileInfo.name,
        email: profileInfo.email
      };

      AuthenticationService.savePreLoginCustomer(user);
      $scope._tryCustomerSignInWithFB(user);
    };

    $scope._tryCustomerSignInWithFB = function(userData){
      $log.debug('SocialLoginController. trying to sign in with fb');
      var requiredParams = $scope._getRequiredParams(userData);
      if (_.isEmpty(requiredParams)){
        $ionicLoading.show();
        AuthenticationService.signInWithFacebook(userData).then($scope._handleSignInResult, $scope._handleSignInResult);
      } else {
        SocialLoginAdditionalParamsService.open(requiredParams, userData);
      }
    };

    $scope._onFBLoginFailed = function(error){
      $log.error('profile info fail. error: ' + error);
      $ionicPopup.alert({
        template: _.isObject(error) ? JSON.stringify(error) : error,
        okText: $translate.instant('ok')
      });
    };

    $scope._getRequiredParams = function(user){
      if (_.isUndefined(user)){
        user = {};
      }
      var requiredParams = {};

      if (ConfigurationService.shouldValidateSocialLoginParams()){
        if (_.isUndefined(user.name)){
          requiredParams.name = true;
        }
        if (_.isUndefined(user.address)){
          requiredParams.address = true;
        }
        // verify require phone is explicitly defined in configuration.
        if (_.isUndefined(user.phone) && (!_.isUndefined(ConfigurationService.requirePhoneOnSignUp()) && ConfigurationService.requirePhoneOnSignUp())){
          requiredParams.phone = true;
        }
        var missingActivationCode = _.isUndefined(user.extras) || _.isUndefined(user.extras.activation_code);
        if (missingActivationCode && ConfigurationService.enableActivationCode()){
          requiredParams.activation_code = true;
        }
        var missingCompanyName = _.isUndefined(user.extras) || _.isUndefined(user.extras.company_name);
        if (missingCompanyName && ConfigurationService.requireCompanyName()){
          requiredParams.company_name = true;
        }
      }

      return requiredParams;
    };

    $scope._handleSignInResult = function(result) {
      $ionicLoading.hide();
      if (result) {
        $scope.sending = false;
        if (result.status === 'ok' && !_.isUndefined(result.customer)) {
          AuthenticationService.savePreLoginCustomer(null);
          AuthenticationService.saveCustomer(result.customer);
          AuthenticationService.onLoginDone();
        } else if (result.rc === 8) {
          SocialLoginAdditionalParamsService.open(result.params, AuthenticationService.getPreLoginCustomer());
        } else if (result.rc === 6){
          $state.go('no_service');
        } else {
          if (result.message) {
            $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: result.message, okText: $translate.instant('ok')});
          } else if (result.status && result.status === 429){
            var message = result.data ? result.data : $translate.instant('error_too_many_requests');
            $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: message, okText: $translate.instant('ok')});
          } else if (result.status){
            $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: $translate.instant('invalid_credentials'), okText: $translate.instant('ok')});
          } else {
            $ionicPopup.alert({title: $translate.instant('error_login_failed'), okText: $translate.instant('ok')});
          }
        }
      } else {
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), okText: $translate.instant('ok')});
      }
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('SocialLoginAdditionalParamsController', function ($scope, $log, SocialLoginAdditionalParamsService, LocationUtil) {
    ga_storage._trackPageview('SocialLoginAdditionalParamsController');
    $scope.submitDisabled = false;

    $scope.handleCancelClick = function () {
      ga_storage._trackEvent('SocialLoginAdditionalParamsController', 'handleCancelClick', 'click');
      $scope.submitDisabled = true;
      $log.debug('SocialLoginAdditionalParamsController.handleCancelClick');
      SocialLoginAdditionalParamsService.cancel();
    };

    $scope.handleContinueClick = function () {
      ga_storage._trackEvent('SocialLoginAdditionalParamsController', 'handleContinueClick', 'click');
      $scope.submitDisabled = true;
      $log.debug('SocialLoginAdditionalParamsController.handleContinueClick');
      SocialLoginAdditionalParamsService.apply($scope.user);
    };

    $scope.addressSelectedCallback = function (callback) {
      $scope.user.address = callback.item.formatted_address;
      if (callback.item.geometry && callback.item.geometry.location){
        $scope.user.lat = callback.item.geometry.location.lat();
        $scope.user.lng = callback.item.geometry.location.lng();
      } else {
        $scope.user.lat = null;
        $scope.user.lng = null;
        $log.error('user address not geocoded');
      }
    };

    $scope.addressDataCallbackMethod = function (query) {
      return LocationUtil.geocodeAddress(query);
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('SocialLoginAdditionalParamsService', function ($ionicModal, $ionicLoading, $ionicPopup, $rootScope, $log, $translate, $state,
                                                           AuthenticationService) {
    var SocialLoginAdditionalParamsService = {};

    SocialLoginAdditionalParamsService.modal = null;
    SocialLoginAdditionalParamsService.open = function (requiredParams, user) {

      $log.debug('SocialLoginAdditionalParamsService.open');

      var scope = $rootScope.$new();
      scope.user = user ? user : {};
      scope.requiredParams = {};
      _.each(requiredParams, function(param){
        scope.requiredParams[param] = true;
      });

      $log.debug('SocialLoginAdditionalParamsService. required params: ' + JSON.stringify(scope.requiredParams));
      $ionicModal.fromTemplateUrl('scripts/core/login_social/login-social-additional-params.html', {
        scope: scope,
        animation: 'slide-in-up',
        backdropClickToClose: false,
        hardwareBackButtonClose: true
      }).then(function (modal) {
        SocialLoginAdditionalParamsService.modal = modal;
        SocialLoginAdditionalParamsService.modal.show();
      });
    };

    SocialLoginAdditionalParamsService.cancel = function () {
      $ionicLoading.hide();
      if(!SocialLoginAdditionalParamsService.modal){
        return;
      }
      SocialLoginAdditionalParamsService.modal.remove();
      SocialLoginAdditionalParamsService.modal = null;
    };

    SocialLoginAdditionalParamsService.apply = function (additionalUserData) {
      var user = _.merge(AuthenticationService.getPreLoginCustomer(), additionalUserData);
      AuthenticationService.savePreLoginCustomer(user);
      $ionicLoading.show();
      AuthenticationService.signInWithFacebook(user).then(SocialLoginAdditionalParamsService._onUpdateProfile);
      SocialLoginAdditionalParamsService.cancel();
    };

    SocialLoginAdditionalParamsService._onUpdateProfile = function(result){
      $ionicLoading.hide();
      if (result && result.status === 'ok'){
        $state.go('categories');
      } else {
        var errorMessage = result.message ? result.message : result;
        $log.error('SocialLoginAdditionalParamsService: update profile failed. error: ' + errorMessage);
        $ionicPopup.alert({
          title: $translate.instant('error_login_failed'),
          template: errorMessage,
          okText: $translate.instant('ok')
        });
      }
    };

    return SocialLoginAdditionalParamsService;
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .controller('ConfirmController', function ($scope, AuthenticationService, ConfigurationService, NetworkHelper,
                                             CountryCodeExtractor, $state, $ionicPopup, $ionicLoading, $translate,
                                             $log, $rootScope) {
    ga_storage._trackPageview('Confirmation');

    if ($rootScope.smsSupported) {
      $scope.smsInboxPlugin = cordova.require('cordova/plugin/smsinboxplugin');
    }

    $scope._startSmsReception = function () {
      ga_storage._trackEvent('ConfirmController', '_startSmsReception', 'called');
      if ($scope.smsInboxPlugin) {
        $scope.smsInboxPlugin.startReception(function (msg) {
          var code = $scope._extractConfirmationCode(msg);
          if (code) {
            $log.debug('ConfirmController.startReception success');
            ga_storage._trackEvent('ConfirmController', '_startSmsReception', 'success');
            $scope._automaticSignIn(code);
          }else{
            $log.debug('ConfirmController.startReception failedParsingMsg');
            ga_storage._trackEvent('ConfirmController', '_startSmsReception', 'failedParsingMsg');
          }
        }, function () {
          $log.debug('ConfirmController.startReception failed');
          ga_storage._trackEvent('ConfirmController', '_startSmsReception', 'failed');
        });
      }
    };

    $scope._stopSmsReception = function () {
      ga_storage._trackEvent('ConfirmController', '_stopSmsReception', 'called');
      if ($scope.smsInboxPlugin) {
        $scope.smsInboxPlugin.stopReception(function () {
          ga_storage._trackEvent('ConfirmController', '_stopSmsReception', 'success');
          $log.debug('ConfirmController.stopReception success');
        }, function () {
          $log.debug('ConfirmController.stopReception failed');
          ga_storage._trackEvent('ConfirmController', '_stopSmsReception', 'failed');
        });
      }
    };

    $scope.data = {
      phone: null,
      confirmationNumber: null
    };
    $scope.confirmForm = {};

    $scope.sending = false;
    $scope.resendSending = false;

    $scope.$on('$ionicView.enter', function () {
      $log.debug('ConfirmController.$ionicView.enter called');
      $scope.data = {phone: null, confirmationNumber: null};
      $scope.sending = false;
      $scope.resendSending = false;
      $scope.data.phone = AuthenticationService.lastUsedPhone;
      if($rootScope.smsSupported){
        $scope._startSmsReception();
      }
    });

    $scope.$on('$ionicView.leave', function () {
      if($rootScope.smsSupported){
        $scope._stopSmsReception();
      }
    });

    $scope._signIn = function () {
      if (!NetworkHelper.validateNetwork()) {
        return;
      }

      var confirmationCode;
      if ($scope.data.confirmationNumber.toLowerCase().indexOf('br-') !== -1) {
        confirmationCode = $scope._extractConfirmationCode($scope.data.confirmationNumber);
      } else {
        confirmationCode = $scope.data.confirmationNumber;
      }

      confirmationCode = $scope.data.confirmationNumber;
      // make sure we have confirmation number
      if (!confirmationCode || _.isUndefined(confirmationCode)) {
        $ionicPopup.alert({
          title: $translate.instant('error_generic'),
          template: $translate.instant('error_wrong_code')
        });
        return;
      }

      $scope.sending = true;

      // make sure we have phone
      //var phone = $scope.data.phone;
      var phone = $scope.data.phone;
      if (phone && !_.isUndefined(phone)) {
        $ionicLoading.show();
        AuthenticationService.signInWithPhone(phone, confirmationCode, ConfigurationService.getCurrentMerchantId(), function (result) {
          $ionicLoading.hide();
          if (result && result.status === 'ok') {
            if($rootScope.smsSupported){
              $scope._stopSmsReception();
            }
            AuthenticationService.onLoginDone();
          } else {
            $scope.handleErrorResponse(result);
          }
        }, function (reason) {
          $ionicLoading.hide();
          $scope.handleErrorResponse(reason);
        });
      } else {
        $scope.sending = false;
        $ionicPopup.alert({
          title: $translate.instant('error_login_failed'),
          template: $translate.instant('error_invalid_phone')
        });
      }
    };

    $scope._automaticSignIn = function (code) {
      ga_storage._trackEvent('ConfirmController', '_automaticSignIn', 'called');
      $log.debug('ConfirmController._automaticSignIn');
      $scope.data.confirmationNumber = code;
      $scope._signIn();
    };

    $scope._extractConfirmationCode = function (smsMessage) {
      var result = /BR-(\w+)$/gi.exec(smsMessage);
      if(_.isArray(result)){
        return result[1];
      }

      return false;
    };

    $scope.handleSignInClick = function () {
      ga_storage._trackEvent('ConfirmController', 'handleSignInClick', 'click');
      $log.debug('ConfirmController.handleSignInClick');
      $scope._signIn();
    };

    $scope.handleResendConfirmClicked = function () {
      ga_storage._trackEvent('ConfirmController', 'handleResendConfirmClicked', 'click');
      $log.debug('ConfirmController.handleResendConfirmClicked');

      if (!NetworkHelper.validateNetwork()) {
        return;
      }

      var phone = $scope.data.phone;
      if (phone && !_.isUndefined(phone)) {
        $ionicLoading.show();
        $scope.resendSending = true;

        //ga_storage._trackEvent('ConfirmController', 'handleResendConfirmClicked', 'click', 1);
        AuthenticationService.confirm(phone, ConfigurationService.getCurrentMerchantId()).then(function (result) {
          $ionicLoading.hide();
          if (result && result.status === 'ok') {
            $scope.resendSending = false;
            $ionicPopup.alert({template: $translate.instant('dialog_wait_for_confirmation_title')});
          } else {
            $scope.handleErrorResponse(result);
          }
        }, function (result) {
          $ionicLoading.hide();
          $scope.handleErrorResponse(result);
        });
      } else {
        $scope.resendSending = false;
        $ionicPopup.alert({
          title: $translate.instant('error_login_failed'),
          template: $translate.instant('error_invalid_phone')
        });
      }
    };

    $scope.handleErrorResponse = function (result) {
      $scope.sending = false;
      $scope.resendSending = false;

      if (result && result.message) {
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: result.message});
      } else if (result && result.status && result.status === 429) {
        var message = result.data ? result.data : $translate.instant('error_too_many_requests');
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: message});
      }
      else {
        $ionicPopup.alert({title: $translate.instant('error_login_failed')});
      }
    };

    $scope.handleBackClicked = function () {
      ga_storage._trackEvent('ConfirmController', 'handleBackClicked', 'click');
      $log.debug('ConfirmController.handleBackClicked');
      $state.go('login');
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('PasswordRemindController', function ($scope, $state, $log, $translate, $ionicPopup, $rootScope, $timeout,
                                                    AuthenticationService, ConfigurationService,
                                                    vcRecaptchaService, RECAPTCHA_SITE_KEY) {
    ga_storage._trackPageview('PasswordRemind');
    $scope.user = {};
    $scope.sending = false;

    $scope.show_captcha = false;

    $scope.recaptcha = null;
    $scope.widgetId = null;
    $scope.model = {
      key: RECAPTCHA_SITE_KEY,
      sToken : ''
    };


    $scope.setRecaptcha = function (recaptcha) {
      $log.debug('PasswordRemindController.recaptcha set');
      $scope.recaptcha = recaptcha;
    };
    $scope.setWidgetId = function (widgetId) {
      $log.debug('PasswordRemindController.widget set');
      $scope.widgetId = widgetId;

      if ($scope.show_captcha){
        vcRecaptchaService.reload($scope.widgetId);

        $timeout(function(){
          $scope.$apply();
        },1);
      }
    };
    $scope.cbExpiration = function() {
      $log.debug('PasswordRemindController.captcha expired');
      $scope.recaptcha = null;
    };

    $scope.captchaRequired = function (securedToken) {
      $scope.show_captcha = true;
      $scope.model.sToken = securedToken;

      if ($scope.widgetId){
        $log.debug('RemindController.captcha required');
        vcRecaptchaService.reload($scope.widgetId);

        $timeout(function(){
          $scope.$apply();
        },1);
      } else {
        $log.debug('RemindController.captcha required, but no widget id');
      }
    };

    $scope.handleBackButtonClick = function () {
      ga_storage._trackEvent('PasswordRemindController', 'handleBackButtonClick', 'click');
      $log.debug('PasswordRemindController.handleBackButtonClick');
      $state.go('login');
    };

    $scope.handleRemindButtonClick = function () {
      $scope.sending = true;
      ga_storage._trackEvent('PasswordRemindController', 'handleRemindButtonClick', 'click');
      $log.debug('PasswordRemindController.handleRemindButtonClick');
      AuthenticationService.remind($scope.user.email, $rootScope.appName, ConfigurationService.getCurrentMerchantId(), $scope.show_captcha ? vcRecaptchaService.getResponse() : '').then(function (result) {
        $scope.sending = false;
        if (result && result.status === 'ok') {
          $log.debug('RemindController.remind succeeded');
          $ionicPopup.alert({template: $translate.instant('resend_password_success'), okText: $translate.instant('ok')}).then(function(){
            $state.go('login');
          });
        } else {
          $log.error('RemindController.remind failed');

          $scope.handleErrorResponse(result);
        }
      }, function (result) {
        $log.error('RemindController.remind error: ' +JSON.stringify(result));
        $scope.sending = false;

        if (result.recaptcha_stoken && result.recaptcha_stoken.length > 0){
          $scope.captchaRequired(result.recaptcha_stoken);
        }

        $scope.handleErrorResponse(result);
      });
    };

    $scope.handleErrorResponse = function (result) {
      $scope.sending = false;
      if (result && result.message) {
        $ionicPopup.alert({title: $translate.instant('error_generic'), template: result.message, okText: $translate.instant('ok')});
      } else if (result && result.status && result.status === 429){
        var message = result.data ? result.data : $translate.instant('error_too_many_requests');
        $ionicPopup.alert({title: $translate.instant('error_login_failed'), template: message, okText: $translate.instant('ok')});
      }
      else {
        $ionicPopup.alert({title: $translate.instant('error_generic'), okText: $translate.instant('ok')});
      }
    };

    $scope.$on('$ionicView.enter', function () {
      $scope.user = {};
      $scope.sending = false;
      $log.debug('RemindController.$ionicView.enter called');
    });
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('CategoriesController', function ($scope, $state, $ionicPopup, $translate, $ionicLoading, $log,
                                                $ionicSideMenuDelegate, CategoriesService, AuthenticationService,
                                                localStorageService, ConfigurationService, DiscountsService,
                                                ProductAddToCartService, $stateParams, CartService) {
    ga_storage._trackPageview('Categories');
    $scope.showSearch = false;
    $scope.query = {searchQuery: ''};

    $scope.waterfall = ConfigurationService.getUiConfiguration().waterfall_view;
    $scope.discounts = null;
    $scope.loading = false;

    $scope._handleIsLoggedInChanged = function(){
      $log.debug('CategoriesController.isLoggedInChanged called');
      if (AuthenticationService.isLoggedIn) {
        if (!$scope.initOnce){
          $log.debug('CategoriesController.isLoggedInChanged init once = true');
          $scope.initOnce = true;
          $scope._loadData();
        }
      }
    };

    $scope.$watch(AuthenticationService.isLoggedIn, $scope._handleIsLoggedInChanged);


    $scope._handleIonicViewEnter = function(){
      $log.debug('CategoriesController.$ionicView.enter called');
      if ($stateParams.rebuild){
        $log.debug('CategoriesController rebuilding catalog');
        $scope._loadData(null, true);
      }
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);

    $scope._processDiscountsIfNecessary = function (result) {
      if ($scope.waterfall && result.length > 0 && result[0] === DiscountsService.getDiscountsCategory()){
        var discounts = result[0];
        if (discounts.products && discounts.products.length > 0){
          $scope.discounts = discounts;
        }
      }
    };

    $scope._loadData = function (callback, shouldForce) {
      $log.debug('CategoriesController._loadData called');
      if($scope.loading){
        return;
      }

      $scope.loading = true;
      if (shouldForce !== false){
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "loading" | translate}}</p>'
        });
      }

      CategoriesService.buildCatalog(function (result) {
        $ionicLoading.hide();
        $scope.loading = false;
        if (result) {
          $log.debug('CategoriesController._loadData returned');

          $scope._processDiscountsIfNecessary(result);
          $scope.categories = result;
        } else {
          $log.error('CategoriesController._loadData failed');
          $ionicPopup.alert({template: $translate.instant('error_failed_loading_catalog'), okText: $translate.instant('ok')});
        }

        if (callback) {
          callback();
        }
      }, shouldForce, shouldForce === false);
    };

    $scope.doRefresh = function () {
      if($scope.loading){
        return;
      }
      ga_storage._trackEvent('CategoriesController', 'doRefresh', 'click');
      $log.debug('CategoriesController.doRefresh called');
      $scope._loadData(function () {
        $scope.$broadcast('scroll.refreshComplete');
      }, true);
    };

    $scope.handleCategoryClick = function (category) {
      ga_storage._trackEvent('CategoriesController', 'handleCategoryClick', 'click');
      $log.debug('CategoriesController.handleCategoryClick clicked with categoryId: ' + category.id);
      $state.go('category', {category_id: category.id});
    };

    $scope.handleProductClicked = function (product) {
      ga_storage._trackEvent('CategoriesController', 'handleProductClicked', 'click');
      $log.debug('CategoriesController.handleProductClicked productId: ' + product.id);
      ProductAddToCartService.open(product);
    };

    $scope.toggleLeft = function () {
      ga_storage._trackEvent('CategoriesController', 'toggleLeft', 'click');
      $log.debug('CategoriesController.toggleLeft');
      $ionicSideMenuDelegate.toggleLeft();
    };

    $scope.handleSearchButtonClick = function () {
      ga_storage._trackEvent('CategoriesController', 'handleSearchButtonClick', 'click');
      $scope.query = {searchQuery: ''};
      $scope.showSearch = !$scope.showSearch;
    };

    $scope.$on('$ionicView.enter', function(){
      $scope.$broadcast('cartCountUpdated', CartService._items.length);
    });
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('CategoryController', function ($scope, $state, $ionicModal, AuthenticationService,
                                              $stateParams, CategoriesService, $ionicPopup, $translate,
                                              $ionicLoading, ProductAddToCartService, $log, CartService,
                                              ConfigurationService) {
    ga_storage._trackPageview('Category');
    $scope.showSearch = false;
    $scope.query = {searchQuery: ''};
    $scope.handleBackClick = function () {
      $log.debug('CategoryController.handleBackClick');
      $state.go('categories');
    };

    $scope.waterfall = ConfigurationService.getUiConfiguration().waterfall_view;

    $scope._handleIsLoggedInChange =  function () {
      if (AuthenticationService.isLoggedIn) {
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "loading" | translate}}</p>'
        });
        $scope._loadData();
      }
    };

    $scope.$watch(AuthenticationService.isLoggedIn, $scope._handleIsLoggedInChange);

    $scope._loadData = function (callback) {
      $log.debug('CategoryController._loadData');
      var categoryId = $stateParams.category_id;

      CategoriesService.getCategoryProducts(categoryId, function (result) {
        $ionicLoading.hide();
        if (result) {
          $scope.category = result;
        } else {
          $ionicPopup.alert({title: $translate.instant('error_generic'), template: $translate.instant('error_showing_category')});
        }

        if (callback) {
          callback();
        }
      });
    };

    $scope.doRefresh = function () {
      ga_storage._trackEvent('CategoryController', 'doRefresh', 'click');
      $log.debug('CategoryController.doRefresh called');
      $scope._loadData(function () {
        $scope.$broadcast('scroll.refreshComplete');
      });
    };

    $scope.handleProductClicked = function (product) {
      ga_storage._trackEvent('CategoryController', 'handleProductClicked', 'click');
      $log.debug('CategoryController.handleProductClicked productId: ' + product.id);
      ProductAddToCartService.open(product);
    };

    $scope.handleSearchButtonClick = function () {
      ga_storage._trackEvent('CategoryController', 'handleSearchButtonClick', 'click');
      $scope.showSearch = !$scope.showSearch;
      $scope.query = {searchQuery: ''};
    };

    $scope.getCartStringForProduct = function(product){
      return CartService.getStringForCart(product);
    };

    $scope.$on('$ionicView.enter', function(){
      $scope.$broadcast('cartCountUpdated', CartService._items.length);
    });
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('CART_CONSTANTS', {
    'TEST_ORDER_KEY': 'test_order',
    'INVALID_NONCE_RC' : 2
  })
  .controller('CartController', function ($scope, $state, CartService, AuthenticationService, $log, ProductAddToCartService,
                                          DistributorsService, OrderService, ConfigurationService, $ionicLoading,
                                          localStorageService, $ionicPopup, $translate, $q, NetworkHelper, LocationUtil,
                                          CART_CONSTANTS, $timeout, MERCHANT_CONFIG, ConfirmFoundLocationService,
                                          DynamicLocationService) {

    $scope.submitDisabled = false;

    ga_storage._trackPageview('Cart');

    $scope.data = {urgent: false, test: false, comment: null};
    $scope.distributor = null;
    $scope.sending = false;

    $scope.initConfig = function(){
      $scope.config = {
        allow_urgent_delivery: ConfigurationService.allowUrgentDelivery(),
        enable_dynamic_address: ConfigurationService.enableDynamicAddress(),
        show_wholesalers: DistributorsService.hasDistributors() && ConfigurationService.showWholesalers(),
        show_test : localStorageService.get(CART_CONSTANTS.TEST_ORDER_KEY),
        enable_find_me : ConfigurationService.enableFindMe(),
        current_delivery_fee: ConfigurationService.getNormalDeliveryPrice()
      };
    };

    $scope.initConfig();

    $scope.handleBackClick = function () {
      ga_storage._trackEvent('CartController', 'handleBackClick', 'click');
      $log.debug('CartController.handleBackClick called');
      $state.go('categories');
    };

    $scope._handleIonicViewEnter = function(){
      $log.debug('CartController.$ionicView.enter called');
      if (AuthenticationService.isLoggedIn) {
        //reset some stuff
        $scope.sending = false;
        $scope.data = {urgent: false, test: false, comment: null};
        $scope.submitDisabled = false;

        $scope.products = CartService.currentCart();
        $scope.selectedLocation = $scope._getSelectedLocation();
        $scope.customerAddress = $scope._getCustomerAddress();
        $scope.customerLocation = $scope._getCustomerLatLng();

        $scope.initConfig();

        $scope.$apply();

        $scope._initDistributors();
        AuthenticationService.requestNonce();

        $scope.$broadcast('cartCountUpdated', CartService._items.length);
      }
    };

    $scope._handleIsLoggedIn = function(){
      if (AuthenticationService.isLoggedIn) {
        $scope.products = CartService.currentCart();
        $scope.selectedLocation = $scope._getSelectedLocation();
        $scope.customerAddress = $scope._getCustomerAddress();
        $scope.customerLocation = $scope._getCustomerLatLng();
        CartService.setCurrentDestinationLocation($scope.customerLocation);
        $scope._setDefaultDistributor();
      }
    };

    $scope._initDistributors = function(){
      if(CartService._selectedDistributor){
        $scope.distributor = CartService._selectedDistributor;
      }

      DistributorsService.getDistributors(function (distributors) {
        $scope.config.show_wholesalers = distributors && distributors.length && ConfigurationService.showWholesalers();
      }, $scope.customerLocation);
    };

    $scope._handleUrgentChanged = function(newValue, oldValue){
      if(newValue === oldValue){
        return;
      }

      if (newValue){
        $scope.validateWorkingHoursForUrgent();
      }

      CartService.updateUrgency(newValue);
      $scope.config.current_delivery_fee = CartService.getExtraDeliveryPrice();
    };

    $scope.handleOrderCompletedClick = function (event, ignoreLocation) {
      $log.debug('CartController.cartOrderCompletedClicked called');

      if (!NetworkHelper.validateNetwork()){
        return;
      }

      $scope.submitDisabled = true;

      if($scope.sending){
        $log.debug('CartController.cartOrderCompletedClicked called but there is a creation in process');
        return;
      }

      if(!CartService.currentCart() || CartService.currentCart().length === 0){
        $ionicPopup.alert({title: $translate.instant('error_generic'), template: $translate.instant('error_cart_empty'), okText: $translate.instant('ok')});
        return;
      }

      // in case we had no location - ask the customer if to still make the delivery
      if ((!$scope.customerLocation || !$scope.customerLocation.lat || !$scope.customerLocation.lng) && !ignoreLocation){
        $ionicPopup.confirm({
          template: $translate.instant('no_location_in_order'),
          scope: $scope,
          cancelText: $translate.instant('cancel'),
          okText: $translate.instant('ok')
        }).then(function (res) {
          if (res) {
            $log.debug('CartController order created with no location');
            $scope.handleOrderCompletedClick(null, true);
          }
        });
        return;
      }

      $scope.sending = true;
      $ionicLoading.show({
        template: '<ion-spinner></ion-spinner><p>{{:: "submitting_order" | translate}}</p>'
      });

      CartService.store();

      if(ConfigurationService.forceStripePayments()){
        OrderService.createCharge(CartService.getIntForCharge(), $translate.instant('CHECKOUT_VIEW.CHARGE_DESCRIPTION')).then(function (result) {
          $log.debug('CartController OrderService.createCharge success' + result);
          $scope._getNonceAndCreateOrder();
        }, function (reason) {
          $scope._closeOrderTransaction();
          $log.error('CartController OrderService.createCharge failed' + reason);
          $ionicPopup.alert({title: $translate.instant('error_generic'), template: reason.message, okText: $translate.instant('ok')});
        });
      } else{
        OrderService.calculatePrice(CartService.currentCart(), $scope.data.urgent, $scope._getDistributor())
          .then($scope.onPriceRetrieved, $scope.onFailedToRetrievePrice);
      }
    };

    $scope.onPriceRetrieved = function(result){
      if (result && !_.isUndefined(result.total_price)){
        var clientPrice = CartService.getTotalInCart();
        var serverPrice = result.total_price;
        if (serverPrice === clientPrice){
          $scope._getNonceAndCreateOrder();
        } else {
          $ionicLoading.hide();
          $ionicPopup.confirm({
            title: $translate.instant('price_mismatch'),
            template: '<div> {{:: "old_price" | translate}} ' + clientPrice + '</div>' +
                      '<div> {{:: "new_price" | translate}} ' + serverPrice + '</div>' +
                      '<div> {{:: "continue_with_order_creation" | translate}}</div>',
            scope: $scope,
            cancelText: $translate.instant('cancel'),
            okText: $translate.instant('ok')
          }).then(function(res){
            if (res){
              $ionicLoading.show();
              $scope._getNonceAndCreateOrder();
            } else {
              $scope._closeOrderTransaction();
            }
          });
        }
      } else {
        $scope._closeOrderTransaction();
      }
    };

    $scope.onFailedToRetrievePrice = function(){
      $log.debug('CartController. failed to retrieve price');
      $scope._getNonceAndCreateOrder();
    };

    $scope._getNonceAndCreateOrder = function(){
      AuthenticationService.requestNonce().then($scope._onNonceRetrieved, $scope._onNonceError);
    };

    $scope.createOrderWithNonce = function(nonce){
      OrderService.createOrder(AuthenticationService.currentUser(), CartService.currentCart(), $scope.data.urgent,
        $scope._getDistributor(), $scope.customerAddress, $scope.customerLocation, $scope.data.test, nonce,
        $scope.data.comment, $scope._getExtras())
        .then($scope.onOrderCreated, $scope.onOrderCreationFailed);
    };

    $scope._getExtras = function(){
      if (ConfigurationService.enableLocationBasedCatalog()){
        return {team_ids : _.map(DistributorsService.getDistributors(), 'id')};
      }
      return null;
    };

    $scope._getDistributor = function(){
      return ConfigurationService.enableLocationBasedCatalog() ? null : $scope.distributor;
    };

    $scope._onNonceRetrieved = function(nonce){
      if (nonce){
        $scope.createOrderWithNonce(nonce);
      } else {
        $scope._onNonceError();
      }
    };

    $scope._onNonceError = function() {
      $scope._closeOrderTransaction();
      $log.error('CartController order create failed - failed to obtain nonce');
      $ionicPopup.alert({title: $translate.instant('error_message_order_failed'), okText: $translate.instant('ok')});
    };

    $scope.onOrderCreated = function(order){
      $log.debug('CartController order created orderId: ' + order.id);
      $scope._closeOrderTransaction();
      AuthenticationService.clearNonce();
      $state.go('order_completed');
    };

    $scope._retriedNonceOnce = false;
    $scope.onOrderCreationFailed = function(result){
      if (result.rc && result.rc === CART_CONSTANTS.INVALID_NONCE_RC && !$scope._retriedNonceOnce){
        $scope._retriedNonceOnce = true;
        $scope._getNonceAndCreateOrder();
      } else {
        $scope._closeOrderTransaction();
        var message = result.message ? result.message : '';
        $log.error('CartController order create failed message: ' + message);
        $ionicPopup.alert({title: $translate.instant('error_message_order_failed'), template: message, okText: $translate.instant('ok')});
      }
    };

    $scope._closeOrderTransaction = function(){
      $scope.sending = false;
      $scope._retriedNonceOnce = false;
      $scope.submitDisabled = false;
      $ionicLoading.hide();
    };

    $scope._getSelectedLocation = function () {
      if ($scope.selectedLocation && $scope.selectedLocation.formatted_address) {
        return $scope.selectedLocation;
      }

      return {formatted_address: $scope._getCustomerAddress()};
    };

    $scope._getCustomerAddress = function(){
      var currentAddress = DynamicLocationService.getCurrentAddress();
      return currentAddress ? currentAddress : AuthenticationService.currentUser().address;
    };

    $scope._getCustomerLatLng = function(){
      var currentLocation = DynamicLocationService.getCurrentLocation();
      return currentLocation ? currentLocation : AuthenticationService.getLastUserLocation();
    };

    $scope.handleSelectDistributor = function () {
      ga_storage._trackEvent('CartController', 'handleSelectDistributor', 'click');
      $log.debug('CartController.handleSelectDistributor called');
      $state.go('select_distributor');
    };

    $scope.handleEditClick = function ($event, product) {
      ga_storage._trackEvent('CartController', 'handleEditClick', 'click');
      $log.debug('CartController.handleEditClick called');
      ProductAddToCartService.open(product.product, true);
    };

    $scope.handleRemoveClick = function ($event, product) {
      ga_storage._trackEvent('CartController', 'handleRemoveClick', 'click');
      $log.debug('CartController.handleRemoveClick called');
      $ionicPopup.confirm({
        title: $translate.instant('remove_item'),
        template: $translate.instant('are_you_sure'),
        scope: $scope,
        cancelText: $translate.instant('cancel'),
        okText: $translate.instant('ok')
      }).then(function (res) {
        if (res) {
          $log.debug('CartController removing item from cart');
          CartService.removeFromCart(product);
        }
      });
    };

    $scope._setDefaultDistributor = function () {
      // first try to obtain by default from server if exists.
      var extras = AuthenticationService.currentUser().extras;
      if (extras && extras.mlp_code) {
        $scope.distributor = DistributorsService.getDistributorByExternalId(extras.mlp_code);
      }
      // if we didn't have a default we obtain the nearest distributor
      if (!$scope.distributor) {
        DistributorsService.getNearestDistributor($scope.customerLocation, function (result) {
          $scope.distributor = result;
        });
      }
    };

    $scope.addressSelectedCallback = function (callback) {
      if (callback.item) {

        if($scope.locationSelection){
          $scope.locationSelection.close();
        }

        $scope.selectedLocation = {formatted_address: callback.item.formatted_address};

        if(callback.item.geometry && callback.item.geometry.location){
          $scope.customerLocation = {
            lat: callback.item.geometry.location.lat(),
            lng: callback.item.geometry.location.lng()
          };
        } else {
          $scope.customerLocation = null;
          $log.error('user address not geocoded');
        }

        $scope.customerAddress = callback.item.formatted_address;
        CartService.setCurrentDestinationLocation($scope.customerLocation);

        DynamicLocationService.setCurrentAddress($scope.customerAddress);
        DynamicLocationService.setCurrentLocation($scope.customerLocation);
      } else {
        $log.warn('CartController.addressSelectedCallback callback.item is null');
      }
    };

    $scope.validateWorkingHoursForUrgent = function(){
      if (ConfigurationService.isOpenAlways()){
        $log.debug('CartController: open all day');
        return;
      }
      var now = new Date();
      var currentHour = now.getHours();
      var currentDay = now.getDay();

      var closing = ConfigurationService.getClosingHourInDay(currentDay);
      var opening = ConfigurationService.getOpeningHourInDay(currentDay);

      if (opening && closing){
        opening = new Date('1/1/2010 ' + opening).getHours();
        closing = new Date('1/1/2010 ' + closing).getHours();

        if (currentHour >= opening && currentHour <= closing) {
          $log.debug('CartController: within working hours');
          return;
        }
      }

      $log.debug('CartController: not within working hours');
      $scope.data.urgent = false;
      if (!$scope.showingAlert) {
        $scope.showingAlert = true;
        $ionicPopup.alert({
          title: $translate.instant('error_generic'),
          template: $translate.instant('out_of_working_hours'),
          okText: $translate.instant('ok')
        }).then(function(){
          $scope.showingAlert = false;
        });
      }
    };

    $scope.addressDataCallbackMethod = function (query) {
      return LocationUtil.geocodeAddress(query);
    };

    $scope.$watch(AuthenticationService.isLoggedIn, $scope._handleIsLoggedIn);

    $scope.$watch('data.urgent', $scope._handleUrgentChanged);

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);

    $scope.$on('cartUpdated', function () {
      $log.debug('CartController.cartUpdated called');
      $scope.products = CartService.currentCart();
    });

    $scope.$on('selectedDistributorUpdated', function (event, distributor) {
      $log.debug('CartController.selectedDistributorUpdated called');
      $scope.distributor = distributor;
    });

    $scope.$on('cartOrderCompletedClicked', $scope.handleOrderCompletedClick);

    $scope.dtCount = 0;
    $scope.magicTapNumber = 5;
    $scope.doubleTap = function () {
      $log.debug('double tap');
      $scope.dtCount++;
      if ($scope.dtCount % $scope.magicTapNumber === 0) {

        if (_.isUndefined($scope.config.show_test) || _.isNull($scope.config.show_test)){
          $scope.config.show_test = false;
        }

        $scope.config.show_test = !$scope.config.show_test;
        $timeout(function(){
          $scope.$apply();
        },1);
        localStorageService.set(CART_CONSTANTS.TEST_ORDER_KEY, $scope.config.show_test);
        $log.debug('CartController: show test changed to ' + $scope.config.show_test);
      }
    };

    $scope.handleFindMeButtonClicked = function(){
      ga_storage._trackEvent('CartController', 'handleFindMeButtonClicked', 'click');

      $ionicPopup.confirm({
        title: $translate.instant('determine_geo_location_title'),
        template: $translate.instant('determine_geo_location_question'),
        cancelText: $translate.instant('cancel'),
        okText: $translate.instant('ok')
      }).then(function(res) {
        if(res) {
          $ionicLoading.show({
            template: '<ion-spinner></ion-spinner><p>{{:: "locating" | translate}}</p>'
          });

          LocationUtil.locateMe(
            $scope._onCustomerLocatedSuccessfully,
            $scope._onCustomerLocatingFailed,
            {maximumAge: 30000, timeout: 10000, enableHighAccuracy: true});
        } else {

        }
      });
    };

    $scope._onCustomerLocatedSuccessfully = function(position){
      ga_storage._trackEvent('CartController', 'geo_location_user', 'event');
      $ionicLoading.hide();
      ConfirmFoundLocationService.open(position).then(function(){
        $scope.customerLocation = {
          lat: position.coords.latitude,
          lng: position.coords.longitude,
          formatted_address: ''
        };

        $scope.selectedLocation = $scope.customerLocation;
        $scope.customerAddress = '';

        CartService.setCurrentDestinationLocation($scope.customerLocation);
        DynamicLocationService.setCurrentAddress($scope.customerAddress);
        DynamicLocationService.setCurrentLocation($scope.customerLocation);
      }, function(){

      });

      // LocationUtil.reverseGeocode({lat: position.coords.latitude, lng: position.coords.longitude});
    };

    $scope._onCustomerLocatingFailed = function (error) {
      $log.error('CartController navigator.geolocation.getCurrentPosition failed' + error);
      $ionicLoading.hide();
      $ionicPopup.alert({
        template: $translate.instant('error_getting_location'),
        okText: $translate.instant('ok')
      });
    };

  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('RESULT_CODES', {
    'NO_SERVICE' : 6,
    'INVALID_PASSWORD' : 7
  })
  .controller('RegisterController', function ($scope, $state, $ionicPopup, $ionicLoading, $translate, $log, $stateParams,
                                              AuthenticationService, NetworkHelper, $q, CountryCodeExtractor,
                                              ConfigurationService, RESULT_CODES, LocationUtil) {

    ga_storage._trackPageview('Register');
    $scope.user = {};

    $scope.edit = $stateParams.edit;
    $scope.sending = false;

    $scope.config = {
      activationCode : !$scope.edit && ConfigurationService.enableActivationCode(),
      requireCompanyName: ConfigurationService.requireCompanyName(),
      requirePhone: ConfigurationService.requirePhoneOnSignUp()
    };

    $scope.needsCreditCard = ConfigurationService.forceStripePayments();

    $scope.handleBackButtonClick = function () {
      ga_storage._trackEvent('RegisterController', 'handleBackButtonClick', 'click');
      $log.debug('RegisterController.handleBackButtonClick');
      if ($scope.edit) {
        $state.go('categories');
      } else {
        $state.go('login');
      }
    };

    $scope.handleNextButtonClick = function(){
      ga_storage._trackEvent('RegisterController', 'handleNextButtonClick', 'click');
      $log.debug('RegisterController.handleNextButtonClick');

      if (!$scope.validateForm()) {
        return;
      } else if (!NetworkHelper.validateNetwork()){
        return;
      }

      AuthenticationService.storeUserTemporarly($scope.user);

      $state.go('credit_card');
    };

    $scope.handleDoneButtonClick = function () {
      ga_storage._trackEvent('RegisterController', 'handleDoneButtonClick', 'click');
      $log.debug('RegisterController.handleDoneButtonClick');

      if (!$scope.validateForm()) {
        return;
      } else if (!NetworkHelper.validateNetwork()){
        return;
      }

      $scope.sending = true;
      $ionicLoading.show({
        template: '<ion-spinner></ion-spinner><p>{{:: "please_wait" | translate}}</p>'
      });

      if ($scope.edit) {
        AuthenticationService.updateProfile($scope._getUpdateParams()).then(function (result) {
          $ionicLoading.hide();
          $scope.sending = false;
          if (result && result.status === 'ok') {
            $scope._updateData(result.customer);
            $ionicPopup.alert({template: $translate.instant('update_successfully'), okText: $translate.instant('ok')});
          } else {
            $scope.handleErrorResponse(result);
          }
        });
      } else {
        AuthenticationService.signUp($scope.user, function (result) {
          $scope._handleSignUpResponse(result);
        });
      }
    };

    $scope._handleSignUpResponse = function(result){
      $ionicLoading.hide();
      if (result && result.status === 'ok') {
        $state.go('confirm');
      } else {
        $scope.sending = false;
        if (result && result.rc && result.rc === RESULT_CODES.NO_SERVICE){
          $state.go('no_service');
        } else if (result && result.rc && result.rc === RESULT_CODES.INVALID_PASSWORD){
          $ionicPopup.alert({template: result.message, okText: $translate.instant('ok')});
        } else {
          $scope.handleErrorResponse(result);
        }
      }
    };

    $scope._updateData = function(customer){
      $scope.user = angular.copy(customer);
      $scope.selectedLocation = {formatted_address: $scope.user.address};
    };

    $scope.$watch(AuthenticationService.isLoggedIn, function () {
      if (AuthenticationService.isLoggedIn && $scope.edit) {
        $scope._updateData(AuthenticationService.currentUser());
      }
    });

    $scope.validateForm = function () {
      // form validation
      if (!$scope.user || _.isUndefined($scope.user)) {
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm missing params');
        return false;
      }

      var requirePhone = ConfigurationService.requirePhoneOnSignUp();
      var phone = $scope.user.phone;

      // if phone is required then make sure it is used and valid
      if (requirePhone){
        if (!$scope._applyPhoneValidation(phone, CountryCodeExtractor.getCountryCode())){
          return false;
        }
      }

      // we don't have phone and not requiring it, make sure we have email and password
      var email = $scope.user.email;
      var password = $scope.user.password;
      if (!phone || _.isUndefined(phone)) {
        if (!$scope._applyCredentialValidation(email, password)){
          return false;
        }
      }

      // in any case if we have password - validate it.
      if (password && !$scope._isValidPassword(password, $scope.user.password_validation)){
        return false;
      }

      // validate other required fields
      if (!$scope.user.name || _.isUndefined($scope.user.name)) {
        $ionicPopup.alert({template: $translate.instant('error_required_username'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm name is required');
        return false;
      }
      if (!$scope.user.address || _.isUndefined($scope.user.address)) {
        $ionicPopup.alert({template: $translate.instant('error_required_address'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm address is required');
        return false;
      }
      if($scope.config.requireCompanyName){
        if (!$scope.user.extras.company_name || _.isUndefined($scope.user.extras.company_name)) {
          $ionicPopup.alert({template: $translate.instant('error_required_company'), okText: $translate.instant('ok')});
          $log.error('RegisterController.validateForm company is required');
          return false;
        }
      }

      return true;
    };

    $scope._getUpdateParams = function () {
      var user = AuthenticationService.currentUser();
      var params = {phone: user.phone};

      if ($scope.user.phone && $scope.user.phone !== user.phone) {
        params.new_phone = $scope.user.phone;
      }

      if ($scope.user.email && $scope.user.email !== user.email) {
        params.new_email = $scope.user.email;
      }
      if ($scope.user.password && $scope.user.password !== user.password) {
        params.new_password = $scope.user.password;
      }
      if($scope.config.requireCompanyName) {
        if ($scope.user.extras.company_name && $scope.user.extras.company_name !== user.extras.company_name) {
          params.company_name = $scope.user.extras.company_name;
        }
      }
      if ($scope.user.address && $scope.user.address !== user.address) {
        params.address = $scope.user.address;
      }
      if ($scope.user.lat !== user.lat) {
        params.lat = $scope.user.lat;
      }
      if ($scope.user.lng !== user.lng) {
        params.lng = $scope.user.lng;
      }
      if ($scope.user.name && $scope.user.name !== user.name) {
        params.name = $scope.user.name;
      }
      return params;
    };

    $scope.handleErrorResponse = function (result) {
      if (result && result.message) {
        $ionicPopup.alert({title: $translate.instant('error_generic'), template: result.message, okText: $translate.instant('ok')});
      } else {
        $ionicPopup.alert({title: $translate.instant('error_generic'), okText: $translate.instant('ok')});
      }
    };

    $scope.selectedLocation = null;
    $scope.addressSelectedCallback = function (callback) {
      $scope.user.address = callback.item.formatted_address;
      if (callback.item.geometry && callback.item.geometry.location){
        $scope.user.lat = callback.item.geometry.location.lat();
        $scope.user.lng = callback.item.geometry.location.lng();
      } else {
        $scope.user.lat = null;
        $scope.user.lng = null;
        $log.error('user address not geocoded');
      }
    };

    $scope.addressDataCallbackMethod = function (query) {
      return LocationUtil.geocodeAddress(query);
    };

    $scope._isValidEmail = function(email){
      var re = /[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/i;
      return re.test(email);
    };

    $scope._isValidPassword = function(password, passwordValidation){
      if (!password){
        return false;
      }

      if (password.length < ConfigurationService.getMinPasswordChars()){
        $ionicPopup.alert({template: $translate.instant('error_invalid_password'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm password too short');
        return false;
      }

      if (!passwordValidation){
        $ionicPopup.alert({template: $translate.instant('error_password_validation_required'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm no password validation');
        return false;
      }

      if (passwordValidation !== password){
        $ionicPopup.alert({template: $translate.instant('error_password_validation_mismatch'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm passwords do not match');
        return false;
      }

      return true;
    };

    $scope._applyPhoneValidation = function(phone, countryCode){
      if (!phone || _.isUndefined(phone)) {
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm phone is required');
        return false;
      } else if (!countryCode || _.isUndefined(countryCode)){
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm invalid country code');
        return false;
      } else if (!isValidNumber(phone, countryCode)){
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm invalid phone');
        return false;
      } else {
        $scope.user.phone = formatE164(countryCode, phone);
        return true;
      }
    };

    $scope._applyCredentialValidation = function(email, password){
      if (!email || _.isUndefined(email)){
        $ionicPopup.alert({template: $translate.instant('error_missing_email_or_phone'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm no email or phone');
        return false;
      } else if (!$scope._isValidEmail(email)){
        $ionicPopup.alert({template: $translate.instant('error_invalid_email'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm invalid email');
        return false;
      }

      // if we have email - make sure we have password
      if (!password || _.isUndefined(password) || password.length === 0){
        $ionicPopup.alert({template: $translate.instant('error_invalid_password'), okText: $translate.instant('ok')});
        $log.error('RegisterController.validateForm email but no password');
        return false;
      }

      return true;
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('HistoryController', function ($scope, $translate, $log, $state, $ionicPopup, $ionicLoading,
                                             OrderHistoryService, $timeout) {
    ga_storage._trackPageview('History');
    $scope.orders = [];
    $scope.handleOrderClick = function (order) {
      $log.debug('HistoryController.handleOrderClick called');
      $state.go('order_details', {order_id: order.id});
    };

    $scope.handleBackClick = function () {
      $log.debug('HistoryController.handleBackClick called');
      $state.go('categories');
    };

    $scope._handleIonicViewEnter = function () {
      // first check if we already loaded the history and use cache.
      //$log.debug('HistoryController.viewEnter: loading orders from cache');
      $scope._loadOrders();
    };

    $scope._loadOrders = function(){
      $log.debug('HistoryController.loadOrders: loading orders from db');
      $ionicLoading.show();
      OrderHistoryService.loadOrdersFromLocal().then(function (orders) {
        $log.debug('HistoryController.loadOrders: orders loaded successfully');
        $ionicLoading.hide();
        $scope.orders = orders;
      }, function (reason) {
        $log.debug('HistoryController.loadOrders: failed to load orders. reason: ' + (reason && reason.message ? reason.message : reason));
        $timeout(function () {
          $ionicLoading.hide();
          $scope.$apply();
        }, 1000);
      });
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);

  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('OrderDetailsController', function ($scope, $translate, $log, $state, $stateParams, $ionicPopup,
                                                  OrderHistoryService, CategoriesService, CartService, DistributorsService) {
    ga_storage._trackPageview('OrderDetails');
    //$scope.order = Object({
    //  'id': 306249,
    //  'total_price': 92000,
    //  'asap': null,
    //  'team_id': 1330,
    //  'driver_id': 14469,
    //  'lat': 32.1065799,
    //  'lng': 34.8341559,
    //  'address': 'HaBarzel Street 1, Tel Aviv-Yafo, Israel',
    //  'inventory': [{
    //    'count': 1,
    //    'product': {
    //      'id': 210,
    //      'name': 'Cam ép Chai nhựa 1L\nLốc 6 Chai',
    //      'price': 92000
    //    }
    //  }],
    //  'driver': {
    //    'id': 14469,
    //    'name': 'Muchael Harrison, Junior',
    //    'phone': '0526511950',
    //    'rating': 0,
    //    'profile_image': '/images/avatar.png'
    //  }
    //});
    //if($scope.order && $scope.order.team_id){
    //  $scope.team = Object({"id":1330,"name":"Team A","external_id":"1330","rating":null,"address":"haargaman 5 tel mond","lat":32.250355,"lng":34.90959,"type":null,"distance":31.9995880590672});
    //}
    $scope.order = {};


    $scope.handleLoadToCartClick = function(){
      var order = $scope.order;
      if (order.inventory){
        var cart = $scope.getLatestInventory(order.inventory);
        if (cart.length !== order.inventory.length){
          $ionicPopup.alert({title: $translate.instant('warning_catalog_changed')});
        }
        _.each(cart, function(product){
          CartService.add(product);
        });

        $state.go('cart');
      }
    };

    $scope.handleBackClick = function () {
      $log.debug('OrderDetailsController.handleBackClick called');
      $state.go('history');
    };

    $scope._handleIonicViewEnter = function () {
      var order_id = parseInt($stateParams.order_id);
      if (order_id) {
        $log.debug('OrderDetailsController: loading history for order id ' + order_id);
        var order = OrderHistoryService.getOrderById(order_id);
        if (order){
          $log.debug(JSON.stringify(order));
          $scope.order = order;
          if($scope.order.team_id){
            $scope.team = DistributorsService.getDistributorByExternalId($scope.order.team_id.toString());
          }
        } else {
          $log.debug('OrderDetailsController: failed to retrieve order for id ' + order_id);
        }
      }
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);

    // removes outdated products from the inventory using the latest catalog. returns true if inventory was valid and false otherwise.
    $scope.getLatestInventory = function(inventory){

      var updatedInventory = [];
      var catalog = CategoriesService.getCatalog();
      _.each(inventory, function(item){
        $log.debug('looking in catalog for ' + JSON.stringify(item));
        var found = null;
        _.find(catalog, function(category){
          return _.find(category.products, function(product){
            if (product.id === item.product.id){
              found = product;
            }
            return product.id === item.product.id;
          });
        });

        $log.debug('found: ' + JSON.stringify(found));

        if (found){
          updatedInventory.push({product: found, count: item.count});
        } else {
          $log.debug('item no longer in catalog');
        }
      });

      return updatedInventory;
    };

  });


'use strict';

angular.module('cocaColaCordovaApp')
  .factory('OrderHistoryService', function ($q, $log, DBService) {
    var OrderHistoryService = {};

    // load the orders from local storage and return them using a promise
    OrderHistoryService.loadOrdersFromLocal = function(){
      var deferred = $q.defer();

      DBService.getOrders().then(function (orders) {
        OrderHistoryService._orders = orders;
        deferred.resolve(orders);
      }, function (reason) {
        OrderHistoryService._orders = [];
        deferred.reject(reason);
      });

      return deferred.promise;
    };

    OrderHistoryService.getOrderById = function(id){
      return _.find(OrderHistoryService._orders, function(order){
        return order.id === id;
      });
    };

    return OrderHistoryService;
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .factory('CategoriesService', function (DiscountsService, localStorageService, ConfigurationService, $log, $rootScope,
                                          RealTimeWebService, OrderHelper, DistributorsService) {
    var CategoriesService = {};


    CategoriesService._categories = [];

    CategoriesService.getCategoryProducts = function (categoryId, callback) {
      if (!CategoriesService._categories.length) {
        CategoriesService.buildCatalog(function (result) {
          CategoriesService._onCatalogBuilt(result, categoryId, callback);
        });
      } else {
        CategoriesService._fetchCategory(CategoriesService._categories, categoryId, callback);
      }
    };

    CategoriesService.getProduct = function(productId, callback){
      if (!CategoriesService._categories.length) {
        CategoriesService.buildCatalog(function () {
          CategoriesService._findProductById(CategoriesService._categories, productId, callback);
        });
      } else {
        CategoriesService._findProductById(CategoriesService._categories, productId, callback);
      }
    };

    CategoriesService._findProductById = function(categories, productId, callback){
      _.some(categories, function(category){
        var product = _.find(category.products, function(product){
            return product.id === parseInt(productId);
        });

        if(product){
          callback(product);
          return true;
        }
      });
    };

    CategoriesService.buildCatalog = function (callback, shouldForce, skipPromotions) {
      var categoriesLastUpdateTime = localStorageService.get('categories_last_update');
      var shouldFetchCategories = _.isUndefined(categoriesLastUpdateTime) || categoriesLastUpdateTime !== ConfigurationService.categoriesLastUpdate() || shouldForce;

      if (!shouldFetchCategories) {
        var categories = localStorageService.get('categories');
        if (categories) {
          $log.debug('categories loaded from local');
          CategoriesService._categories = categories;
          CategoriesService._sortCategories();
          CategoriesService._getProducts(callback, shouldForce, skipPromotions);
        } else {
          callback(null);
        }
      } else if ($rootScope._currentUser){ // make sure we have a logged in user
        CategoriesService._getCategoriesFromServer(callback);
      } else {
        $log.debug('user not logged in');
        callback(null);
      }
    };

    CategoriesService._getProducts = function (callback, shouldForce, skipPromotions) {
      var productsLastUpdateTime = localStorageService.get('products_last_update');
      var shouldFetchProducts = _.isUndefined(productsLastUpdateTime) || productsLastUpdateTime !== ConfigurationService.productsLastUpdate() || shouldForce;

      if (!shouldFetchProducts) {
        var products = localStorageService.get('products');
        if (products) {
          $log.debug('products loaded from local');
          CategoriesService._buildProductsData(products, callback, skipPromotions);
        } else {
          callback(null);
        }
      } else {
        CategoriesService._getProductsFromServer(callback);
      }
    };

    CategoriesService._getCategoriesFromServer = function(callback){
      RealTimeWebService.getCategories(CategoriesService._getDistributorIds()).then(function(categoriesResult){
        CategoriesService._onCategoriesRetrieved(categoriesResult, callback, true);
      }, function(){
        callback(null);
      });
    };

    CategoriesService._getProductsFromServer = function(callback){
      RealTimeWebService.getProducts(CategoriesService._getDistributorIds()).then(function(productsResult){
        CategoriesService._onProductsRetrieved(productsResult, callback);
      }, function(){
        callback(null);
      });
    };

    CategoriesService._getDiscounts = function(callback, localDiscounts){
      DiscountsService.getDiscounts(callback, localDiscounts);
    };

    CategoriesService._getDistributorIds = function(){
      var params = {};
      if (ConfigurationService.enableLocationBasedCatalog()){
        params.team_ids = _.map(DistributorsService.getDistributors(), 'id');
      }
      return params;
    };

    CategoriesService._setDiscountsToProducts = function(discounts, products){
      // get our dynamic category and clear the discounts
      var discountsCat = DiscountsService.getDiscountsCategory();
      discountsCat.products = [];
      _.each(discounts, function(discount){
        if(discount.inventory_id){
          _.each(products, function(product){
            if (discount.inventory_id === product.id){
              // save the discount data
              product.discount = discount;

              // calculate the discount based on its type
              if (CategoriesService._isValidDiscount(discount.discount_percentage)) {
                product.discountedPrice = (product.price * (100 - discount.discount_percentage) / 100);
              } else if (CategoriesService._isValidDiscount(discount.discount_total)){
                product.discountedPrice = product.price - discount.discount_total;
              }

              // add the product to the discounts category
              product.categories.push(discountsCat.id);
              discountsCat.products.push(product);
            }
          });
        }else if(discount.bundles && discount.bundles.length > 0){
          var newBundle = {products: [], discount: discount, bundles: [], name: discount.name, price: 0,discountedPrice: 0, bundle: true};
          _.each(discount.bundles, function(bundle){
            newBundle.bundles.push(bundle);
            newBundle.id = OrderHelper.guid();
            newBundle.image = discount.image;
            _.each(products, function(product){
              if(product.id === bundle.inventory_id){
                var newProduct = angular.copy(product);
                if (CategoriesService._isValidDiscount(bundle.discount_percentage)) {
                  newProduct.discountedPrice = (newProduct.price * (100 - bundle.discount_percentage) / 100);
                }

                newBundle.price += newProduct.price;
                newBundle.discountedPrice += newProduct.discountedPrice;
                newBundle.products.push(newProduct);
              }
            });
          });
          discountsCat.products.push(newBundle);
        }
      });

      // add the discounts category to all the categories if we managed to add discounts
      // note that we can get here without adding promotions if there are promotions and no inventories
      $log.debug(discountsCat.products);
      if (discountsCat.products.length > 0 ){
        CategoriesService._categories.push(discountsCat);
      } else {
        $log.debug('CategoriesService. has ' + discounts.length + ' promotions but did not add any');
      }
      CategoriesService._sortCategories();
    };

    CategoriesService._onProductsRetrieved = function(productsResult, callback){
      if (productsResult.success && productsResult.products) {
        // save products locally
        $log.debug('products loaded from remote');
        localStorageService.set('products_last_update', ConfigurationService.productsLastUpdate());
        localStorageService.set('products', productsResult.products);

        // associate products with categories
        CategoriesService._buildProductsData(productsResult.products, callback);
      } else {
        callback(null);
      }
    };

    CategoriesService._onCategoriesRetrieved = function(categoriesResult, callback, shouldForce){
      if (categoriesResult.success && categoriesResult.categories) {
        $log.debug('categories loaded from remote');
        // save categories locally
        localStorageService.set('categories_last_update', ConfigurationService.categoriesLastUpdate());
        localStorageService.set('categories', categoriesResult.categories);

        CategoriesService._categories = categoriesResult.categories;
        CategoriesService._sortCategories();
        CategoriesService._getProducts(callback, shouldForce);
      } else {
        callback(null);
      }
    };

    CategoriesService._fillProductsInCategories = function (products) {
      CategoriesService._cleanProductsFromCategories();

      _.each(products, function (product) {
        _.each(product.categories, function (category) {
          var cat = _.find(CategoriesService._categories, function (item) {
            return item.id === category.id;
          });

          if (cat){
            cat.products.push(product);
          }
        });
      });
    };

    CategoriesService._cleanProductsFromCategories = function() {
      _.each(CategoriesService._categories, function (category) {
        category.products = [];
      });
    };

    CategoriesService._buildProductsData = function(products, callback, localDiscounts){
      // associate products with categories
      CategoriesService._fillProductsInCategories(products);
      CategoriesService._sortProducts();

      // obtain discounts
      CategoriesService._getDiscounts(function(discounts){

        // apply discounts to products if necessary
        if (discounts && discounts.length > 0) {
          CategoriesService._setDiscountsToProducts(discounts, products);
        }
        // return the built catalog with categories-products-discounts.
        callback(CategoriesService._categories);
      }, localDiscounts);
    };

    CategoriesService._onCatalogBuilt = function(result, categoryId, callback){
      if (result && result.length) {
        CategoriesService._fetchCategory(result, categoryId, callback);
      } else if (result){
        callback(result);
      } else {
        callback(null);
      }
    };

    CategoriesService.getCatalog = function(){
      return CategoriesService._categories;
    };

    CategoriesService.clearAll = function () {
      // clear catalog
      CategoriesService._categories = [];
      // clear discounts
      DiscountsService.clear();
    };

    CategoriesService._fetchCategory = function(categories, categoryId, callback){
      var cat = _.find(categories, function (category) {
        return category.id === parseInt(categoryId);
      });

      if (!cat && categoryId === DiscountsService.getDiscountsCategory().id){
        cat = DiscountsService.getDiscountsCategory();
      }
      callback(cat);
    };

    CategoriesService._sortCategories = function(){
      CategoriesService._categories = _.sortBy(CategoriesService._categories, function(category){
        return category.sort_order ? category.sort_order : category.order;
      });
    };

    CategoriesService._sortProducts = function(){
      _.each(CategoriesService._categories, function(category, index){
        CategoriesService._categories[index].products = _.sortBy(category.products, function(product){
          return product.sort_order ? product.sort_order : product.order;
        });
      });
    };

    CategoriesService._isValidDiscount = function(discount){
      return !_.isUndefined(discount) && !_.isNull(discount) && !_.isNaN(discount);
    };

    return CategoriesService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('DiscountsService', function ($log, $translate, RealTimeWebService) {
    var DiscountsService = {};

    DiscountsService._discounts = [];

    // initial setting
    DiscountsService._discountsCategory = {
      id: -1,
      level: 1,
      order: -1,
      name: 'Deals',
      image : null,
      products : []
    };
    // make sure we get the name from translations
    $translate('deals').then(function(result){
      DiscountsService._discountsCategory = {
        id: -1,
        level: 1,
        order: -1,
        name: result,
        image : null,
        products : []
      };
    });


    DiscountsService.getDiscountsCategory = function(){
      return DiscountsService._discountsCategory;
    };

    DiscountsService.getDiscounts = function(callback, localDiscounts){
      if (localDiscounts){
        callback(DiscountsService._discounts);
      } else {
        RealTimeWebService.getPromotions().then(function (promotions) {
          DiscountsService._onDiscountsRetrieved(promotions, callback);
        }, function (reason) {
          callback(reason);
        });
      }
    };

    DiscountsService._onDiscountsRetrieved = function(discountsResult, callback){
      if (discountsResult.success && discountsResult.consumer_promotions){
        if (discountsResult.consumer_promotions.length > 0) {
          $log.debug('DiscountsService: ' + discountsResult.consumer_promotions.length + ' discounts loaded');
        } else {
          $log.debug('DiscountsService: no discounts');
        }
        DiscountsService._discounts = discountsResult.consumer_promotions;
        callback(discountsResult.consumer_promotions);

      } else {
        DiscountsService._discounts = [];

        if (discountsResult.message) {
          $log.error('DiscountsService: failed to load discounts: ' + discountsResult.message);
          callback(discountsResult.message);
        } else {
          $log.error('DiscountsService: failed to load discounts');
          callback(null);
        }
      }
    };

    DiscountsService.clear = function(){
      DiscountsService._discounts = [];
    };


    return DiscountsService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('DEFAULT_CONFIG_VALUES', {
    'CURRENCY': '$',
    'ALLOW_URGENT_DELIVERY': true,
    'ENABLE_DYNAMIC_ADDRESS': false,
    'FORCE_RATING': false,
    'ENABLE_COUPONS': false,
    'ENABLE_ACTIVATION_CODE': false,
    'SHOW_WHOLESALERS': true,
    'ENABLE_FIND_ME': false,
    'REQUIRE_PHONE': false,
    'REQUIRE_COMPANY': true,
    'MIN_PASSWORD_CHARS': 6,
    'OPEN_ALL_HOURS': true,
    'OPENING_TIMES' : [],
    'ALLOW_MULTIPLE_ORDERS' : false,
    'ASAP_ORDER_OFFSET_MINUTES' : 30,
    'NORMAL_ORDER_OFFSET_MINUTES' : 60 * 24,
    'FORCE_UPGRADE' : false,
    'VALIDATE_SOCIAL_LOGIN_PARAMS' : false,
    'ALLOW_MAINTENANCE_TICKETS' : false,
    'MAINTENANCE_SERVICE_REQUESTS' : [],
    'NORMAL_DELIVERY_PRICE' : 0,
    'URGENT_DELIVERY_PRICE' : 0,
    'ENABLE_LOCATION_BASED_CATALOG': false
  }).constant('PRESET_MERCHANT_ACCOUNTS', {
    'NAME': 'COCA COLA GLOBAL DEMO',
    'STAGING_ID': 8250,
    'DEMO_ID': 9031
  }).factory('ConfigurationService', function (RealTimeWebService, DEFAULT_CONFIG_VALUES, PRESET_MERCHANT_ACCOUNTS,
                                               $rootScope, localStorageService, $log) {

    var ConfigurationService = {};

    ConfigurationService.merchants = [];
    ConfigurationService.configuration = {
      currency: DEFAULT_CONFIG_VALUES.CURRENCY,
      allow_urgent_delivery: DEFAULT_CONFIG_VALUES.ALLOW_URGENT_DELIVERY,
      enable_dynamic_address: DEFAULT_CONFIG_VALUES.ENABLE_DYNAMIC_ADDRESS,
      force_rating: DEFAULT_CONFIG_VALUES.FORCE_RATING,
      enable_coupons: DEFAULT_CONFIG_VALUES.ENABLE_COUPONS,
      enable_activation_code: DEFAULT_CONFIG_VALUES.ENABLE_ACTIVATION_CODE,
      show_wholesalers: DEFAULT_CONFIG_VALUES.SHOW_WHOLESALERS,
      min_password_chars: DEFAULT_CONFIG_VALUES.MIN_PASSWORD_CHARS,
      require_phone_on_sign_up: DEFAULT_CONFIG_VALUES.REQUIRE_PHONE,
      require_company_name: DEFAULT_CONFIG_VALUES.REQUIRE_COMPANY,
      allow_multiple_orders : DEFAULT_CONFIG_VALUES.ALLOW_MULTIPLE_ORDERS,
      asap_order_schedule_offset_minutes : DEFAULT_CONFIG_VALUES.ASAP_ORDER_OFFSET_MINUTES,
      normal_order_schedule_offset_minutes : DEFAULT_CONFIG_VALUES.NORMAL_ORDER_OFFSET_MINUTES,
      force_upgrade : DEFAULT_CONFIG_VALUES.FORCE_UPGRADE,
      validate_social_login_params_on_client : DEFAULT_CONFIG_VALUES.VALIDATE_SOCIAL_LOGIN_PARAMS,
      allow_maintenance_tickets : DEFAULT_CONFIG_VALUES.ALLOW_MAINTENANCE_TICKETS,
      available_service_requests : DEFAULT_CONFIG_VALUES.MAINTENANCE_SERVICE_REQUESTS,
      enable_find_me: DEFAULT_CONFIG_VALUES.ENABLE_FIND_ME,
      normal_order_price: DEFAULT_CONFIG_VALUES.NORMAL_DELIVERY_PRICE,
      urgent_order_price: DEFAULT_CONFIG_VALUES.URGENT_DELIVERY_PRICE,
      enable_location_based_catalog: DEFAULT_CONFIG_VALUES.ENABLE_LOCATION_BASED_CATALOG
    };

    ConfigurationService.getMerchantsByCC = function (countryCode, callback) {
      // handle debug/demo cases
      if ($rootScope.isGlobalDemo || !$rootScope.isProduction) {
        ConfigurationService.merchants = [];
        if ($rootScope.isGlobalDemo) {
          ConfigurationService.merchants[0] = {
            name: PRESET_MERCHANT_ACCOUNTS.NAME,
            id: PRESET_MERCHANT_ACCOUNTS.DEMO_ID
          };
        } else {
          ConfigurationService.merchants[0] = {
            name: PRESET_MERCHANT_ACCOUNTS.NAME,
            id: $rootScope.staging_merchant_id ? $rootScope.staging_merchant_id : PRESET_MERCHANT_ACCOUNTS.STAGING_ID
          };
        }
        if (callback) {
          callback(ConfigurationService.merchants);
        }
      } else if (countryCode) {    // handle normal flow
        RealTimeWebService.getMerchantsByCountryCode({country_code: countryCode}).then(function (result) {
          if (ConfigurationService._isValidResponse(result)) {
            if (result.merchants && !_.isUndefined(result.merchants)) {
              ConfigurationService.merchants = result.merchants;

              if (callback) {
                callback(ConfigurationService.merchants);
              }
            } else if (callback) {
              callback(result.message);
            }
          } else if (callback) {
            callback(result);
          }
        }, function (error) {
          if (callback) {
            callback(error);
          }
        });
      }
    };

    ConfigurationService.getConfigurationForMerchant = function (merchantId, callback) {
      if (merchantId) {
        ConfigurationService.merchant_id = merchantId;
        RealTimeWebService.getCustomerConfig({merchant_id: merchantId}).then(function (result) {
          if (ConfigurationService._isValidResponse(result)) {
            if (result.config) {
              $log.debug('ConfigurationService. got new config ' + JSON.stringify(result.config));
              ConfigurationService.configuration = result.config.configuration;

              // these attributes are 1 level higher in the config hierarchy
              ConfigurationService.products_last_update = result.config.products_last_update;
              ConfigurationService.categories_last_update = result.config.categories_last_update;


              if (!result.hasOwnProperty('all_hours')){
                ConfigurationService.opening_hours.all_hours = DEFAULT_CONFIG_VALUES.OPEN_ALL_HOURS;
              }else{
                ConfigurationService.opening_hours.all_hours = result.all_hours;
              }

              if (!result.hasOwnProperty('opening_periods')){
                ConfigurationService.opening_hours.opening_periods = DEFAULT_CONFIG_VALUES.OPENING_TIMES;
              }else{
                ConfigurationService.opening_hours.opening_periods = result.opening_periods;
              }

              if (!result.config.configuration.hasOwnProperty('currency')){
                ConfigurationService.configuration.currency = DEFAULT_CONFIG_VALUES.CURRENCY;
              }

              if (!result.config.configuration.hasOwnProperty('allow_urgent_delivery')){
                ConfigurationService.configuration.allow_urgent_delivery = DEFAULT_CONFIG_VALUES.ALLOW_URGENT_DELIVERY;
              }

              if (!result.config.configuration.hasOwnProperty('enable_dynamic_address')){
                ConfigurationService.configuration.enable_dynamic_address = DEFAULT_CONFIG_VALUES.ENABLE_DYNAMIC_ADDRESS;
              }

              if (!result.config.configuration.hasOwnProperty('force_rating')){
                ConfigurationService.configuration.force_rating = DEFAULT_CONFIG_VALUES.FORCE_RATING;
              }

              if (!result.config.configuration.hasOwnProperty('enable_coupons')){
                ConfigurationService.configuration.enable_coupons = DEFAULT_CONFIG_VALUES.ENABLE_COUPONS;
              }

              if (!result.config.configuration.hasOwnProperty('enable_activation_code')){
                ConfigurationService.configuration.enable_activation_code = DEFAULT_CONFIG_VALUES.ENABLE_ACTIVATION_CODE;
              }

              if (!result.config.configuration.hasOwnProperty('enable_find_me')){
                ConfigurationService.configuration.enable_find_me = DEFAULT_CONFIG_VALUES.ENABLE_FIND_ME;
              }

              if (!result.config.configuration.hasOwnProperty('show_wholesalers')){
                ConfigurationService.configuration.show_wholesalers = DEFAULT_CONFIG_VALUES.SHOW_WHOLESALERS;
              }

              if (!result.config.configuration.hasOwnProperty('min_password_chars')){
                ConfigurationService.configuration.min_password_chars = DEFAULT_CONFIG_VALUES.MIN_PASSWORD_CHARS;
              }

              if (!result.config.configuration.hasOwnProperty('require_phone_on_sign_up')){
                ConfigurationService.configuration.require_phone_on_sign_up = DEFAULT_CONFIG_VALUES.REQUIRE_PHONE;
              }

              if (!result.config.configuration.hasOwnProperty('require_company_name')){
                ConfigurationService.configuration.require_company_name = DEFAULT_CONFIG_VALUES.REQUIRE_COMPANY;
              }

              if (!result.config.configuration.hasOwnProperty('allow_multiple_orders')){
                ConfigurationService.configuration.allow_multiple_orders = DEFAULT_CONFIG_VALUES.ALLOW_MULTIPLE_ORDERS;
              }

              if (!result.config.configuration.hasOwnProperty('asap_order_schedule_offset_minutes')){
                ConfigurationService.configuration.asap_order_schedule_offset_minutes = DEFAULT_CONFIG_VALUES.ASAP_ORDER_OFFSET_MINUTES;
              }

              if (!result.config.configuration.hasOwnProperty('normal_order_schedule_offset_minutes')){
                ConfigurationService.configuration.normal_order_schedule_offset_minutes = DEFAULT_CONFIG_VALUES.NORMAL_ORDER_OFFSET_MINUTES;
              }

              if (!result.config.configuration.hasOwnProperty('force_upgrade')){
                ConfigurationService.configuration.force_upgrade = DEFAULT_CONFIG_VALUES.FORCE_UPGRADE;
              }

              if (!result.config.configuration.hasOwnProperty('validate_social_login_params_on_client')){
                ConfigurationService.configuration.validate_social_login_params_on_client = DEFAULT_CONFIG_VALUES.VALIDATE_SOCIAL_LOGIN_PARAMS;
              }

              if (!result.config.configuration.hasOwnProperty('allow_maintenance_tickets')){
                ConfigurationService.configuration.allow_maintenance_tickets = DEFAULT_CONFIG_VALUES.ALLOW_MAINTENANCE_TICKETS;
              }

              if (!result.config.hasOwnProperty('available_service_requests')){
                ConfigurationService.configuration.available_service_requests = DEFAULT_CONFIG_VALUES.MAINTENANCE_SERVICE_REQUESTS;
              } else {
                ConfigurationService.configuration.available_service_requests = result.config.available_service_requests;
              }

              if (!result.config.configuration.hasOwnProperty('normal_order_price')){
                ConfigurationService.configuration.normal_order_price = DEFAULT_CONFIG_VALUES.NORMAL_DELIVERY_PRICE;
              }

              if (!result.config.configuration.hasOwnProperty('urgent_order_price')){
                ConfigurationService.configuration.urgent_order_price = DEFAULT_CONFIG_VALUES.URGENT_DELIVERY_PRICE;
              }

              if (!result.config.configuration.hasOwnProperty('enable_location_based_catalog')){
                ConfigurationService.configuration.enable_location_based_catalog = DEFAULT_CONFIG_VALUES.ENABLE_LOCATION_BASED_CATALOG;
              }

              if (callback) {
                callback(result);
              }
            } else if (callback) {
              callback(result.message);
            }
          } else if (callback) {
            callback(null);
          }
        }, function(reason){
          if (callback){
            callback(reason);
          }
        });
      }
    };


    ConfigurationService._isValidResponse = function (result) {
      return result && result.success;
    };

    // ===================================================
    // =================== catalog =======================

    ConfigurationService.productsLastUpdate = function () {
      return ConfigurationService.products_last_update;
    };

    ConfigurationService.categoriesLastUpdate = function () {
      return ConfigurationService.categories_last_update;
    };

    // ==================================================
    // ================ configuration ===================

    ConfigurationService.getCurrencyId = function(){
      return ConfigurationService.configuration.currency_id;
    };

    ConfigurationService.getCurrency = function () {
      return ConfigurationService.configuration.currency;
    };

    ConfigurationService.getMerchantPhone = function () {
      return ConfigurationService.configuration.customer_support_phone_number;
    };

    ConfigurationService.enableActivationCode = function () {
      return ConfigurationService.configuration.enable_activation_code;
    };

    ConfigurationService.allowUrgentDelivery = function () {
      return ConfigurationService.configuration.allow_urgent_delivery;
    };

    ConfigurationService.enableDynamicAddress = function () {
      return ConfigurationService.configuration.enable_dynamic_address;
    };

    ConfigurationService.enableFindMe = function () {
      return ConfigurationService.configuration.enable_find_me;
    };

    ConfigurationService.forceRating = function () {
      return ConfigurationService.configuration.force_rating;
    };

    ConfigurationService.forceStripePayments = function () {
      return ConfigurationService.configuration.force_stripe_payments;
    };

    ConfigurationService.enableCoupons = function () {
      return ConfigurationService.configuration.enable_coupons;
    };

    ConfigurationService.showWholesalers = function () {
      return ConfigurationService.configuration.show_wholesalers;
    };

    ConfigurationService.getMinPasswordChars = function() {
      return ConfigurationService.configuration.min_password_chars;
    };

    ConfigurationService.useWaterfalLayout = function() {
      return ConfigurationService.configuration.use_waterfal_layout;
    };

    ConfigurationService.requireCompanyName = function() {
      return ConfigurationService.configuration.require_company_name;
    };

    ConfigurationService.requirePhoneOnSignUp = function() {
      return ConfigurationService.configuration.require_phone_on_sign_up;
    };

    ConfigurationService.allowMultipleOrders = function() {
      return ConfigurationService.configuration.allow_multiple_orders;
    };

    ConfigurationService.shouldForceUpgrade = function(){
      var latestVersion = ConfigurationService.configuration.force_upgrade;
      if (latestVersion === 'true'){
        return true;
      }

      return $rootScope.appVersion && latestVersion && $rootScope.appVersion < latestVersion;
    };

    ConfigurationService.clearAll = function () {
      ConfigurationService.configuration = null;
      ConfigurationService.merchants = null;
    };

    ConfigurationService.getUiConfiguration = function(){
      var uiConfig = localStorageService.get('ui_configuration_data');
      if(!uiConfig){
        uiConfig = {waterfall_view: ConfigurationService.useWaterfalLayout()};
        localStorageService.set('ui_configuration_data', uiConfig);
      }

      return uiConfig;
    };

    ConfigurationService.setUiConfiguration = function(data){
      localStorageService.set('ui_configuration_data', data);
    };

    ConfigurationService.getCurrentMerchantId = function () {
      return ConfigurationService.merchant_id;
    };


    ConfigurationService.setEnv = function(env){
      localStorageService.set('last_env', env);
    };

    ConfigurationService.getLastEnv = function(){
      return localStorageService.get('last_env');
    };

    //==============================================
    // Open hours part
    //==============================================
    ConfigurationService.opening_hours = {
      all_hours : DEFAULT_CONFIG_VALUES.OPEN_ALL_HOURS,
      opening_periods : DEFAULT_CONFIG_VALUES.OPENING_TIMES
    };

    ConfigurationService.getOpeningHourInDay = function(day){
      var day_config = ConfigurationService._getOpeningsForDay(day);
      return day_config ? day_config.opening_hour : null;
    };

    ConfigurationService.getClosingHourInDay = function(day){
      var day_config = ConfigurationService._getOpeningsForDay(day);
      return day_config ? day_config.closing_hour : null;
    };

    ConfigurationService._getOpeningsForDay = function(day){
      return _.find(ConfigurationService.opening_hours.opening_periods, function(day_config){
        return day_config.day_of_week === day;
      });
    };

    ConfigurationService.isOpenAlways = function(){
      return ConfigurationService.opening_hours.all_hours;
    };

    ConfigurationService.getNormalOrderSchedulingOffset = function(){
      return ConfigurationService.configuration.normal_order_schedule_offset_minutes;
    };

    ConfigurationService.getAsapOrderSchedulingOffset = function(){
      return ConfigurationService.configuration.asap_order_schedule_offset_minutes;
    };

    ConfigurationService.shouldValidateSocialLoginParams = function(){
      return ConfigurationService.configuration.validate_social_login_params_on_client;
    };

    ConfigurationService.allowMaintenanceTickets = function(){
      return ConfigurationService.configuration.allow_maintenance_tickets;
    };

    ConfigurationService.getAvailableMaintenanceServices = function(){
      return ConfigurationService.configuration.available_service_requests;
    };

    ConfigurationService.getTermsAndConditionsLink = function () {
      return ConfigurationService.configuration.terms_and_conditions_link;
    };

    ConfigurationService.getPrivacyPolicyLink = function () {
      return ConfigurationService.configuration.privacy_policy_link;
    };

    ConfigurationService.getNormalDeliveryPrice = function(){
      return ConfigurationService.configuration.normal_order_price;
    };

    ConfigurationService.getUrgentDeliveryPrice = function(){
      return ConfigurationService.configuration.urgent_order_price;
    };

    ConfigurationService.enableLocationBasedCatalog = function () {
      return ConfigurationService.configuration.enable_location_based_catalog;
    };

    return ConfigurationService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('CountryCodeExtractor', function ($log, $rootScope, localStorageService, ENV) {
    var CountryCodeExtractor = {};

    if(ENV === 'development'){
      CountryCodeExtractor._countryCode = 'us';
    }

    CountryCodeExtractor.setCountryCode = function (countryCode) {
      var cc = countryCode.toLowerCase();
      $log.debug('country code : ' + cc);
      CountryCodeExtractor._countryCode = cc;
      localStorageService.set('countryCode', cc);
      $rootScope.$broadcast('country code set');
    };

    CountryCodeExtractor.getCountryCode = function () {
      if (CountryCodeExtractor._countryCode){
        return CountryCodeExtractor._countryCode;
      }

      var cc = localStorageService.get('countryCode');
      if (cc){
        $log.debug('CountryCodeExtractor: got from storage - ' + cc);
        CountryCodeExtractor._countryCode = cc;
      }
      return cc;
    };

    return CountryCodeExtractor;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('LocationUtil', function ($q, $window, $log) {
    var LocationUtil = {};

    LocationUtil.getDistanceBetween = function getDistanceFromLatLonInKm(lat1, lon1, lat2, lon2) {
      var R = 6371; // Radius of the earth in km
      var dLat = LocationUtil.deg2rad(lat2 - lat1);  // deg2rad below
      var dLon = LocationUtil.deg2rad(lon2 - lon1);
      var a =
        Math.sin(dLat / 2) * Math.sin(dLat / 2) +
        Math.cos(LocationUtil.deg2rad(lat1)) * Math.cos(LocationUtil.deg2rad(lat2)) *
        Math.sin(dLon / 2) * Math.sin(dLon / 2);

      var c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1 - a));
      return R * c; // Distance in km;
    };

    LocationUtil.deg2rad = function (deg) {
      return deg * (Math.PI / 180);
    };

    // ============================================

    LocationUtil.geocoder = null;
    LocationUtil.initGeocoder = function(){
      if ($window.google && $window.google.maps && $window.google.maps.Geocoder){
        LocationUtil.geocoder = new $window.google.maps.Geocoder();
      }
    };
    LocationUtil.initGeocoder();

    LocationUtil.geocodeAddress = function (query) {
      if (!query || query.length < 3) {
        return [];
      }

      var deferred = $q.defer();

      if (!LocationUtil.geocoder){
        LocationUtil.initGeocoder();
        if (!LocationUtil.geocoder){
          $log.error('LocationUtil.geocodeAddress - no geocoder available');
          deferred.resolve({formatted_address : query});
          return deferred.promise;
        }
      }

      LocationUtil.geocoder.geocode({
        'address': query
      }, function (results, status) {
        if (!results){
          results = [];
        }

        if (status === google.maps.GeocoderStatus.OK) {
          if(results[0].partial_match){
            results.unshift({formatted_address : query});
          }
          deferred.resolve(results);
        } else if (status === google.maps.GeocoderStatus.ZERO_RESULTS){
          results.unshift({formatted_address : query});
          deferred.resolve(results);
        } else {
          //deferred.resolve([{formatted_address: $filter('googleGeolocationStringFilter')(status), disabled: true}]);
          //deferred.resolve([{formatted_address: 'Address not found'}]);
        }
      });

      return deferred.promise;
    };

    LocationUtil.reverseGeocode = function(latlng){
      if (!latlng){
        return [];
      }

      var deferred = $q.defer();

      if (!LocationUtil.geocoder){
        LocationUtil.initGeocoder();
        if (!LocationUtil.geocoder) {
          $log.error('LocationUtil.reverseGeocode - no geocoder available');
          deferred.resolve([]);
          return deferred.promise;
        }
      }

      LocationUtil.geocoder.geocode({
       'location': latlng
      }, function (results, status) {
       if (status === google.maps.GeocoderStatus.OK) {
         if(results.length > 1){
           deferred.resolve(results);

           // $scope.locationSelection = $ionicPopup.show({
           //   template: '<ion-list>                                ' +
           //   '  <ion-item ng-repeat="location in geoCodeingResults" ng-click="addressSelectedCallback({item: location})"> ' +
           //   '    {{location.formatted_address}}' +
           //   '  </ion-item> ' +
           //   '</ion-list> ',
           //
           //   title: $translate.instant('LOGIN.SELECT_MERCHANT'),
           //   scope: $scope
           // });
         }

       } else {
         deferred.resolve([]);
       }
      });

      return deferred.promise;
    };

    LocationUtil._onFailureWithRetry = function(onSuccess, onFailure, params){
      params.enableHighAccuracy = false;
      params.timeout = 5000;

      navigator.geolocation.getCurrentPosition(
        onSuccess,
        onFailure,
        params);
    };

    LocationUtil.locateMe = function (onSuccess, onFailure, params, allowLowAccuracyOnFail) {
      if (params && params.enableHighAccuracy === true && allowLowAccuracyOnFail){
        navigator.geolocation.getCurrentPosition(
          onSuccess,
          function () {
            LocationUtil._onFailureWithRetry(onSuccess, onFailure, params);
          },
          params);
      } else {
        navigator.geolocation.getCurrentPosition(
          onSuccess,
          onFailure,
          params);
      }
    };

    return LocationUtil;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('CartService', function ($rootScope, $log, localStorageService, $filter, ConfigurationService) {
    var CartService = {};

    CartService._items = [];
    CartService._currentDestination = null;
    CartService._selectedDistributor = null;
    CartService._isUrgent = false;

    CartService.getCurrentDestinationLocation = function () {
      return CartService._currentDestination;
    };

    CartService.setCurrentDestinationLocation = function (location) {
      CartService._currentDestination = location;
    };

    CartService.getTotalInCart = function () {
      var result = 0;

      _.each(CartService._items, function (item) {
        if(item.product.bundle && item.product.products){
          _.each(item.product.products, function(bundeledProduct){
            var price = !_.isUndefined(bundeledProduct.discountedPrice) ? bundeledProduct.discountedPrice : bundeledProduct.price;
            result += price * item.count;
          });
        }else{
          var price = !_.isUndefined(item.product.discountedPrice) ? item.product.discountedPrice : item.product.price;
          result += price * item.count;
        }
      });
      result += CartService.getExtraDeliveryPrice();

      return result;
    };

    CartService.getExtraDeliveryPrice = function () {
        return CartService._isUrgent ? ConfigurationService.getUrgentDeliveryPrice() : ConfigurationService.getNormalDeliveryPrice();
    };

    CartService.updateUrgency = function (isUrgent) {
      CartService._isUrgent = isUrgent;
    };

    CartService.getProductById = function (id) {
      var found = _.find(CartService._items, function (item) {
        return item.product.id === id;
      });

      return found;
    };

    CartService.add = function (product) {
      var found = _.find(CartService._items, function (item) {
        return item.product.id === product.product.id;
      });

      if (found) {
        found.count = product.count;
      } else {
        CartService._items.push(product);
      }

      $rootScope.$broadcast('cartCountUpdated', CartService._items.length);
    };

    CartService.currentCart = function () {
      return CartService._items;
    };

    CartService.removeFromCart = function (product) {
      CartService._items = _.reject(CartService._items, function (item) {
        return item.product.id === product.product.id;
      });
      $rootScope.$broadcast('cartCountUpdated', CartService._items.length);
      $rootScope.$broadcast('cartUpdated', CartService._items.length);
    };

    CartService.setSelectedDistributor = function (distibutor) {
      CartService._selectedDistributor = distibutor;
      $rootScope.$broadcast('selectedDistributorUpdated', CartService._selectedDistributor);
    };

    CartService.clearAll = function () {
      CartService._items = [];
      CartService._selectedDistributor = null;
      CartService._currentDestination = null;
      localStorageService.remove('cart');
      $log.debug('cart cleared');

      $rootScope.$emit('cartCountUpdated', CartService._items.length);
      $rootScope.$emit('cartUpdated', CartService._items.length);
    };

    CartService.store = function () {
      var cart = {
        items: CartService._items,
        distributor: CartService._selectedDistributor,
        destination: CartService._currentDestination
      };

      localStorageService.set('cart', cart);
    };

    CartService.restore = function () {
      var cart = localStorageService.get('cart');
      if (cart) {
        CartService._items = cart.items;
        CartService._selectedDistributor = cart.distributor;
        CartService._currentDestination = cart.destination;
        $log.debug('cart restored');
      }
      return cart;
    };

    CartService.getStoredItems = function () {
      var cart = localStorageService.get('cart');
      if (cart && cart.items){
        return cart.items;
      }
      return [];
    };

    CartService.getStringForCart = function (product) {
      var found = _.find(CartService._items, function (item) {
        return item.product.id === product.id;
      });

      if (!found) {
        return null;
      }

      var actualPrice = found.product.discountedPrice ? found.product.discountedPrice : found.product.price;
      var price = $filter('currency')(actualPrice);
      var total = $filter('currency')(found.count * actualPrice);
      return '<span class="in-cart-label">' + found.count + ' x ' + price + ' = ' + total + '</span>';
    };

    CartService.getIntForCharge = function(){
      return CartService.getTotalInCart() * 100;
    };

    return CartService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('LOCAL_STORAGE_KEYS', {
    'APP_VERSION': 'registered_version',
    'PUSH_ID': 'push_id'
  })
  .factory('PushService', function ($timeout, $log, $q, RealTimeWebService, localStorageService, LOCAL_STORAGE_KEYS) {
    var PushService = {};
    PushService.retryDelay = 1000 * 60 * 5; // 5 minutes

    PushService.setPushId = function (token, appVersion) {
      // token validation
      if (!token || _.isUndefined(token)) {
        $log.warn('PushService.setPushId invalid token');
        return;
      }

      if (appVersion){
        localStorageService.set(LOCAL_STORAGE_KEYS.APP_VERSION, appVersion);
      }

      localStorageService.set(LOCAL_STORAGE_KEYS.PUSH_ID, token);
      PushService.setPushIdInServer(token);
    };

    PushService.setPushIdInServer = function(token){
      $log.debug('PushService.setPushIdInServer');

      var deferred = $q.defer();
      RealTimeWebService.setPushId(token).then(function (result) {
        if (result && result.status && result.status === 'ok') {
          $log.debug('PushService.setPushId success');
          deferred.resolve();
        }
      }, function (result) {
        $log.debug('PushService.setPushId failure');

        // resolve anyway so we will log out the user locally.
        deferred.resolve();

        if (!_.isUndefined(result)) {
          var status = result.status;
          if (!_.isUndefined(status) && status !== 404 && status !== 401 && status !== 400) {
            PushService._sendLater(token);
          }
        } else {
          PushService._sendLater(token);
        }
      });
      return deferred.promise;
    };

    PushService.storePushIdLocally = function (token, currentVersion) {
      $log.debug('PushService: storing push token locally');
      localStorageService.set(LOCAL_STORAGE_KEYS.PUSH_ID, token);

      if (currentVersion){
        localStorageService.set(LOCAL_STORAGE_KEYS.APP_VERSION, token);
      }
    };


    PushService.getPushId = function(currentVersion){
      var pushId = localStorageService.get(LOCAL_STORAGE_KEYS.PUSH_ID);
      if (!pushId){
        $log.debug('PushService: no push id');
        return null;
      }

      // if we provided a version to check against
      if (currentVersion) {
        var registeredVersion = localStorageService.get(LOCAL_STORAGE_KEYS.APP_VERSION);
        if (!registeredVersion || currentVersion !== registeredVersion) {
          $log.debug('PushService: version changed');
          return null;
        }
      }

      return pushId;
    };

    PushService._sendLater = function (token) {
      $timeout(function(){
        PushService.setPushIdInServer(token);
      },PushService.retryDelay);
    };

    return PushService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('PushHandlerService', function (PromotionService, ORDER_STATUS, OrderService, OrderHelper, $log) {
    var PushHandlerService = {};

    PushHandlerService.handlePush = function (data) {
      $log.debug('PushHandlerService. push message = ' + JSON.stringify(data));
      //var message = data.message;
      var extras = data.additionalData;
      if (extras) {
        if (extras.task_status) {
          var existingOrder = OrderService.getActiveOrder();

          // if we dont have an active existing order - do nothing
          if (OrderHelper.isDone(existingOrder)){
            $log.debug('PushHandlerService. no existing order - ignoring push');
            return;
          }
          if (extras.task_id && existingOrder && extras.task_id !== existingOrder.task_id){
            $log.debug('PushHandlerService. push for task id ' + extras.task_id + ' but current task id is ' + existingOrder.task_id + '. ignoring');
            return;
          }

          // if the new status require us to change the status
          var status = parseInt(extras.task_status);
          if (OrderHelper.shouldChangeStatus(existingOrder, status)){
            existingOrder.status = status;
            OrderService.saveOrder(existingOrder);
          }
        } else if (extras.shared_location) {
          $log.debug('PushHandlerService. shared location push');
        } else if (extras.notification_url) {
          $log.debug('PushHandlerService. handling promotion push ' + JSON.stringify(extras));
          // if not in foreground this is called once the user clicked the notification
          if (!extras.foreground){
            PromotionService.launchPromotion(extras.notification_url);
          } else {
            PromotionService.promptPromotion(extras.notification_url, data.message);
          }
        } else {
          $log.warn('PushHandlerService. unknown push');
        }
      } else {
        $log.error('missing push data');
      }
    };

    return PushHandlerService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .directive('cartFooter', function ($state, CartService, $rootScope, $translate, $timeout) {
    return {
      restrict: 'E',
      replace: true,
      scope: {
        cart: '='
      },
      templateUrl: 'scripts/common/directives/cart-footer-directive.html',
      link: function (scope) {

        scope.disabled = false;

        scope.disableForTime = function(){
          scope.disabled = true;
          $timeout(function(){
            scope.disabled = false;
          }, 1000);
        };

        scope.handleCompleteOrderClick = function () {
          ga_storage._trackEvent('cartFooter', 'handleCompleteOrderClick', 'click');
          scope.disableForTime();
          if (scope.cart) {
            $rootScope.$broadcast('cartOrderCompletedClicked');
          } else {
            $state.go('cart');
          }
        };

        if (scope.cart) {
          scope.submitLabel = $translate.instant('button_submit');
        } else {
          scope.submitLabel = $translate.instant('complete_order_label');
        }

        scope.total = CartService.getTotalInCart();
        scope.cartItems = CartService._items;
        scope.$on('cartCountUpdated', function () {
          scope.total = CartService.getTotalInCart();
          scope.cartItems = CartService._items;
        });
      }
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('LogoutController', function ($scope, AuthenticationService, $state, $log) {

    ga_storage._trackPageview('Logout');
    $scope._handleIonicViewEnter = function(){
      AuthenticationService.logOut($scope._onLoggedOut);
    };

    $scope._onLoggedOut = function(){
      $log.debug('LogoutController.logged out');
      $state.go('login');
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('ProductAddToCartService', function ($ionicModal, $rootScope, $log, CartService) {
    var ProductAddToCartService = {};

    ProductAddToCartService.modal = null;
    ProductAddToCartService.open = function (product, editing, hideInfoButton) {

      if(_.isUndefined(hideInfoButton)){
        hideInfoButton = false;
      }

      var fromCart = angular.copy(CartService.getProductById(product.id));

      $log.debug('ProductAddToCartService.open');

      var scope = $rootScope.$new();
      scope.item = fromCart ? fromCart : {product: product, count: 1};
      scope.editing = editing;
      scope.hideInfoButton = hideInfoButton;
      $ionicModal.fromTemplateUrl('scripts/core/product_add_to_cart/product-add-to-cart.html', {
        scope: scope,
        animation: 'slide-in-up',
        backdropClickToClose: false,
        hardwareBackButtonClose: true
      }).then(function (modal) {
        ProductAddToCartService.modal = modal;
        ProductAddToCartService.modal.show();
      });
    };

    ProductAddToCartService.cancel = function () {
      if(!ProductAddToCartService.modal){
        return;
      }
      ProductAddToCartService.modal.remove();
      ProductAddToCartService.modal = null;
    };

    ProductAddToCartService.apply = function (item) {
      CartService.add(item);
      ProductAddToCartService.cancel();
    };

    return ProductAddToCartService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('ProductAddToCartController', function ($scope, $log, ProductAddToCartService, $translate, $state, $ionicPopup) {
    ga_storage._trackPageview('ProductAddToCart');
    $scope.submitDisabled = false;

    $scope.handleMinusButtonClick = function () {
      ga_storage._trackEvent('ProductAddToCartController', 'handleMinusButtonClick', 'click');
      $log.debug('ProductAddToCartController.handleMinusButtonClick');
      $scope.item.count--;
    };

    $scope.handlePlusButtonClick = function () {
      ga_storage._trackEvent('ProductAddToCartController', 'handlePlusButtonClick', 'click');
      $log.debug('ProductAddToCartController.handlePlusButtonClick');

      if (!$scope.allowedToAdd(1)){
        $scope.showLimitedPromotionDialog();
        return;
      }

      $scope.item.count++;
    };

    if ($scope.editing) {
      $scope.applyLabel = $translate.instant('update_cart');
    } else {
      $scope.applyLabel = $translate.instant('load_cart');
    }

    $scope.handleCancelClick = function () {
      ga_storage._trackEvent('ProductAddToCartController', 'handleCancelClick', 'click');
      $scope.submitDisabled = true;
      $log.debug('ProductAddToCartController.handleCancelClick');
      ProductAddToCartService.cancel();
    };

    $scope.handleMoreInfoButtonClick = function () {
      ga_storage._trackEvent('ProductAddToCartController', 'handleMoreInfoButtonClick', 'click');
      ProductAddToCartService.cancel();
      $state.go('product', {product_id: $scope.item.product.id});
    };

    $scope.handleAddToCartClick = function () {
      if (!$scope.allowedToAdd()){
        $scope.showLimitedPromotionDialog();
        return;
      }

      ga_storage._trackEvent('ProductAddToCartController', 'handleAddToCartClick', 'click');
      $scope.submitDisabled = true;
      $log.debug('ProductAddToCartController.handleAddToCartClick');
      ProductAddToCartService.apply($scope.item);
    };

    $scope.allowedToAdd = function(modifier){
      if(!modifier){
        modifier = 0;
      }
      var promotion = $scope.item.product.discount;
      var useCount = $scope.item.count + modifier;
      if (promotion && promotion.use_limit){
        if (promotion.use_limit < useCount){
          return false;
        }
      }
      return true;
    };

    $scope.showLimitedPromotionDialog = function(){
      $ionicPopup.alert({title: $translate.instant('limited_promotion'), template: $translate.instant('promotion_limit_reached')});
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('SelectDistributorController', function ($scope, AuthenticationService, DistributorsService, $ionicLoading,
                                                       $timeout, CartService, $state, $log) {
    ga_storage._trackPageview('SelectDistributor');
    $scope.showList = true;
    $scope.Math = Math;
    $scope.map = {
      center: {latitude: 32.1068777, longitude: 34.8343631},
      zoom: 12,
      options: {disableDefaultUI: true, draggable: false}
    };

    $scope.markers = [];
    $scope.googleMap = {};

    $scope._handleIsLoggedIn = function () {
      if (AuthenticationService.isLoggedIn) {
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "loading" | translate}}</p>'
        });
        $scope._loadData(function () {
          $ionicLoading.hide();
        });
      }
    };

    $scope.$watch(AuthenticationService.isLoggedIn, $scope._handleIsLoggedIn);

    $scope.handleDistributorClicked = function (distributor) {
      ga_storage._trackEvent('SelectDistributorController', 'handleDistributorClicked', 'click');
      $log.debug('SelectDistributorController.handleDistributorClicked');
      CartService.setSelectedDistributor(distributor);
      $state.go('cart');
    };

    $scope.doRefresh = function () {
      $log.debug('SelectDistributorController.doRefresh');
      $scope._loadData(function () {
        $scope.$broadcast('scroll.refreshComplete');
      });
    };

    $scope.handleBackClick = function () {
      ga_storage._trackEvent('SelectDistributorController', 'handleBackClick', 'click');
      $log.debug('SelectDistributorController.handleBackClick');
      $state.go('cart');
    };

    $scope._loadData = function (callback) {
      DistributorsService.getDistributors(function (distributors) {
        if (distributors && distributors.length){
          $scope.distributors = distributors.slice(0,10);
        }

        if (callback) {
          callback();
        }
      }, CartService.getCurrentDestinationLocation());
    };

    $scope.handleMapButtonClick = function () {
      ga_storage._trackEvent('SelectDistributorController', 'handleMapButtonClick', 'click');
      $log.debug('SelectDistributorController.handleMapButtonClick');
      $state.go('select_distributor_map');
    };

    var fakerHiddenBlock = $("<div><span class='item-text-wrap'></span></div>")
      .css({
        position:   'absolute', // Optional if #myDiv is already absolute
        // visibility: 'hidden',
        width: '50%',
        padding: '11px',
        display:    'inline-block'
      })
      .appendTo('body');

    /**
     * get distributor height
     * @param distributor
     */
    $scope.getDistributorHeight = function (distributor) {
      fakerHiddenBlock.children(0).text(distributor.name);
      var dynamicCalculatedHeight = fakerHiddenBlock.outerHeight();
      return dynamicCalculatedHeight <= 55 ? '55px' : (dynamicCalculatedHeight + 20) + 'px';
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('ORDER_STATUS', {
    'CREATED': 0,
    'ASSIGNED': 1,
    'ON_THE_WAY': 2,
    'CHECKED_IN': 3,
    'DONE': 4,
    'ACCEPTED': 6,
    'CANCELLED': 7,
    'REJECTED': 8
  })
  .constant('STORAGE_CONSTANTS', {
    'CURRENT_ORDER' : 'savedOrder',
    'CART' : 'savedOrderVisual',
    'CURRENT_SHARED_CONFIGURATION' : 'sharedLocationConfig',
    'ONGOING_SHARED_CONFIGS' : 'ongoingConfigs',
    'ONGOING_ORDERS' : 'ongoingOrders',
    'ONGOING_INVENTORIES' : 'ongoingInventories'
  })
  .factory('OrderService', function ($q, MERCHANT_CONFIG, CartService, RealTimeWebService, ConfigurationService, DBService,
                                     $log, localStorageService, $rootScope, ORDER_STATUS, STORAGE_CONSTANTS, $translate) {
    var OrderService = {};

    OrderService._ongoingOrders = [];
    OrderService._activeOrder = null;

    OrderService.calculatePrice = function(cartItems, urgent, distributor){
      var order = {
        inventory: OrderService._createInventory(cartItems),
        asap: urgent
      };

      if (distributor && distributor.id){
        order.team_id = distributor.id;
      }

      return RealTimeWebService.calculatePrice(order);
    };

    OrderService.createOrder = function (user, cartItems, urgent, distributor, address, location, test, nonce, comment, extras) {
      $log.debug('OrderService.createOrder called');
      var deferred = $q.defer();

      var order = {};

      if($rootScope._currentUser.extras && $rootScope._currentUser.extras.hasOwnProperty('company_name')){
        order.title = $rootScope._currentUser.extras.company_name;
      }else{
        order.title = $translate.instant('new_order_title') + ' ' + $rootScope._currentUser.merchant_id;
      }

      order.phone = user.phone;
      order.total_price = CartService.getTotalInCart();
      order.asap = urgent;


      //create inventory
      order.inventory = OrderService._createInventory(cartItems);

      //create the notes
      //order.notes = OrderService._createNotes(cartItems);
      if(comment){
        order.notes = OrderService._createCommentNote(comment);
      }

      //create the waypoint
      order.way_points = OrderService._createWayPoints(user, address, location, urgent);

      // add distributor if exists
      if (distributor && distributor.id) {
        order.team_id = distributor.id;
      }

      if (test){
        order.test = test;
      }

      if (extras){
        order.extras = extras;
      }

      RealTimeWebService.createOrder(order, nonce).then(function (result) {
        $log.debug('OrderService.createOrder success orderId: ' + result.task.id);
        if (!result.task.way_points){
          result.task.way_points = order.way_points;
        }
        OrderService._onOrderCreated(result.task, cartItems);
        deferred.resolve(result.task);
      }, function (reason) {
        $log.error('OrderService.createOrder error');
        deferred.reject(reason);
      });

      return deferred.promise;
    };

    OrderService.createMaintenanceTicket = function (ticket) {
      var order = {};

      order.way_points = [{
        address: ticket.address,
        phone: ticket.phone,
        scheduled_at: OrderService._calcScheduledAt()
      }];

      order.extras = {
        asset_number: ticket.asset_number,
        serial_number: ticket.serial_number,
        service_request_id: ticket.service_request_id
      };

      if(ticket.comment){
        order.notes = OrderService._createCommentNote(ticket.comment);
      }

      return RealTimeWebService.createMaintenanceTicket(order);
    };

    OrderService.cancelOrder = function (order_id) {
      $log.debug('OrderService.cancelOrder called');
      var deferred = $q.defer();

      RealTimeWebService.cancelOrder(order_id).then(function (result) {
        $log.debug('OrderService.cancelOrder success on ' + order_id);
        OrderService._onOrderCanceled(order_id);
        deferred.resolve(result);
      }, function (reason) {
        $log.debug('OrderService.cancelOrder failed on ' + order_id);
        deferred.reject(reason);
      });
      return deferred.promise;
    };

    OrderService.saveOrder = function (order) {
      var merged;
      var saved = OrderService.getSavedOrder();
      var statusChanged = true;
      var priceChanged = false;
      if (saved) {
        priceChanged = !_.isUndefined(order.total_price) && order.total_price !== saved.total_price;

        if (saved.status === order.status){
          $log.debug('OrderService.saveOrder: order update. status still ' + order.status);
          statusChanged = false;
        } else {
          $log.debug('OrderService.saveOrder: order status was ' + saved.status + ' changing to ' + order.status);
        }
        // save anyway
        merged = _.merge(saved, order);

        if (merged.status === ORDER_STATUS.CREATED){
          merged.driver = null;
        }
      } else {
        $log.debug('saving order with status ' + order.status);
        merged = order;
      }

      localStorageService.set(STORAGE_CONSTANTS.CURRENT_ORDER, merged);
      OrderService._activeOrder = merged;

      if (statusChanged) {
        $rootScope.$broadcast('order updated');
      } else if (priceChanged){
        $rootScope.$broadcast('price updated');
      }
    };

    // =====================================

    OrderService.getOngoingOrders = function(loadFromLocal){
      // restore from local storage if needed
      if (loadFromLocal){
        OrderService._ongoingOrders = localStorageService.get(STORAGE_CONSTANTS.ONGOING_ORDERS);
        if (!OrderService._ongoingOrders){
          OrderService._ongoingOrders = [];
        }

        $log.debug('OrderService - loaded ' + OrderService._ongoingOrders.length + ' ongoing orders from local');
      }

      return OrderService._ongoingOrders;
    };

    OrderService.getOngoingOrderById = function(orderId){
      return _.find(OrderService._ongoingOrders, function(order){
        return order.id === parseInt(orderId);
      });
    };

    OrderService.setActiveOrder = function(order){
      var orderId = order ? order.id : 'null';
      $log.debug('setting active order: ' + orderId);

      OrderService._activeOrder = order;

      if (order && !OrderService.getOngoingOrderById(order.id)){
        OrderService.addToOngoing(order);
      }
    };

    OrderService.getActiveOrder = function(){
      return OrderService._activeOrder ? OrderService._activeOrder : OrderService.getSavedOrder();
    };

    OrderService.addToOngoing = function(order){
      $log.debug('OrderService.addToOngoing ' + order.id);

      OrderService._ongoingOrders.push(order);
      localStorageService.set(STORAGE_CONSTANTS.ONGOING_ORDERS, OrderService._ongoingOrders);
    };

    OrderService.getSavedOrder = function () {
      return localStorageService.get(STORAGE_CONSTANTS.CURRENT_ORDER);
    };

    OrderService.getOrderFromServer = function(orderId){
      return RealTimeWebService.getOrder(orderId);
    };

    // =========================================
    // cart
    // =========================================

    OrderService.storeCartItemsForOrder = function(orderId, cartItems){
      // set current order items
      OrderService._storeCurrentCart(cartItems);

      // set for multiple tracking
      var inventories = OrderService._getOngoingCartItems();
      inventories[orderId] = cartItems;
      localStorageService.set(STORAGE_CONSTANTS.ONGOING_INVENTORIES, inventories);
    };

    OrderService.getCartForActiveOrder = function () {
      if (OrderService._activeOrder){
        var cart = OrderService._getCartByOrderId(OrderService._activeOrder.id);
        if (cart) {
          localStorageService.set(STORAGE_CONSTANTS.CART, cart);
          return cart;
        }
      }
      return localStorageService.get(STORAGE_CONSTANTS.CART);
    };

    OrderService._storeCurrentCart = function(cart){
      localStorageService.set(STORAGE_CONSTANTS.CART, cart);
    };

    OrderService._getOngoingCartItems = function(){
      var inventories = localStorageService.get(STORAGE_CONSTANTS.ONGOING_INVENTORIES);
      return inventories ? inventories : {};
    };

    OrderService._getCartByOrderId = function(orderId){
      var inventories = OrderService._getOngoingCartItems();
      return inventories[orderId] ? inventories[orderId] : [];
    };

    OrderService._removeCartItemsForOrder = function(orderId){
      var inventories = OrderService._getOngoingCartItems();
      if (inventories[orderId]){
        delete inventories[orderId];
        localStorageService.set(STORAGE_CONSTANTS.ONGOING_INVENTORIES, inventories);
      }
    };

    // ====================================
    // shared location configs
    // ====================================

    OrderService.storeSharedLocationConfig = function(sharedLocation, orderId){
      OrderService._storeCurrentConfig(sharedLocation);

      // set for multiple tracking
      var configs = OrderService._getOngoingSharedConfigs();
      configs[orderId] = sharedLocation;
      localStorageService.set(STORAGE_CONSTANTS.ONGOING_SHARED_CONFIGS, configs);
    };

    OrderService.getSharedLocationConfig = function(){
      if (OrderService._activeOrder){
        var config = OrderService._getSharedConfigByOrderId(OrderService._activeOrder.id);
        if (config) {
          localStorageService.set(STORAGE_CONSTANTS.CURRENT_SHARED_CONFIGURATION, config);
          return config;
        }
      }
      return localStorageService.get(STORAGE_CONSTANTS.CURRENT_SHARED_CONFIGURATION);
    };

    OrderService._getOngoingSharedConfigs = function(){
      var configs = localStorageService.get(STORAGE_CONSTANTS.ONGOING_SHARED_CONFIGS);
      return configs ? configs : {};
    };

    OrderService._getSharedConfigByOrderId = function(orderId){
      var configs = OrderService._getOngoingSharedConfigs();
      return configs[orderId];
    };

    OrderService._storeCurrentConfig = function(sharedConfig){
      localStorageService.set(STORAGE_CONSTANTS.CURRENT_SHARED_CONFIGURATION, sharedConfig);
    };

    OrderService._removeSharedConfigForOrder = function(orderId){
      var configs = OrderService._getOngoingSharedConfigs();
      if (configs[orderId]){
        delete configs[orderId];
        localStorageService.set(STORAGE_CONSTANTS.ONGOING_SHARED_CONFIGS, configs);
      }
    };

    // =====================================

    OrderService.clearSaved = function (clearCart, ongoing) {

      // in case we got here because order was done we clear the cart and add the order to db.
      if (clearCart){
        var order = OrderService.getSavedOrder();
        if (order){
          // save the order by default when this is called
          if (_.isUndefined(ongoing)) {
            OrderService._onOrderDone(order);
          }
        }
        CartService.clearAll();
      }

      localStorageService.set(STORAGE_CONSTANTS.CURRENT_ORDER, null);
      localStorageService.set(STORAGE_CONSTANTS.CART, null);
      localStorageService.set(STORAGE_CONSTANTS.CURRENT_SHARED_CONFIGURATION, null);
      $log.debug('order cleared');

    };

    OrderService._createInventory = function (cartItems) {
      var result = [];
      _.each(cartItems, function (product) {
        if(product.product.bundle && product.product.products){
          _.each(product.product.products, function(bundeledProducs){
            result.push({id: bundeledProducs.id, quantity: product.count});
          });
        }else{
          result.push({id: product.product.id, quantity: product.count});
        }

      });

      return result;
    };

    OrderService._createWayPoints = function (user, address, location, asap) {
      var wayPoint = {};

      wayPoint.email = user.email;
      wayPoint.name = user.name;
      wayPoint.phone = user.phone;
      wayPoint.asap = asap;

      wayPoint.scheduled_at = OrderService._calcScheduledAt(asap);

      if (location && location.lat && location.lng) {
        wayPoint.lat = location.lat.toString();
        wayPoint.lng = location.lng.toString();
      }

      if (address) {
        wayPoint.address = address;
      }

      //wayPoint.scheduled_at = new Date().toISOString();

      return [wayPoint];
    };

    OrderService._createNotes = function (cartItems) {
      var itemsNote = '';

      _.forEach(cartItems, function (product) {
        var price = product.product.discountedPrice ? product.product.discountedPrice : product.product.price;
        itemsNote += product.product.name + ' ' + ConfigurationService.getCurrency() + price + ' x ' + product.count + '\n';
      });

      var priceNote = 'Total: ' + ConfigurationService.getCurrency() + CartService.getTotalInCart();

      return [itemsNote, priceNote];
    };

    OrderService._createCommentNote = function(comment){
      return [$translate.instant('comment_by_customer') + '\n' + comment];
    };

    OrderService._onOrderCreated = function(order, cartItems){
      OrderService.saveOrder(order);
      OrderService.setActiveOrder(order);
      OrderService.storeCartItemsForOrder(order.id, cartItems);
    };

    OrderService._onOrderDone = function(order){
      $log.debug('OrderService: order done - ' + order.id);

      var inventory = OrderService._getCartByOrderId(order.id);

      // remove ongoing inventory for order
      OrderService._removeCartItemsForOrder(order.id);

      // save to db
      DBService.addOrder(order, inventory);
    };

    OrderService._saveCanceledOrder = function(orderId){
      var order = OrderService.getActiveOrder();
      if (!order || order.id !== orderId){
        order = OrderService.getOngoingOrderById(orderId);
      }

      // try to save in history
      if (order) {
        if (order.extras && order.extras.service_request_id){
          $log.debug('OrderService: ticket canceled');
          return;
        }
        $log.debug('OrderService: cancel order - saving in db');
        var inventory = OrderService._getCartByOrderId(orderId);
        order.status = 7;
        DBService.addOrder(order, inventory);
      } else {
        $log.debug('OrderService: cancel order - did not add to db');
      }
    };

    OrderService._onOrderCanceled = function(orderId){
      // try to get order if active, otherwise from ongoing orders if exists
      OrderService._saveCanceledOrder(orderId);

      // clear from local storage
      OrderService.clearSaved(true, true);

      // remove from active and ongoing orders
      if (OrderService._activeOrder && OrderService._activeOrder.id === orderId){
        OrderService._activeOrder = null;
      }

      OrderService._ongoingOrders = _.reject(OrderService._ongoingOrders, function(order){
        return order.id === orderId;
      });
      localStorageService.set(STORAGE_CONSTANTS.ONGOING_ORDERS, OrderService._ongoingOrders);

      OrderService._removeCartItemsForOrder(orderId);
      OrderService._removeSharedConfigForOrder(orderId);
    };

    OrderService.createCharge = function (amount, description) {
      var deferred = $q.defer();
      RealTimeWebService.createCharge({
        amount: amount,
        description: description,
        currency: ConfigurationService.getCurrencyId()
      }).then(function (result) {
        deferred.resolve(result);
      }, function (reason) {
        deferred.reject(reason);
      });
      return deferred.promise;
    };

    OrderService._calcScheduledAt = function(asap){
      var offsetInMinutes = asap ?
        ConfigurationService.getAsapOrderSchedulingOffset() :
        ConfigurationService.getNormalOrderSchedulingOffset();

      var today = new Date();
      var future = new Date(today.getTime() + (60 * 1000 * offsetInMinutes));
      return future.toISOString();
    };

    return OrderService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('OrderCompletedController', function ($scope, MapHelper, uiGmapIsReady, $translate, OrderService,
                                                    TrackingService, $log, $rootScope, AuthenticationService, $state,
                                                    ORDER_STATUS, $timeout, ConfigurationService, $ionicPopup,
                                                    OrderCanceledHelper, DistributorsService, $stateParams) {
    ga_storage._trackPageview('OrderCompleted');

    $scope.eta = -1;
    $scope.loading = true;
    $scope.initialized = false;

    $scope.map = {};

    $scope.step = 'one';
    $scope._showingAlert = false;

    $scope.markers = [];
    $scope.googleMap = {};

    $scope.order = OrderService.getSavedOrder();
    if($scope.order && $scope.order.team_ids && $scope.order.team_ids.length){
      $scope.team = DistributorsService.getDistributorByExternalId($scope.order.team_ids[0].toString());
    }

    $scope.initContactPhone = function () {
      $scope.contactPhone = $scope.team && $scope.team.contact_phone ? $scope.team.contact_phone : ConfigurationService.getMerchantPhone();
    };

    $scope.initContactPhone();

    $scope.shouldAllowReturnToMainScreen = function(){
      return ConfigurationService.allowMultipleOrders() || ($scope.order && $scope.order.extras && $scope.order.extras.service_request_id);
    };

    $scope.allowMultipleOrders = $scope.shouldAllowReturnToMainScreen();


    $scope.getCart = function(){
      var inventories = $scope.order ? $scope.order.task_inventories : null;
      var cartItems = OrderService.getCartForActiveOrder();

      if (!inventories){
        return cartItems;
      }

      return $scope._matchPricesForInventories(cartItems, inventories);
    };

    $scope._matchPricesForInventories = function (cartItems, inventories) {
      var pricesChanged = false;
      _.each(cartItems, function(cartItem){
        if (cartItem.product) {
          var inventoryItem = _.find(inventories, function(item) {
            return cartItem.product.id === item.inventory_id;
          });

          if (inventoryItem && inventoryItem.price && inventoryItem.price !== cartItem.product.price) {
            cartItem.product.price = inventoryItem.price;
            pricesChanged = true;
          }
        }
      });

      if (pricesChanged){
        OrderService.storeCartItemsForOrder($scope.order ? $scope.order.id : OrderService.getActiveOrder().id, cartItems);
      }
      return cartItems;
    };

    $scope.cartItems = $scope.getCart();

    $scope.$on('order cancelled', function (event, orderId) {
      $log.debug('OrderCompletedController order cancelled ' + orderId);
      TrackingService.disconnect();

      if ($scope.order && $scope.order.id === orderId){
        if (!$scope.order.extras || !$scope.order.extras.service_request_id){
          $scope.onOrderCancelled(orderId);
        }
      }
    });

    $scope.$on('realtime failure', function(){
      $log.debug('OrderCompletedController order cancelled');
      TrackingService.disconnect();
      $ionicPopup.alert({template: $translate.instant('tracking_failure'), okText: $translate.instant('ok')});
    });

    $scope.$on('eta updated', function (event, value) {
      $log.debug('OrderCompletedController eta updated to ' + value);
      $scope.eta = value;

      $timeout(function () {
        $scope.$apply();
      }, 1);
    });

    $scope.customerMarker = null;
    $scope.driverMarker = null;

    $scope.$on('customer location updated', function(event, lat, lng){
      $scope.updateCustomerPin(lat, lng);
    });

    $scope.$on('driver location updated', function (event, location) {
      $log.debug('OrderCompletedController driver location updated' + location.lat() + '|' + location.lng());

      var map = $scope.googleMap.getGMap();

      if (!$scope.driverMarker) {
        $scope.driverMarker = new google.maps.Marker({
          position: location,
          map: map,
          icon: 'images/delivery-pin.png',
          optimized: true,
          draggable: false
        });
      } else {
        $scope.driverMarker.setPosition(location);
      }

      $scope.tracking = true;

      MapHelper.centerMapMulti(map, [$scope.driverMarker, $scope.customerMarker]);
      $timeout(function () {
        $scope.$apply();
      }, 1);
    });

    $scope.$on('order updated', function () {
      $scope.order = OrderService.getActiveOrder();
      $scope.cartItems = $scope.getCart();
      if ($scope.order) {
        $log.debug('OrderCompleteController.order update for order ' + $scope.order.id);
        $scope.updateCurrentStep();
        if($scope.order && $scope.order.team_ids && $scope.order.team_ids.length){
          $scope.team = DistributorsService.getDistributorByExternalId($scope.order.team_ids[0].toString());
        }
      } else {
        $log.error('OrderCompleteController.order update but not active order');
      }
    });

    $scope.$on('price updated', function(){
      $scope.order = OrderService.getActiveOrder();
      $scope.cartItems = $scope.getCart();
      if ($scope.order) {
        $log.debug('OrderCompleteController.price update for order ' + $scope.order.id);
      } else {
        $log.error('OrderCompleteController.price update but not active order');
      }
    });

    $scope.updateCurrentStep = function () {
      if (!$scope.order) {
        $log.debug('OrderCompletedController.updateCurrentStep - no order');
        return;
      }

      // this can happen if we support multiple trackings
      if ($scope.order.status === ORDER_STATUS.CREATED){
        $scope.step = 'one';
        $log.debug('OrderCompletedController.updateCurrentStep one');
        $scope.driverMarker = null;
        $scope.order.driver = null;
      }
      else if ($scope.order.status === ORDER_STATUS.ASSIGNED) {
        $scope.step = 'one';
        $log.debug('OrderCompletedController.updateCurrentStep assigned');
      } else if ($scope.order.status === ORDER_STATUS.ACCEPTED) {
        $scope.step = 'two';
        $log.debug('OrderCompletedController.updateCurrentStep accepted');
      } else if ($scope.order.status === ORDER_STATUS.ON_THE_WAY) {
        $scope.step = 'three';
        $log.debug('OrderCompletedController.updateCurrentStep started');
      } else if ($scope.order.status === ORDER_STATUS.CHECKED_IN) {
        $scope.step = 'four';
        $log.debug('OrderCompletedController.updateCurrentStep arrived');
      } else if ($scope.order.status === ORDER_STATUS.DONE) {
        $log.debug('OrderCompletedController.updateCurrentStep left');
        $rootScope.$broadcast('order done', $scope.order.id);
      } else {
        $log.debug('OrderCompletedController.updateCurrentStep with status ' + $scope.order.status);
      }

      $timeout(function () {
        $scope.$apply();
      }, 1);
    };


    $scope.updateCustomerPin = function (lat, lng) {

      if(!lat || !lng){
        return;
      }

      var map = $scope.googleMap.getGMap();

      var location = new google.maps.LatLng(lat, lng);
      $log.debug('OrderCompletedController.updateCustomerPin ' + location.lat() + ' | ' + location.lng());
      if (!$scope.customerMarker) {
        $scope.customerMarker = new google.maps.Marker({
          position: location,
          map: map,
          icon: 'images/customer-pin.png',
          optimized: true,
          draggable: false
        });
      } else {
        $scope.customerMarker.setPosition(location);
      }

      MapHelper.centerMapMulti(map, [$scope.customerMarker]);

      $timeout(function () {
        $scope.$apply();
      }, 1);
    };

    $scope.handleCancelOrder = function () {
      ga_storage._trackEvent('MainController', 'handleCancelOrder', 'click');
      $log.debug('OrderCompletedController.handleCancelOrder');
      $ionicPopup.confirm({
        title: $translate.instant('action_cancel'),
        template: $translate.instant('cancel_order_verification'),
        scope: $scope,
        cancelText: $translate.instant('cancel'),
        okText: $translate.instant('ok')
      }).then(function (res) {
        if (res) {
          var order = OrderService.getSavedOrder();
          if (order && order.id) {
            $log.debug('OrderCompletedController cancelling order ' + order.id);
            OrderService.cancelOrder(order.id).then(function () {
              $rootScope.$broadcast('order cancelled', {id: order.id});
              TrackingService.disconnect();
              $log.debug('OrderCompletedController cancelling success');
              $scope.showCancelledAlert(true);
              $state.go('categories');
            }, function () {
              $log.debug('OrderCompletedController cancelling failed');
              $scope.showCancelledAlert(false);
            });
          } else {
            $log.error('OrderCompletedController - could not cancel order - does not exist.');
            $scope.showCancelledAlert(false);
            $state.go('categories');
          }
        }
      });
    };

    $scope.handleNewOrder = function(){
      $log.debug('OrderCompletedController.handleNewOrder');
      $ionicPopup.confirm({
        title: $translate.instant('action_new_order'),
        template: $translate.instant('new_order_verification'),
        scope: $scope,
        cancelText: $translate.instant('cancel'),
        okText: $translate.instant('ok')
      }).then(function (res) {
        if (res) {
          $log.debug('OrderCompletedController going to new order');
          ga_storage._trackEvent('MainController', 'handleNewOrder', 'click-confirm');
          OrderService.clearSaved(true, true);
          $state.go('categories');
        } else {
          ga_storage._trackEvent('MainController', 'handleNewOrder', 'click-abort');
        }
      });
    };

    $scope.showCancelledAlert = function(success){
      OrderCanceledHelper.showCancelledAlert(success);
    };

    $scope.onOrderCancelled = function(orderId){
      OrderCanceledHelper.onOrderCancelled(orderId);
    };

    $scope.init = function(){
      $log.debug('OrderCompletedController. init called');
      $scope.initialized = true;

      // either use provided param of order id or use the last stored order if none provided.
      var order;
      var orderId = $stateParams.order_id;
      if (orderId){
        $log.debug('OrderCompletedController loaded for order id ' + orderId);
        order = OrderService.getOngoingOrderById(orderId);
        if (order){
          OrderService.saveOrder(order);
        } else {
          order = OrderService.getSavedOrder();
        }
      } else {
        order = OrderService.getSavedOrder();
      }

      if (!order){
        $log.debug('OrderService. init without valid order');
        $state.go('categories');
        return;
      }
      $scope.order = order;
      OrderService.setActiveOrder(order);

      if($scope.order && $scope.order.team_ids && $scope.order.team_ids.length){
        $scope.team = DistributorsService.getDistributorByExternalId($scope.order.team_ids[0].toString());
      }
      $scope.initContactPhone();
      $scope.allowMultipleOrders = $scope.shouldAllowReturnToMainScreen();

      // update the ui before polling if we already have a tracking on the status or switching between statuses
      if (orderId || (order && order.status !== ORDER_STATUS.CREATED && order.status !== ORDER_STATUS.ASSIGNED)){
        $scope.updateCurrentStep();
      }

      if(order && order.way_points && order.way_points.length){
        var wayPoint = $scope.order.way_points[0];
        $scope.updateCustomerPin(wayPoint.lat, wayPoint.lng);
      }

      TrackingService.connect(orderId !== null);
    };

    $scope._handleIonicViewEnter = function(){
      $log.debug('OrderCompletedController $ionicView.enter');

      $scope.map = {
        center: {latitude: AuthenticationService.currentUser().lat, longitude: AuthenticationService.currentUser().lng},
        zoom: 12,
        options: {disableDefaultUI: true, draggable: false}
      };

      if (!$scope.googleMap.getGMap){
        $log.debug('OrderCompletedScreen: googleMap.getGmap does not exist yet. waiting...');
        return;
      }

      $scope.init();
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);

    uiGmapIsReady.promise()
      .then(function () {
        $log.debug('OrderCompletedController.uiGmapIsReady');
        $scope.loading = false;
        if (!$scope.initialized){
          $scope.init();
        }
      });
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('MapHelper', function () {
    var MapHelper = {};

    MapHelper.centerMap = function (map, objectWithLocation) {
      var lat = null,
        lng = null;

      if (!_.isUndefined(objectWithLocation) && objectWithLocation.lat !== undefined && objectWithLocation.lat !== null &&
        objectWithLocation.lat !== 0 && objectWithLocation.lat !== 0) {
        lat = objectWithLocation.lat;
        lng = objectWithLocation.lng;
      }

      if (!_.isNull(lat) && !_.isNull(lng)) {
        map.setCenter(new google.maps.LatLng(lat, lng));
      }
    };

    MapHelper.centerMapMulti = function (map, markerArray) {
      if (markerArray.length === 0) {
        return;
      }
      var latlngbounds = new google.maps.LatLngBounds();

      _.each(markerArray, function (marker) {
        if (marker) {
          latlngbounds.extend(marker.getPosition());
        }
      });
      map.fitBounds(latlngbounds);
      map.setCenter(latlngbounds.getCenter());
    };

    MapHelper.removeMarkers = function (markers) {
      _.each(markers, function (marker) {
        marker.setMap(null);
      });

      markers.length = 0;
    };

    return MapHelper;
  });

/*global BringgSDK:false */

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('LoadingController', function ($scope, ConfigurationService, CountryCodeExtractor, AuthenticationService,
                                             $log, $state, $translate, $rootScope, $location, DynamicHostService,
                                             $ionicPopup, OrderService, OrderHelper, ORDER_STATUS, $ionicLoading,
                                             $window, TrackingService, CartService, DistributorsService, NetworkHelper,
                                             OrderCanceledHelper, NavigationHelper, ConfirmFoundLocationService,
                                             LocationUtil, DynamicLocationService, MERCHANT_CONFIG, ENV, $stateParams,
                                             LocationSelectMapService) {

    ga_storage._trackPageview('LoadingController');

    $scope.fetchingConfig = false;
    $scope.$watch(AuthenticationService.isLoggedIn, function () {
      if (NetworkHelper.validateNetwork() && CountryCodeExtractor.getCountryCode()) {
        $log.debug('LoadingController$watch.isLoggedIn: init hosts...');
        // dynamicHost.init always succeeds so we do not need to pass a failure function.
        DynamicHostService.init().then(function(){
          $scope._loadConfig();
        });
      } else {
        $log.debug('LoadingController$watch.isLoggedIn: no network or country code yet');
      }
    });

    $scope.$on('country code set', function () {
      $log.debug('LoadingController country code arrived');
      if (CountryCodeExtractor.getCountryCode()) {
        // dynamicHost.init always succeeds so we do not need to pass a failure function.
        DynamicHostService.init().then(function(){
          $scope._loadConfig();
        });
      }
    });

    $scope.handleViewEnter = function(){
      if (NetworkHelper.validateNetwork()) {
        $log.debug('LoadingController.$ionicView.enter called. network-on');
        // get the last used env
        var lastEnv = ConfigurationService.getLastEnv();
        if (lastEnv && lastEnv === 'staging'){
          $rootScope.isProduction = false;
        } else {
          $rootScope.isProduction = true;
        }
        $log.debug('env: ' + ($rootScope.isProduction ? 'production' : 'staging'));

        if ($rootScope.isDebug || $rootScope.isGlobalDemo || $rootScope.isLocalDemo) {
          DynamicHostService.init().then(function(){
            $scope._loadConfig();
          });
        } else if(ENV === 'development'){
          DynamicHostService.init().then(function(){

          }, function(){
            $scope._loadConfig();
          });
        } else if (!$scope.fetchingConfig) {
          $scope._loadConfig();
        }
      } else {
        $log.debug('LoadingController.$ionicView.enter called. network-off');
      }
    };

    $scope.$on('$ionicView.enter', $scope.handleViewEnter);

    $scope.merchantsPopup = null;
    $scope.data = {
      merchants: [],
      selected_merchant: null
    };

    $scope._loadConfig = function () {
      $log.debug('LoadingController loading config for ' + ($rootScope.isProduction ? 'production' : 'staging'));
      if (!AuthenticationService.isLoggedIn) {
        if(MERCHANT_CONFIG.MERCHANT_ID) {
          $scope._getMerchantConfig(MERCHANT_CONFIG.MERCHANT_ID, true);
        } else if ($stateParams.merchant_id){
          $scope._getMerchantConfig($stateParams.merchant_id, true);
        }
        else{
          var countryCode = CountryCodeExtractor.getCountryCode();
          if (countryCode) {
            $log.debug('LoadingController loading merchants for ' + countryCode);
            ConfigurationService.getMerchantsByCC(countryCode, $scope._onMerchantsLoaded);
          } else {
            $log.debug('LoadingController : no country code');
          }
        }
      } else {
        $scope._getMerchantConfig(AuthenticationService.currentUser().merchant_id);
      }
    };

    $scope._onMerchantsLoaded = function(merchants){
      if (!merchants || merchants.status === 0) {
        $scope._onGetConfigFailed('unknown',
          $translate.instant('error_failed_configuration'),
          $translate.instant('try_again'));

        return;
      }

      if (merchants.length === 0) {
        $log.debug('LoadingController merchants not loaded');
        $scope._changeState('no_service');
        return;
      }

      $log.debug('LoadingController merchants loaded');
      $scope.data.merchants = merchants;
      if (merchants.length > 1) {
        $scope._selectMerchantsDialog();
      } else {
        $scope.data.selected_merchant = merchants[0];
        $scope._setMerchantConfig();
      }
    };

    $scope.initLoggedInDataState = function (gotDistributorsCallback, currentLocation) {
      OrderService.clearSaved(true, true);
      OrderService.getOngoingOrders(true);
      DistributorsService.getDistributors(gotDistributorsCallback,
        currentLocation ? currentLocation : AuthenticationService.getLastUserLocation(),
        ConfigurationService.enableLocationBasedCatalog());
    };

    $scope.locating = false;
    $scope.initialLoggedInState = function(initData){
      if (ConfigurationService.enableLocationBasedCatalog()){
        $scope._hideSplash();
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "locating" | translate}}</p>'
        });

        if (!$scope.locating){
          $scope.locating = true;
          LocationUtil.locateMe(
            $scope._onLocatingSuccess,
            $scope._onLocatingFailed,
            {maximumAge: 30000, timeout: 5000, enableHighAccuracy: true},
            true
          );
        }
      } else {
        if (initData){
          $scope.initLoggedInDataState();
        }
        $scope._changeState('categories');
      }
    };

    $scope._onLocatingSuccess = function(position){
      $ionicLoading.hide();
      $scope.locating = false;
      LocationUtil.reverseGeocode({lat: position.coords.latitude, lng: position.coords.longitude}).then(function(results){
        $scope.approveLocation(position, results);
      });
    };

    $scope._showingAlert = false;
    $scope._onLocatingFailed = function(error){
      $log.error('LoadingController locating customer failed: ' + JSON.stringify(error));

      if ($scope.confirmLocationDialogOpen){
        $log.debug('LoadingController._onLocatingFailed: LocationSelectionDialogOpen already open');
        return;
      }

      $scope.locating = false;
      $ionicLoading.hide();
      if (!$scope._showingAlert){
        $scope._showingAlert = true;
        $ionicPopup.confirm({
          template: $translate.instant('error_getting_location'),
          cancelText: $translate.instant('cancel'),
          okText: $translate.instant('ok')
        }).then(function(res){
          $scope._showingAlert = false;
          if (res){
            $log.debug('LoadingController locating customer manually');
            $scope.approveLocation();
          } else {
            $log.debug('LoadingController customer refused location');
          }
        });
      }
    };

    $scope.confirmLocationDialogOpen = false;
    $scope.onLocationApproved = function(location){
      $scope.confirmLocationDialogOpen = false;
      var customerLocation, customerAddress;
      if (location && location.coords){
        customerLocation = {
          lat: location.coords.latitude,
          lng: location.coords.longitude
        };
        customerAddress = location.address;
      } else {
        $log.error('LoadingController.approveLocation - failed to obtain location');
        $ionicPopup.alert({
          title: $translate.instant('failed_to_find_distributors_nearby'),
          okText: $translate.instant('ok')
        });
        return;
      }

      DynamicLocationService.setCurrentLocation(customerLocation);
      DynamicLocationService.setCurrentAddress(customerAddress);
      $scope.initLoggedInDataState($scope._onDistributorsRetrieved, customerLocation);
    };

    $scope.onLocationRejected = function(){
      $scope.confirmLocationDialogOpen = false;
    };

    $scope.approveLocation = function(position, addresses){
      if ($scope.confirmLocationDialogOpen){
        $log.error('LoadingController.approveLocation - dialog already open');
        return;
      }

      $scope.confirmLocationDialogOpen = true;

      if (!position && !addresses){
        ConfirmFoundLocationService.open(position, addresses, true).then($scope.onLocationApproved, $scope.onLocationRejected);
      } else {
        LocationSelectMapService.open(position, addresses, true).then($scope.onLocationApproved, $scope.onLocationRejected);
      }
    };

    $scope._onDistributorsRetrieved = function(result){
      if (result && result.length){
        $log.debug('LoadingController. distributors loaded: ' + JSON.stringify(result));
        $scope._changeState('categories', {rebuild: true});
      } else {
        $log.debug('LoadingController.distributorsRetrieved - no distributors found');
        $ionicPopup.alert({
          title: $translate.instant('failed_to_find_distributors_nearby'),
          template: result && result.message ? result.message : '',
          okText: $translate.instant('ok')
        });
      }
    };

    $scope.goToRating = function(sharedLocationConfig){
      $scope._loadSharedLocationConfig(sharedLocationConfig);
      OrderService.getOngoingOrders(true);
      $scope._changeState('rating');
    };

    $scope._loadSharedLocationConfig = function (config) {
      $log.debug('LoadingController._loadSharedLocationConfig' + JSON.stringify(config));
      BringgSDK.setEventCallback({
        'taskRated': TrackingService.onTaskRatedCb
      });
      $window.MONITOR_END_POINT = DynamicHostService.realTimeHost;
      BringgSDK.setConfiguration(config);
    };

    $scope._selectMerchantsDialog = function () {
      $scope._hideSplash();
      if($scope.merchantsPopup){
        return;
      }
      $scope.merchantsPopup = $ionicPopup.show({
        template: '<div class="form-group"><select ng-model="data.selected_merchant" ng-options="sm as sm.name for sm in data.merchants" ng-change="_setMerchantConfig()" class="form-control"></div>',
        title: $translate.instant('select_city'),
        scope: $scope
      });
    };

    $scope._setMerchantConfig = function () {
      if ($scope.merchantsPopup) {
        $scope.merchantsPopup.close();
        $scope.merchantsPopup = null;
      }

      var merchant_id = $scope.data.selected_merchant.id;
      if ($scope.data.selected_merchant) {
        if (AuthenticationService.isLoggedIn) {
          $scope._getMerchantConfig(merchant_id);
        } else {
          // different handling of after config loaded in case not logged in
          $scope._getMerchantConfig(merchant_id, true);
        }
      }
    };

    $scope._getMerchantConfig = function(merchant_id, loggedOut) {
      $scope.fetchingConfig = true;
      ConfigurationService.getConfigurationForMerchant(merchant_id, function (configurationResult) {
        $scope.fetchingConfig = false;
        if (configurationResult) {
          if (configurationResult.success){
            $log.debug('LoadingController config loaded for ' + merchant_id);

            if (ConfigurationService.shouldForceUpgrade()){
              $log.debug('LoadingController force upgrade ' + merchant_id);
              $scope.forceUpgrade();
              return;
            }

            if (loggedOut){
              $scope._changeState('login');
            } else {
              $scope.onMerchantConfigLoaded();
            }
          } else {

            if(configurationResult.status === 401){
              $state.go('logout');
            } else {
              $scope._onGetConfigFailed(merchant_id,
                $translate.instant('error_failed_configuration'),
                $translate.instant('try_again'));
            }
          }
        } else {
          $scope._onGetConfigFailed(merchant_id,
            $translate.instant('error_no_connection'),
            $translate.instant('try_again'));
        }
      });
    };

    $scope.handleOrderRestored = function(order, cart, sharedLocationConfig) {
      if (!order) {
        $log.error('LoadingController task from the server is no longer available');
        $scope.initialLoggedInState(true);
      } else if (order.status === ORDER_STATUS.CANCELLED) {
        if (cart) {
            $log.debug('LoadingController task from server was canceled');
            $scope.initialLoggedInState();
            OrderCanceledHelper.onOrderCancelled();
          } else {
            $log.debug('LoadingController task from local storage was already finished');
            $scope.initialLoggedInState(true);
          }
      } else if (order.status === ORDER_STATUS.DONE) {
        if (sharedLocationConfig) {
          $log.debug('LoadingController task from the local storage is done and should be rated');
          $scope.goToRating(sharedLocationConfig);
        } else {
          $log.error('LoadingController task from the local storage is done but no shared location configuration');
          $scope.initialLoggedInState(true);
        }
      } else {
        $log.debug('LoadingController task from the local storage is still in progress');
        DistributorsService.getDistributors(null, DynamicLocationService.getCurrentLocation() ?
          DynamicLocationService.getCurrentLocation() : AuthenticationService.getLastUserLocation());
        OrderService.saveOrder(order);
        OrderService.getOngoingOrders(true);
        $scope._changeState('order_completed');
      }
    };

    $scope.onMerchantConfigLoaded = function(){
      $rootScope.$broadcast('config updated');
      var sharedLocationConfig = OrderService.getSharedLocationConfig();
      var localOrder = OrderService.getSavedOrder();
      var cart = CartService.restore();

      // order is done and we have shared location config for rating
      if (localOrder && localOrder.status === ORDER_STATUS.DONE && sharedLocationConfig) {
        $log.debug('LoadingController task from the local storage is done and should be rated');
        $scope.goToRating(sharedLocationConfig);
      }
      // order was cancelled and we have our cart so we can resubmit
      else if (localOrder && localOrder.status === ORDER_STATUS.CANCELLED && cart) {
        $scope.initialLoggedInState();
        OrderCanceledHelper.onOrderCancelled();
      }
      // if order exists locally and is not done - fetch it from server to make sure to have the most updated status.
      else if (localOrder && !OrderHelper.isDone(localOrder)) {
        $log.debug('LoadingController found task in local storage with status ' + localOrder.status);
        OrderService.getOrderFromServer(localOrder.id).then(function (result) {
          $log.debug('LoadingController retrieved status from server: ' + (result ? result.status : -1));
          $scope.handleOrderRestored(result, cart, sharedLocationConfig);
        }, function(reason){
          $log.debug('LoadingController - failed getting status from server. reason: ' + reason);
          $scope.handleOrderRestored(localOrder, cart, sharedLocationConfig);
        });
      } else if ($rootScope.savedPath) {
          // if there is no order stored locally or it is done/canceled.
          if ($rootScope.savedPath === '/loading' || $rootScope.savedPath === '/order_completed') {
            $scope.initialLoggedInState(true);
          } else {
            // make sure to clear all caching including the visuals.
            $scope.initLoggedInDataState();
            $location.path($rootScope.savedPath);
          }
          $rootScope.savedPath = null;
      } else {
        $scope.initialLoggedInState(true);
      }
    };

    $scope._changeState = function(state, params){
      $state.go(state, params).then(function(){
        $scope._hideSplash();
      });
    };

    $scope._hideSplash = function(){
      if(navigator && navigator.splashscreen){
        navigator.splashscreen.hide();
      }
    };

    $scope.showing = false;
    $scope._onGetConfigFailed = function(merchant_id, title, message){
      $log.error('error loading config for ' + merchant_id);
      if (!$scope.showing){
        $scope.showing = true;
        $scope._hideSplash();
        $ionicPopup.confirm({
          title: title,
          template:  message,
          okText: $translate.instant('ok'),
          cancelText: $translate.instant('cancel')
        }).then(function(res){
          $scope.showing = false;
          if (res){
            $log.debug('LoadingController.onGetConfigFailed - try again');
            window.location.reload(true);
          } else if (AuthenticationService.isLoggedIn){
            $log.debug('LoadingController.onGetConfigFailed - logged-in, dont try');
          } else {
            $log.debug('LoadingController.onGetConfigFailed - logged-out, dont try');
            $scope._changeState('login');
          }
        });
      }
    };

    $scope.forceUpgrade = function(){
      $scope._hideSplash();
      $ionicPopup.alert({
        title: $translate.instant('force_upgrade_title'),
        template: $translate.instant('force_upgrade_message'),
        okText: $translate.instant('ok')
      }).then(function(){
        $scope.goToMarket($rootScope.platform);
        if(navigator.app) {
          navigator.app.exitApp();
        }
      });
    };

    $scope.goToMarket = function(platform){
      var marketLink = 'market://details?id=com.bringg.cocacola';
      if (platform){
        if (platform === 'iOS'){
          marketLink = 'itms-apps://itunes.apple.com/app/id1017704525?mt=8';
        } else if (platform === 'Android'){
          marketLink = 'market://details?id=com.bringg.cocacola';
        }
      }

      NavigationHelper.navigateToUrl(marketLink, platform);
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .directive('rating', function () {
    return {
      restrict: 'E',
      scope: {
        rating: '=',
        interactive: '='
      },
      templateUrl: 'scripts/common/directives/rating-directive.html',
      link: function (scope) {
        scope.handleStarClicked = function (index) {
          if (!scope.interactive) {
            return;
          }
          scope.rating = index.toString();
        };
      }
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('SelectDistributorMapController', function ($scope, uiGmapIsReady, $state, AuthenticationService,
                                                          DistributorsService, $ionicLoading, $log, MapHelper,
                                                          $timeout, CartService) {
    ga_storage._trackPageview('SelectDistributorMap');
    $scope.map = {
      center: {latitude: AuthenticationService.currentUser().lat, longitude: AuthenticationService.currentUser().lng},
      zoom: 12,
      options: {disableDefaultUI: true, draggable: true}
    };

    $scope.Math = Math;

    $ionicLoading.show({
      template: '<ion-spinner></ion-spinner><p>{{:: "loading" | translate}}</p>'
    });

    $scope.markers = [];
    $scope.googleMap = {};

    $scope.handleListButtonClick = function () {
      ga_storage._trackEvent('SelectDistributorMapController', 'handleListButtonClick', 'click');
      $log.debug('SelectDistributorMapController.handleListButtonClick');
      $state.go('select_distributor');
    };

    $scope.handleBackClick = function () {
      ga_storage._trackEvent('SelectDistributorMapController', 'handleBackClick', 'click');
      $log.debug('SelectDistributorMapController.handleBackClick');
      $state.go('cart');
    };

    $scope._handleIsLoggedIn = function(){
      $log.debug('SelectDistributorMapController AuthenticationService.isLoggedIn');
      if (AuthenticationService.isLoggedIn) {
        $scope._loadData(function () {
          $ionicLoading.hide();
          $scope._renderDistributor();
        });
      }
    };

    $scope.$watch(AuthenticationService.isLoggedIn, $scope._handleIsLoggedIn);

    $scope._loadData = function (callback) {
      $log.debug('SelectDistributorMapController._loadData');
      DistributorsService.getDistributors(function (distributors) {
        if (distributors && distributors.length){
          $scope.distributors = distributors;
          $scope.distributorsLoaded = true;
        }
        $scope.checkIfLoading();
        if (callback) {
          callback();
        }
      });
    };

    $scope.mapLoaded = false;
    $scope.distributorsLoaded = false;
    $scope.checkIfLoading = function () {
      if ($scope.mapLoaded && $scope.distributorsLoaded) {
        $scope.loading = false;
      } else {
        $scope.loading = true;
      }
    };

    $scope._distributorsMarkers = [];
    $scope._distributorsRendered = false;
    $scope._renderDistributor = function () {
      $log.debug('SelectDistributorMapController._renderDistributor called');

      if ($scope.loading) {
        $log.debug('SelectDistributorMapController._renderDistributor returned');
        return;
      }

      var map = $scope.googleMap.getGMap();
      _.each($scope.distributors.slice(0,10), function (distributor) {

        var location = new google.maps.LatLng(distributor.lat, distributor.lng);
        var marker = new google.maps.Marker({
          position: location,
          map: map,
          icon: 'images/delivery-pin.png',
          optimized: true,
          draggable: false
        });

        var listenrId = google.maps.event.addListener(marker, 'click', function () {
          $scope.markerClicked(marker);
        });
        marker.set('distributor_id', distributor.id);
        marker.set('listener_id', listenrId);

        $scope._distributorsMarkers.push(marker);
      });

      MapHelper.centerMapMulti(map, $scope._distributorsMarkers);
      map.setZoom(map.getZoom() - 1);
      $scope._distributorsRendered = true;
    };

    $scope.markerClicked = function (marker) {
      $log.debug('SelectDistributorMapController.marcherClicked');

      $scope.selectedDistributor = _.find($scope.distributors, function (distributor) {
        return distributor.id === marker.distributor_id;
      });

      $timeout(function () {
        $scope.$apply();
      }, 1);
    };

    $scope.handleSelectClicked = function () {
      $log.debug('SelectDistributorMapController.handleSelectClicked');
      CartService.setSelectedDistributor($scope.selectedDistributor);
      $state.go('cart');
    };

    $scope.handleCenterMapClicked = function () {
      ga_storage._trackEvent('SelectDistributorMapController', 'handleCenterMapClicked', 'click');
      var map = $scope.googleMap.getGMap();
      MapHelper.centerMapMulti(map, $scope._distributorsMarkers);
      map.setZoom(map.getZoom() - 1);
    };

    $scope._ionicViewEnter = function () {
      $log.debug('SelectDistributorMapController $ionicView.enter');
      if ($scope._distributorsRendered) {
        $scope.handleCenterMapClicked();
      } else {
        $scope._renderDistributor();
      }
    };

    $scope.$on('$ionicView.enter', $scope._ionicViewEnter);

    $scope._uiGmapIsReady = function(){
      $log.debug('SelectDistributorMapController.uiGmapIsReady');
      $scope.mapLoaded = true;
      $scope.checkIfLoading();
      $scope._renderDistributor();
    };

    uiGmapIsReady.promise().then($scope._uiGmapIsReady);
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('RatingController', function ($scope, $translate, $log, $state, $rootScope, $ionicPopup,
                                            ConfigurationService, TrackingService, OrderService, $ionicLoading,
                                            DistributorsService) {
    ga_storage._trackPageview('Rating');
    $scope.data = {
      rating: 0,
      force_rating: ConfigurationService.forceRating()
    };

    $scope.sending = false;

    $scope.handleRateButtonClick = function () {
      ga_storage._trackEvent('RatingController', 'handleRateButtonClick', 'click');
      $log.debug('RatingController:handleRateButtonClick');
      if (!$scope.data.rating) {
        $ionicPopup.alert({
          template: $translate.instant('rating_box_label'),
          okText: $translate.instant('ok')
        });
        return;
      }

      $scope.sending = true;
      $ionicLoading.show();
      TrackingService.rate($scope.data.rating);
    };

    $scope._handleTaskRated = function(){
      $ionicLoading.hide();
      $scope.onOrderDone();
    };

    $scope.$on('task rated', $scope._handleTaskRated);

    $scope.handleNoThanksButtonClick = function () {
      ga_storage._trackEvent('RatingController', 'handleNoThanksButtonClick', 'click');
      $log.debug('RatingController:handleNoThanksButtonClick');
      $scope.onOrderDone();
    };

    $scope.onOrderDone = function () {
      $scope.sending = false;
      $ionicLoading.hide();
      OrderService.clearSaved(true);

      if (ConfigurationService.enableLocationBasedCatalog()){
        DistributorsService.clearAll();
        $state.go('loading');
      } else {
        $state.go('categories', {rebuild: true});
      }
    };
  });

'use strict';


angular.module('cocaColaCordovaApp')
  .constant('HOST_FILE_URL', {
    'REMOTE_PATH': 'https://s3.amazonaws.com/bringg-hosts/coca-cola-app.json',
    'LOCAL_PATH': 'host_file'
  })
  .factory('DynamicHostService', function ($http, $q, $log, $rootScope, localStorageService,
                                           REALTIME_END_POINT,  HOST_FILE_URL, ENV, REALTIME_STAGING_END_POINT) {
    var DynamicHostService = {};

    DynamicHostService.realTimeHost = REALTIME_END_POINT;

    DynamicHostService.init = function () {
      var deferred = $q.defer();

      if(ENV === 'development'){
        deferred.reject();
        return deferred.promise;
      }

      DynamicHostService._getHostsFile().then(function (json) {
        $log.debug('DynamicHostService get hosts succeeded');
        DynamicHostService._extractHosts(json, function(){
          deferred.resolve();
        });
      }, function () {
        $log.error('DynamicHostService get hosts failed - using storage');
        DynamicHostService._extractHosts(localStorageService.get(HOST_FILE_URL.LOCAL_PATH), function(){
          // in any case we succeed in obtaining a host so we call resolve and not reject.
          deferred.resolve();
        });
      });

      return deferred.promise;
    };

    DynamicHostService._getHostsFile = function () {
      var deferred = $q.defer();
      if(ENV === 'development'){
        deferred.reject();
        return deferred.promise;
      }

      var req = {
        method: 'GET',
        url: HOST_FILE_URL.REMOTE_PATH
      };

      $http(req).then(function (result) {
        $log.debug('RESULT: ' + JSON.stringify(result));
        if (result.data && result.data.status === 'error') {
          deferred.reject(result.data);
        } else {
          deferred.resolve(result.data);
        }
      }, function (reason) {
        if (reason.message) {
          $log.error('ERROR: ' + reason.message);
        } else {
          $log.error(reason);
        }

        deferred.reject(reason);
      });

      return deferred.promise;
    };

    DynamicHostService._extractHosts = function (json, callback) {
      if (json && !_.isUndefined(json)) {
        localStorageService.set(HOST_FILE_URL.LOCAL_PATH, json);
        var hosts;
        if ($rootScope.isProduction) {
          hosts = json.production;
        } else {
          hosts = json.staging;
          if (hosts && hosts.merchant_id) {
            $log.debug('staging merchant id set to ' + hosts.merchant_id);
            $rootScope.staging_merchant_id = hosts.merchant_id;
          } else {
            $log.debug('no staging merchant id will use default');
          }
        }

        if (hosts) {
          if (hosts.real_time_url) {
            DynamicHostService.realTimeHost = hosts.real_time_url;
          }
        }
      } else {
        $log.warn('unable to obtain host file - using default');
        if ($rootScope.isProduction){
          DynamicHostService.realTimeHost = REALTIME_END_POINT;
        } else {
          DynamicHostService.realTimeHost = REALTIME_STAGING_END_POINT;
        }
      }

      if(callback){
        callback();
      }
    };

    return DynamicHostService;
  });


/*global BringgSDK:false */

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('REALTIME_EVENTS', {
    'ORDER_UPDATE': 'order update'
  })
  .factory('TrackingService', function (OrderService, REALTIME_EVENTS, $rootScope, $log, RealTimeWebService,
                                          AuthenticationService, MERCHANT_CONFIG, ORDER_STATUS) {
    var TrackingService = {};

    TrackingService.connect = function (forceReconnect) {
      if (BringgSDK.isConnected() && !forceReconnect) {
        $log.debug('TrackingService.connect: socket already connected');
        return;
      }

      $log.debug('TrackingService.connect: connecting...');

      var access_token = AuthenticationService.currentUser() ? AuthenticationService.currentUser().access_token : null;
      if (!access_token){
        $log.error('invalid credentials for tracking');
        return;
      }

      // set current destination in sdk.
      var order = OrderService.getSavedOrder();
      if (order){
        if (order.way_points && order.way_points.length) {
          var newLat = order.way_points[0].lat;
          var newLng = order.way_points[0].lng;
          if (newLat !== 0 && newLng !== 0){
            BringgSDK.setDestination(newLat, newLng);
          }
        }
      } else {
        $log.error('no order found for tracking');
        return;
      }

      // initialize with app credentials.
      // currently not used
      BringgSDK.initializeBringg({token : MERCHANT_CONFIG.APP_TOKEN});

      // connect with customer credentials
      BringgSDK.connect(access_token, TrackingService.onConnect, TrackingService.onDisconnect);
    };

    TrackingService.disconnect = function () {
      $log.debug('TrackingService.disconnect');
      BringgSDK.disconnect();
    };


    TrackingService.rate = function (value) {
      $log.debug('TrackingService.rate');
      BringgSDK.submitRating(value);
    };

    // =================================================

    TrackingService._handleOrderUpdate = function (order) {
      if (!order){
        $log.error('order update: no data');
        return;
      } else if (_.isUndefined(order.status)){
        $log.error('order update: no status in ' + JSON.stringify(order));
        return;
      }

      OrderService.saveOrder(order);

      if (order.status === ORDER_STATUS.CANCELLED) {
        TrackingService.onOrderCanceledCb(order.id);
        TrackingService.disconnect();
        return;
      }

      if (order.status === ORDER_STATUS.DONE) {
        TrackingService.onOrderDoneCb();
        TrackingService.disconnect();
        return;
      }

      $log.debug('TrackingService.got order update ' + order.status);
    };

    TrackingService._updateSharedLocation = function (shared_location) {
      if (shared_location) {
        $log.debug('TrackingService.updateSharedLocation : ' + JSON.stringify(shared_location));
        var order = OrderService.getSavedOrder();
        order.shared_location = shared_location;
        OrderService.saveOrder(order);
        OrderService.storeSharedLocationConfig(shared_location, order.id);
      }
    };

    // ==================================================
    // ============= BRINGG SDK callbacks ===============

    TrackingService.onConnect = function () {
      $log.debug('TrackingService.onConnect');

      var order = OrderService.getSavedOrder();
      if (order) {
        BringgSDK.watchOrder({
          order_uuid: order.uuid,
          way_point_id: order.active_way_point_id,
          share_uuid: order.shared_location ? order.shared_location.uuid : null
        }, function (result) {
          if (result) {
            $log.debug('Subscribed to watch order: ' + result.success);

            if (_.isUndefined(result.success) || result.success === true){
              TrackingService._updateSharedLocation(result.shared_location);
            } else {
              $rootScope.$broadcast('realtime failure');
            }
          }
        });
      } else {
        $log.debug('socket connected but no order available');
        TrackingService.disconnect();
      }
    };

    TrackingService.onDisconnect = function(){
      $log.debug('TrackingService.onDisconnect');
    };

    TrackingService.onTaskRatedCb = function () {
      $log.debug('TrackingService.onTaskRatedCb');
      $rootScope.$broadcast('task rated');
    };

    TrackingService.etaUpdateCb = function (eta) {
      $log.debug('TrackingService.etaUpdateCb ' + eta);
      if (eta) {
        $rootScope.$broadcast('eta updated', eta);
      }
    };

    TrackingService.locationUpdateCb = function (location) {
      $log.debug('TrackingService.locationUpdateCb ' + location);
      if (!location.lat() || !location.lng()) {
        return;
      }

      $rootScope.$broadcast('driver location updated', location);
    };

    TrackingService.orderUpdateCb = function(order){
      var currentOrder = OrderService.getSavedOrder();

      if (order.way_points && order.way_points.length && currentOrder.way_points && currentOrder.way_points.length) {
        var newLat = order.way_points[0].lat;
        var newLng = order.way_points[0].lng;
        if (newLat !== 0 && newLng !== 0 && (newLat !== currentOrder.way_points[0].lat || newLng !== currentOrder.way_points[0].lng)){
          TrackingService.onCustomerLocationChanged(newLat, newLng);
        }
      }

      TrackingService._handleOrderUpdate(order);
    };

    TrackingService.onCustomerLocationChanged = function(lat, lng){
      $log.debug('customer location updated');
      $rootScope.$broadcast('customer location updated', lat, lng);
      BringgSDK.setDestination(lat, lng);
    };

    TrackingService.onOrderDoneCb = function() {
      $log.debug('TrackingService.onOrderDone');
      $rootScope.$broadcast('order done');
    };

    TrackingService.onOrderCanceledCb = function(orderId) {
      $log.debug('TrackingService.onOrderCancelled');
      $rootScope.$broadcast('order cancelled', orderId);
    };

    BringgSDK.setLocationUpdateCb(TrackingService.locationUpdateCb);
    BringgSDK.setETAUpdateCb(TrackingService.etaUpdateCb);
    BringgSDK.setOrderUpdateCb(TrackingService.orderUpdateCb);

    BringgSDK.setEventCallback({
      'taskRatedCb': TrackingService.onTaskRatedCb,
      'taskEndedCb': TrackingService.onOrderDoneCb
    });

    return TrackingService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('PromotionService', function ($log, $translate, localStorageService, $ionicPopup, $rootScope, NavigationHelper) {

    var PromotionService = {};

    PromotionService.launchPromotion = function(url){
      if (url) {
        $log.debug('PromotionService: redirecting to ' + url);
        localStorageService.remove('promotion');
        ga_storage._trackEvent('PromotionService', 'promotionNotification', 'click');

        NavigationHelper.navigateToUrl(url, $rootScope.platform);
      } else {
        $log.debug('PromotionService: no promotion');
      }
    };

    PromotionService.promptPromotion = function(url, notification_message){
      if (url) {
        var message = (notification_message && notification_message.length > 0 ) ? notification_message : $translate.instant('view_promotion');
        $ionicPopup.confirm({
          template : message
        }).then(function (res) {
          if (res) {
            ga_storage._trackEvent('PromotionService', 'promotionPopup', 'click ok');
            PromotionService.launchPromotion(url);
          } else {
            ga_storage._trackEvent('PromotionService', 'promotionPopup', 'click cancel');
          }
        });
      } else {
        $log.error('PromotionService.prompt: no url provided');
      }
    };

    return PromotionService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('OrderHelper', function (ORDER_STATUS) {
    var OrderHelper = {};

    OrderHelper.isActive = function (order) {
      if (!order) {
        return false;
      }
      return [ORDER_STATUS.ON_THE_WAY, ORDER_STATUS.CHECKED_IN].indexOf(order.status) !== -1;
    };

    OrderHelper.isDone = function (order) {
      if (!order) {
        return false;
      }
      return [ORDER_STATUS.DONE, ORDER_STATUS.CANCELLED].indexOf(order.status) !== -1;
    };

    OrderHelper.shouldChangeStatus = function(existingOrder, newStatus){
      // if order is done or the same status then do nothing.
      if (!existingOrder || OrderHelper.isDone(existingOrder) || existingOrder.status === newStatus){
        return false;
      }

      switch (newStatus){
        // if new status is terminating order or assigned
        case ORDER_STATUS.CANCELLED:
        case ORDER_STATUS.DONE:
        // checkin in this case can only occur after order is started/assigned so allow it always.
        case ORDER_STATUS.CHECKED_IN:
        // always allow assigned status for re-assign flow.
        case ORDER_STATUS.ASSIGNED:
          return true;
        // allow only if not already checked-in
        case ORDER_STATUS.ON_THE_WAY:
          return existingOrder.status !== ORDER_STATUS.CHECKED_IN;
        // allow only if order hasn't been started already
        case ORDER_STATUS.ACCEPTED:
          return !OrderHelper.isActive(existingOrder);
        default:
          return false;
      }
    };

    OrderHelper.guid = function() {
      function s4() {
        return Math.floor((1 + Math.random()) * 0x10000)
          .toString(16)
          .substring(1);
      }
      return s4() + s4() + '-' + s4() + '-' + s4() + '-' +
        s4() + '-' + s4() + s4() + s4();
    };


    return OrderHelper;
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .factory('NavigationHelper', function ($log, $ionicPopup, $translate, ConfigurationService, $state) {
    var NavigationHelper = {};

    NavigationHelper._goodPaths = ['login', 'categories', 'loading', 'order_completed', 'no_service', 'login_social'];
    NavigationHelper._badBackPaths = ['order_completed', 'loading', 'login', 'logout', 'remind', 'register', 'rating',
      'credit_card', 'history', 'order_details'];
    NavigationHelper.handleBackPress = function (history) {
      if (!history || !history.currentView){
        $log.debug('no history available');
        navigator.app.exitApp();
        return;
      }

      $log.debug('current screen : ' + history.currentView.stateName);

      if (_.includes(NavigationHelper._goodPaths, history.currentView.stateName)) {
        navigator.app.exitApp();
      } else if (history.currentView.stateName === 'rating') {
        if (ConfigurationService.forceRating()) {
          $ionicPopup.alert({
            template: $translate.instant('rate_us')
          });
        } else {
          navigator.app.exitApp();
        }
      } else if(history.currentView.stateName === 'confirm'){
        if(navigator && navigator.home && navigator.home.home){
          navigator.home.home(function(){
            console.info('Successfully launched home intent');
          }, function(){
            console.error('Error launching home intent');
          });
        }
      } else if(history.forwardView && _.includes(NavigationHelper._badBackPaths, history.forwardView.stateName)){
        $log.debug('forward screen : ' + history.forwardView.stateName);
        $state.go('categories');
      } else {
        navigator.app.backHistory();
      }
    };

    NavigationHelper.navigateToUrl = function(url, platform){
      if(platform && platform === 'Android' && navigator.app) {
        navigator.app.loadUrl(url, { openExternal:true });
      } else {
        window.open(url, '_system');
      }
    };

    return NavigationHelper;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('NetworkHelper', function ($translate, $ionicPopup, $log) {
    var NetworkHelper = {};

    NetworkHelper._isConnected = true;
    NetworkHelper._isShowing = false;

    NetworkHelper.init = function(){

      document.addEventListener('offline', function () {
        NetworkHelper.setConnected(false);
      }, false);

      document.addEventListener('online', function () {
        NetworkHelper.setConnected(true);
      }, false);

      var isConnected = navigator.connection.type !== 'none';
      $log.debug('app connected: ' + isConnected);
      NetworkHelper.setConnected(isConnected);
    };

    NetworkHelper.isConnected = function(){
      return NetworkHelper._isConnected;
    };

    NetworkHelper.setConnected = function(isConnected){
      $log.debug('network status changed to: ' + isConnected);
      NetworkHelper._isConnected = isConnected;
    };

    NetworkHelper.validateNetwork = function () {
      if (NetworkHelper._isConnected){
        return true;
      } else {
        NetworkHelper._showNoNetworkAlert();
        return false;
      }
    };

    NetworkHelper._showNoNetworkAlert = function(){
      if (!NetworkHelper._isShowing) {
        NetworkHelper._isShowing = true;
        $ionicPopup.alert({
          title: $translate.instant('error_no_connection')
        }).then(function(){
          NetworkHelper._isShowing = false;
        });
      }
    };


    return NetworkHelper;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('OrderCanceledHelper', function ($translate, $ionicPopup, OrderService, $state, $log) {
    var OrderCanceledHelper = {};

    OrderCanceledHelper._showingAlert = false;

    OrderCanceledHelper.showCancelledAlert = function(success){
      if (!OrderCanceledHelper._showingAlert) {
        OrderCanceledHelper._showingAlert = true;
        if (success) {
          $ionicPopup.alert({title: $translate.instant('order_canceled'), okText: $translate.instant('ok')}).then(function(){
            OrderCanceledHelper._showingAlert = false;
          });
        } else {
          $ionicPopup.alert({title: $translate.instant('cancel_order_failure'), okText: $translate.instant('ok')}).then(function(){
            OrderCanceledHelper._showingAlert = false;
          });
        }
      }
    };

    OrderCanceledHelper.onOrderCancelled = function(){
      if (!OrderCanceledHelper._showingAlert){
        OrderCanceledHelper._showingAlert = true;
        $ionicPopup.confirm({
          title: $translate.instant('order_canceled'),
          template : $translate.instant('dialog_message_order_could_not_be_delivered'),
          cancelText: $translate.instant('cancel'),
          okText: $translate.instant('ok')
        }).then(function(res){
          if (res){
            $log.debug('OrderService: resubmit selected');
            OrderService.clearSaved();
            $state.go('cart');
          } else {
            $log.debug('OrderService: no resubmit');
            OrderService.clearSaved(true, true);
            $state.go('categories');
          }
          OrderCanceledHelper._showingAlert = false;
        });
      }
    };


    return OrderCanceledHelper;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .directive('gesture', function ($ionicGesture) {
    return {
      restrict: 'A',
      link: function (scope, elem) {
        $ionicGesture.on('doubletap', function () {
          scope.doubleTap();
        }, elem);
      }
    };
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .filter('currency', function (ConfigurationService) {
    return function (number) {
      var currencyCode = ConfigurationService.getCurrencyId();
      var currency = {
        USD: '$',
        CAD: '$',
        AUD: '$',
        GBP: '£',
        EUR: '€',
        EURO: '€',
        ILS: '₪',
        VND: 'VND',
        MIXED: '~',
        PHP: '₱',
        CLP: '$'
      };

      var thousand;
      var decimal;
      var format;

      if (_.indexOf(['USD', 'AUD', 'CAD', 'MIXED', 'ILS', 'PHP'], currencyCode) >= 0) {
        thousand = ',';
        decimal = '.';
        format = '%s%v';
      } else {
        thousand = '.';
        decimal = ',';
        format = '%s%v';
      }
      var dec = 2;
      if (_.indexOf(['CLP'], currencyCode) >= 0) {
        dec = 0;
      }

      return accounting.formatMoney(number, currency[currencyCode], dec, thousand, decimal, format);
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .constant('DB_CONSTANTS', {
    'DB_NAME': 'coca-cola.db',
    'DB_LOCATION': 2,
    'DB_VERSION': 3,
    'SCHEMA_VERSION_TABLE_NAME': 'schema_version',
    'ORDERS_TABLE_NAME': 'orders',
    'ORDER_INVENTORY_TABLE_NAME': 'order_inventory',
    'DRIVERS_TABLE_NAME': 'drivers',
    'VERSION_COL_NAME': 'version'
  })
  .factory('DBService', function (DB_CONSTANTS, $q, $log, CipherUtil) {
    var DBService = {};


    // ====================================================
    // sql statement
    // ====================================================

    var CREATE_SCHEMA_TABLE_SQL = 'CREATE TABLE ' + DB_CONSTANTS.SCHEMA_VERSION_TABLE_NAME + '(' +
      DB_CONSTANTS.VERSION_COL_NAME + ' integer)';

    var ADD_VERSION_NUMBER_SQL = 'INSERT INTO ' + DB_CONSTANTS.SCHEMA_VERSION_TABLE_NAME +
      '(' + DB_CONSTANTS.VERSION_COL_NAME + ') values (?)';

    var CREATE_ORDERS_TABLE_SQL = 'CREATE TABLE IF NOT EXISTS ' + DB_CONSTANTS.ORDERS_TABLE_NAME + '(' +
      'id integer primary key, ' +
      'total_price integer, ' +
      'asap integer, ' +
      'driver_id integer, ' +
      'team_id integer, ' +
      'lat real, ' +
      'lng real, ' +
      'address text, ' +
      'delivered_at text, ' +
      'status integer' +
      ')';

    var CREATE_DRIVERS_TABLE_SQL = 'CREATE TABLE IF NOT EXISTS ' + DB_CONSTANTS.DRIVERS_TABLE_NAME + '(' +
      'id integer primary key, name text, phone text, rating integer' +
      ')';

    var CREATE_ORDER_INVENTORY_TABLE_SQL = 'CREATE TABLE IF NOT EXISTS ' + DB_CONSTANTS.ORDER_INVENTORY_TABLE_NAME + '(' +
      'order_id integer, product_id integer, product_name text, product_price real, quantity integer' +
      ')';

    var GET_SCHEMA_VERSION_SQL = 'SELECT ' + DB_CONSTANTS.VERSION_COL_NAME + ' FROM ' + DB_CONSTANTS.SCHEMA_VERSION_TABLE_NAME;

    var GET_ORDERS =      'SELECT id, total_price, asap, team_id, driver_id, lat, lng, address, delivered_at, status FROM ' + DB_CONSTANTS.ORDERS_TABLE_NAME;

    var GET_ORDER_BY_ID = 'SELECT id, total_price, asap, team_id, driver_id, lat, lng, address, delivered_at, status FROM ' + DB_CONSTANTS.ORDERS_TABLE_NAME + ' WHERE id = ?';

    var GET_DRIVER_BY_ID = 'SELECT id, name, phone, rating FROM ' + DB_CONSTANTS.DRIVERS_TABLE_NAME + ' WHERE id = ?';

    var GET_INVENTORY_FOR_ORDER_ID = 'SELECT product_id, product_name, product_price, quantity FROM ' + DB_CONSTANTS.ORDER_INVENTORY_TABLE_NAME + ' WHERE order_id = ?';

    var ADD_ORDER_SQL = 'INSERT INTO ' + DB_CONSTANTS.ORDERS_TABLE_NAME + '(id, total_price, asap, team_id, driver_id, lat, lng, address, delivered_at, status) values (?,?,?,?,?,?,?,?,?,?)';
    var ADD_DRIVER_SQL = 'INSERT INTO ' + DB_CONSTANTS.DRIVERS_TABLE_NAME + '(id, name, phone, rating) values (?,?,?,?)';
    var ADD_INVENTORY_SQL = 'INSERT INTO ' + DB_CONSTANTS.ORDER_INVENTORY_TABLE_NAME + '(order_id, product_id, product_name, product_price, quantity) values (?,?,?,?,?)';

    // ========= migrations =========

    var ADD_STATUS_COLUMN_TO_ORDERS = 'ALTER TABLE ' + DB_CONSTANTS.ORDERS_TABLE_NAME + ' ADD COLUMN status integer';

    // =====================================================

    DBService.init = function(){
      if (DBService._db){
        $log.error('db already initialized');
        return;
      }

      window.sqlitePlugin.openDatabase({name: DB_CONSTANTS.DB_NAME, location: DB_CONSTANTS.DB_LOCATION}, function(db){
        $log.debug('DBService: db opened successfully');
        DBService._db = db;
        DBService._onDBInitialized();
      }, function(error){
        $log.error('DBService: failed to open db. ERROR: ' + JSON.stringify(error));
      });
    };

    DBService.close = function(shouldDelete){
      if (DBService._db){
        DBService._db.close(function(){
          $log.debug('DBService: db closed successfully');
          DBService._db = null;

          if (shouldDelete){
            DBService.delete();
          }
        }, function(error){
          $log.debug('DBService: db close error : ' + JSON.stringify(error));
        });
      }
    };

    DBService.delete = function(){
      // if db is still open close it first
      if (DBService._db){
        DBService.close(true);
      } else {
        // remove the db
        if(window.sqlitePlugin){
          window.sqlitePlugin.deleteDatabase({name: DB_CONSTANTS.DB_NAME, location: DB_CONSTANTS.DB_LOCATION}, function(){
            $log.debug('DBService: db deleted successfully');
          }, function(error){
            $log.debug('DBService: db delete error : ' + JSON.stringify(error));
          });
        }
      }
    };


    // =========================================

    DBService.addOrder = function(order, inventory){
      if (DBService._db && order) {
        $log.debug('DBService: adding ' + JSON.stringify(order));
        var driver_id = order.driver ? order.driver.id : 0;
        var team_id = order.team_ids && order.team_ids.length > 0 ? order.team_ids[0] : 0;
        var way_point = (order.way_points && order.way_points.length > 0) ? order.way_points[0] : {};
        var lat = way_point.lat;
        var lng = way_point.lng;
        var address = way_point.address;
        var delivered_at = way_point.scheduled_at;
        var status = order.status;

          DBService._db.executeSql(ADD_ORDER_SQL, [order.id, order.total_price, order.asap, team_id, driver_id, lat, lng, address, delivered_at, status], function () {
            $log.debug('DBService.addOrder success. id: ' + order.id);

            if (order.driver) {
              var driver = order.driver;
              if (driver.phone){
                driver.phone = CipherUtil.r(driver.phone, CipherUtil.t(driver.id.toString(16)));
              }
              DBService._db.executeSql(ADD_DRIVER_SQL, [driver.id, driver.name, driver.phone, driver.average_rating], function(){
                $log.debug('DBService: added driver for order ' + order.id);
              }, function(error){
                $log.debug('DBService: failed to add driver to order ' + order.id + '. error ' + error.message);
              });
            }

            if (inventory){
              $log.debug('DBService: adding inventory ' + JSON.stringify(inventory));
              DBService._db.transaction(function(tx){
                _.each(inventory, function(item){
                  if (item.product) {
                    var product = item.product;
                    var price = product.discountedPrice ? product.discountedPrice : product.price;
                    tx.executeSql(ADD_INVENTORY_SQL, [order.id, product.id, product.name, price, item.count]);
                  }
                });
              }, function (error){
                //error adding inventory for order
                $log.debug(error.message);
              });
            }

          }, function(error){
            // error adding order
            $log.debug('DBService.addOrder failed. id: ' + order.id + '; error; ' + error.message);
          });
      }
    };

    DBService.getOrders = function(){
      var deferred = $q.defer();

      if (DBService._db) {
        DBService._getOrders().then(function (orders) {
          // create an array of promises for each order to add its complementary data
          if (orders.length > 0) {
            var promises = [];
            _.each(orders, function (order) {
                promises.push(DBService._addDataToOrder(order));
            });

            // once all the orders get filled with the additional data, return them
            $q.all(promises).then(function (filledOrders) {
              deferred.resolve(filledOrders);
            });
          } else {
            deferred.resolve([]);
          }
        }, function(error){
          // order failed to load
          deferred.reject(error);
        });
      } else {
        // db is not available
        deferred.reject('db not available');
      }
      return deferred.promise;
    };

    DBService.getOrderById = function(id){
      var deferred = $q.defer();

      if (DBService._db && id) {
        DBService._getOrderById(id).then(function (order) {
          // first add inventory and if succeeded add the driver via the successCallback.
          DBService._addDataToOrder(order).then(function(order){
            deferred.resolve(order);
          });
        }, function(){
          // order failed to load
          deferred.reject();
        });
      } else {
        // either db is not available or no id was provided
        deferred.reject();
      }
      return deferred.promise;
    };

    DBService._getOrders = function(){
      var deferred = $q.defer();

      DBService._db.executeSql(GET_ORDERS, [], function (res) {
        $log.debug('DBService.getOrders success. rows: ' + res.rows.length);
        var orders = [];
        if (res.rows.length > 0) {
          for (var i = 0; i < res.rows.length; i++){
            orders.push(res.rows.item(i));
          }
        }
        deferred.resolve(orders);
      }, function(error){
        $log.debug('DBService.getOrders failed. error: ' + error.message);
        deferred.reject(error);
      });

      return deferred.promise;
    };

    DBService._getOrderById = function(id){
      var deferred = $q.defer();

      DBService._db.executeSql(GET_ORDER_BY_ID, [id], function (res) {
        $log.debug('DBService.getOrder success. id: ' + id);
        if (res.rows.length > 0) {
          var order = res.rows.item(0);
          deferred.resolve(order);
        }
      }, function(error){
        $log.debug('DBService.getOrder failed. id: ' + id + '; error: ' + error.message);
        deferred.reject();
      });

      return deferred.promise;
    };

    DBService._addDataToOrder = function(order){
      var deferred = $q.defer();

      // first add inventory and if succeeded add the driver via the successCallback.
      DBService._getInventoryForOrder(order.id).then(function (inventory) {
        $log.debug('DBService: inventory loaded ' + JSON.stringify(inventory));
        order.inventory = inventory;
        if (order.driver_id) {
          DBService._getDriverById(order.driver_id).then(function (driver) {
            // driver loaded successfully

            order.driver = driver;
            if (order.driver.phone){
              order.driver.phone = CipherUtil.s(order.driver.phone, CipherUtil.t(order.driver_id.toString(16)));
            }

            deferred.resolve(order);
          }, function(){
            // driver failed to load
            $log.debug('DBService: failed to load driver');
            deferred.resolve(order);
          });
        } else {
          // no driver id
          $log.debug('DBService: failed to load driver - no id');
          deferred.resolve(order);
        }
      }, function(){
        // inventory failed to load
        $log.debug('DBService: failed to load inventory');
        deferred.resolve(order);
      });

      return deferred.promise;
    };

    DBService._getInventoryForOrder = function(order_id){
      var deferred = $q.defer();

      DBService._db.executeSql(GET_INVENTORY_FOR_ORDER_ID, [order_id], function (res) {
        var inventory = [];
        if (res.rows.length > 0) {
          $log.debug('DBService.getInventory for order id: ' + order_id + ' success');
          for (var i = 0; i < res.rows.length; i++){
            var item = {};
            var row = res.rows.item(i);
            item.count = row.quantity;
            item.product = {
              id : row.product_id,
              name : row.product_name,
              price: row.product_price
            };
            inventory.push(item);
          }
        } else {
          $log.debug('DBService.getInventory for order id: ' + order_id + ' no results');
        }
        deferred.resolve(inventory);
      }, function(error){
        $log.debug('DBService.getInventory failed. error: ' + error.message);
        deferred.reject();
      });

      return deferred.promise;
    };

    DBService._getDriverById = function(id){
      var deferred = $q.defer();

      DBService._db.executeSql(GET_DRIVER_BY_ID, [id], function (res){
        // successfully obtained driver for the order
        if (res.rows.length > 0) {
          $log.debug('DBService.getDriver id: ' + id + ' - success.');
          var driver = res.rows.item(0);
          deferred.resolve(driver);
        } else {
          $log.debug('DBService.getDriver id: ' + id + ' - no results.');
          deferred.resolve();
        }
      }, function(error){
        // couldn't obtain driver for the order
        $log.debug('DBService.getDriver failed. error: ' + error.message);
        deferred.reject();
      });

      return deferred.promise;
    };

    // =======================================
    // schema updating stuff
    // =======================================

    DBService._onDBInitialized = function(){
      DBService._getSchemaVersion(DBService._updateSchemaIfNecessary);
    };

    DBService._getSchemaVersion = function(callback){
      if (DBService._db) {
        DBService._db.executeSql(GET_SCHEMA_VERSION_SQL, [], function (res) {
          if (res.rows.length) {
            var result = res.rows.item(0);
            if (result && result.version) {
              callback(result.version);
            } else {
              callback(0);
            }
          } else {
            callback(0);
          }
        }, function (error) {
          $log.debug('DBService: failed to obtain version number. error: ' + error.message);
          callback(0);
        });
      }
    };

    DBService._updateSchemaIfNecessary = function(currentVersion){
      $log.debug('DBService: latest version ' + DB_CONSTANTS.DB_VERSION + ', current is ' + currentVersion );
      if (DB_CONSTANTS.DB_VERSION > currentVersion){
        DBService._db.transaction(function(tx) {
          tx.executeSql('DROP TABLE IF EXISTS ' + DB_CONSTANTS.SCHEMA_VERSION_TABLE_NAME);
          tx.executeSql(CREATE_SCHEMA_TABLE_SQL);
          tx.executeSql(ADD_VERSION_NUMBER_SQL, [DB_CONSTANTS.DB_VERSION]);

          if (currentVersion === 0){
            DBService._onCreate(tx);
          } else {
            DBService._onUpgrade(tx, currentVersion);
          }
        }, function(error) {
          $log.debug('DBService: could not update schema. error: ' + error.message);
          DBService.close();
        }, function() {
          $log('DBService: updated schema');
        });
      }
    };

    // extend this function if we change the schema
    DBService._onUpgrade = function(tx, currentVersion){
      $log.debug('DBService.onUpgrade called from version ' + currentVersion + ' to version ' + DB_CONSTANTS.DB_VERSION);

      if (currentVersion < 3){
        tx.executeSql(ADD_STATUS_COLUMN_TO_ORDERS, [], function(){
          $log.debug('DBService. db upgrade success');
        }, function(error){
          $log.debug('DBService: could not update schema. error: ' + error.message);
          DBService.close();
        });
      }
    };

    DBService._onCreate = function(tx){
      $log.debug('DBService.onCreate called');
      tx.executeSql(CREATE_ORDERS_TABLE_SQL);
      tx.executeSql(CREATE_ORDER_INVENTORY_TABLE_SQL);
      tx.executeSql(CREATE_DRIVERS_TABLE_SQL);
    };

    return DBService;
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .controller('CreditCardController', function ($scope, AuthenticationService, $state, $ionicPopup, $translate, MERCHANT_CONFIG, $ionicLoading) {
    ga_storage._trackPageview('CreditCard');
    $scope.user = AuthenticationService.getTemporarlyStoredUser();
    $scope.processing = false;
    $scope.cc = {name:$scope.user.name};

    $scope.handleDoneButtonClick = function () {
      ga_storage._trackEvent('CreditCardController', 'handleDoneButtonClick', 'click', 1);
      if(!$scope.cc.number || !$scope.cc.cvv || !$scope.cc.name || !$scope.cc.exp_month || !$scope.cc.exp_year){
        $ionicPopup.alert({title: $translate.instant('error'), template: $translate.instant('all_credit_card_fields_are_required')});
        return;
      }

      $ionicLoading.show({
        template: '<ion-spinner></ion-spinner><p>{{::"please_wait" | translate}}</p>'
      });

      $scope.processing = true;

      Stripe.setPublishableKey(MERCHANT_CONFIG.STRIPE_PUB_KEY);
      Stripe.card.createToken({
        number: $scope.cc.number,
        cvc: $scope.cc.cvv,
        exp_month: $scope.cc.exp_month,
        exp_year: $scope.cc.exp_year,
        name: $scope.cc.name
      }, $scope._handleStripeResponse);
    };

    $scope._handleStripeResponse = function (status, result) {
      ga_storage._trackEvent('CreditCardController', '_handleStripeResponse', 'received', 1);
      if (result.error) {
        $scope.processing = false;
        $ionicLoading.hide();
        $ionicPopup.alert({title: $translate.instant('error'), template: result.error.message});
      } else {
        $scope.stripe_credit_card_result = result;
        if($scope.stripe_customer_result){
          $scope._signUp($scope.stripe_customer_result);
        }else{
          AuthenticationService.createStripeCustomer({
            email: $scope.user.email,
            source: result.id,
            description: 'Customer name: ' + $scope.user.name
          }).then(function(createStripeResult){
            $scope.stripe_customer_result = createStripeResult.customer;
            $scope._signUp($scope.stripe_customer_result);
          }, function(reason){
            $scope.processing = false;
            $ionicLoading.hide();
            $ionicPopup.alert({title: $translate.instant('error'), template: reason.message});
          });
        }
      }
    };

    $scope._signUp = function(customer){
      ga_storage._trackEvent('CreditCardController', '_signUp', 'received', 1);
      AuthenticationService.signUp({
        phone: $scope.user.phone,
        email: $scope.user.email,
        password: $scope.user.password,
        name: $scope.user.name,
        stripe_id: customer.id
      }, function (result) {
        $scope.processing = false;
        $ionicLoading.hide();
        if (result.status === 'error') {
          $ionicPopup.alert({title: $translate.instant('error'), template: result.message});
        }
      });
    };

    $scope.handleBackButtonClick = function () {
      $state.go('register');
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('UiConfigurationController', function ($scope, $log, $state, localStorageService, ConfigurationService) {

    ga_storage._trackPageview('UiConfiguration');
    $scope.handleBackClick = function () {
      $log.debug('UiConfigurationController.handleBackClick called');
      $state.go('categories');
    };

    $scope.data = ConfigurationService.getUiConfiguration();

    $scope.$watch('data', function (newValue, oldValue) {
      if(newValue === oldValue){
        return;
      }
      ConfigurationService.setUiConfiguration(newValue);
      location.reload();
    }, true);
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('NoServiceController', function ($scope, $translate, $log,
                                               $state, CountryCodeExtractor, ConfigurationService, $ionicPopup, $rootScope) {

    ga_storage._trackPageview('NoService');
    $scope.$on('$ionicView.enter', function () {
      $log.debug('NoServiceController.$ionicView.enter called');
    });



    $scope.debug = {
      text: null,
      countryCode: null,
      enabled: $rootScope.isDebug
    };

    $scope.dtCount = 0;
    $scope.magicTapNumber = 5;
    $scope.doubleTap = function () {
      $log.debug('double tap');
      $scope.dtCount++;
      if ($scope.dtCount % $scope.magicTapNumber === 0) {
        ga_storage._trackEvent('LoginController', 'doubleTapDEBUG', 'click');
        $ionicPopup.confirm({
          title: 'Enter Code',
          template: '<label class="item item-input"><input type="text" autocapitalize="off" ng-model="debug.text"></label>',
          scope: $scope,
          cancelText: $translate.instant('cancel'),
          okText: $translate.instant('ok')
        }).then(function (res) {
          if (res) {
            if ($scope.debug.text === 'wantafanta') {
              $rootScope.isDebug = true;
              $scope.debug.enabled = true;
            } else if ($scope.debug.text === 'ccdemo') {
              $rootScope.isGlobalDemo = true;
              $rootScope.isLocalDemo = false;
              $state.go('loading');
            } else if ($scope.debug.text && $scope.debug.text.startsWith('bg')){
              $rootScope.isGlobalDemo = false;
              $rootScope.isLocalDemo = true;
              CountryCodeExtractor.setCountryCode($scope.debug.text);
              $state.go('loading');
            }
          }
        });
      }
    };

    $scope.handleSetCountryCode = function () {
      $ionicPopup.confirm({
        title: 'Set Country Code',
        template: '<label class="item item-input"><input type="text" autocapitalize="off" ng-model="debug.countryCode"></label>',
        scope: $scope,
        cancelText: $translate.instant('cancel'),
        okText: $translate.instant('ok')
      }).then(function (res) {
        if (res) {
          if ($scope.debug.countryCode === 'staging' && $rootScope.isProduction) {
            $rootScope.isProduction = false;
            $rootScope.isGlobalDemo = false;
            $rootScope.isLocalDemo = false;
            ConfigurationService.setEnv('staging');
          } else if ($scope.debug.countryCode === 'production' && !$rootScope.isProduction) {
            $rootScope.isProduction = true;
            $rootScope.isGlobalDemo = false;
            $rootScope.isLocalDemo = false;
            ConfigurationService.setEnv('production');
          } else if ($scope.debug.text === 'ccdemo') { // allow moving to demo from here also
            $rootScope.isGlobalDemo = true;
            $rootScope.isLocalDemo = false;
          } else if ($scope.debug.countryCode && $scope.debug.countryCode.length === 2) {
            $log.debug('setting cc to ' + $scope.debug.countryCode);
            CountryCodeExtractor.setCountryCode($scope.debug.countryCode);
          }
          $state.go('loading');
        }
      });
    };

  });


'use strict';

angular.module('cocaColaCordovaApp')
  .factory('ConfirmFoundLocationService', function($ionicModal, $log, $rootScope, $q){
    var ConfirmFoundLocationService = {};

    ConfirmFoundLocationService.modal = null;
    ConfirmFoundLocationService.deferred = null;

    ConfirmFoundLocationService.open = function(location, addresses, forceApproval){
      $log.debug('ConfirmFoundLocationService.open');
      ConfirmFoundLocationService.deferred = $q.defer();
      var scope = $rootScope.$new();
      scope.location = location;
      scope.address = addresses && addresses.length && addresses.length > 0 ? addresses[0] : null;
      scope.forceApproval = forceApproval;

      $ionicModal.fromTemplateUrl('scripts/core/confirm_found_location/confirm-found-location.html', {
        scope: scope,
        animation: 'slide-in-up',
        backdropClickToClose: false,
        hardwareBackButtonClose: true
      }).then(function (modal) {
        ConfirmFoundLocationService.modal = modal;
        ConfirmFoundLocationService.modal.show();
      });

      return ConfirmFoundLocationService.deferred.promise;
    };

    ConfirmFoundLocationService.cancel = function(){
      if(!ConfirmFoundLocationService.modal){
        return;
      }
      $log.debug('ConfirmFoundLocationService.cancel');
      ConfirmFoundLocationService.deferred.reject();
      ConfirmFoundLocationService.modal.remove();
      ConfirmFoundLocationService.modal = null;
      ConfirmFoundLocationService.deferred = null;
    };

    ConfirmFoundLocationService.confirm = function(location, address){
      $log.debug('ConfirmFoundLocationService.confirm');
      location.address = address;
      ConfirmFoundLocationService.deferred.resolve(location);
      ConfirmFoundLocationService.cancel();
    };

    return ConfirmFoundLocationService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('ConfirmFoundLocationController', function($scope, $log, $window, ConfirmFoundLocationService, LocationUtil){

    ga_storage._trackPageview('ConfirmFoundLocation');
    var width = 0;
    var height = 0;
    if($window.innerWidth < 680){
      width = Math.floor($window.innerWidth - 32);
      height = width;
    }else{
      width = Math.floor(($window.innerWidth - 32) * 0.6);
      height = Math.floor(($window.innerHeight - 32) * 0.6);
    }

    if ($scope.location && $scope.location.coords && $scope.location.coords.latitude && $scope.location.coords.longitude){
      $scope.path = 'https://maps.googleapis.com/maps/api/staticmap?zoom=15&size=' + width + 'x' + height + '&maptype=roadmap&markers=color:blue|' + $scope.location.coords.latitude + ',' + $scope.location.coords.longitude + '&center=' + $scope.location.coords.latitude + ',' + $scope.location.coords.longitude;
    }

    $scope.handleCancelButtonClick = function(){
      ga_storage._trackEvent('ConfirmFoundLocationController', 'handleCancelButtonClick', 'click');
      $log.debug('ConfirmFoundLocationController.handleCancelButtonClick');
      ConfirmFoundLocationService.cancel();
    };

    $scope.handleSubmitButtonClick = function(){
      ga_storage._trackEvent('ConfirmFoundLocationController', 'handleSubmitButtonClick', 'click');
      $log.debug('ConfirmFoundLocationController.handleSubmitButtonClick');
      ConfirmFoundLocationService.confirm($scope.location, $scope.address);
    };

    $scope.addressSelectedCallback = function (callback) {
      if (!callback || !callback.item){
        $log.error('ConfirmFoundLocationController. addressSelectedCallback - no callback');
        return;
      }

      $log.debug('ConfirmLocationController. address selected: ' + callback.item.formatted_address);
      $scope.address = callback.item.formatted_address;
      if (callback.item.geometry && callback.item.geometry.location){
        $log.debug('ConfirmFoundLocationController. user address geocoded successfully');
        $scope.location = {coords : {}};
        $scope.location.coords.latitude = callback.item.geometry.location.lat();
        $scope.location.coords.longitude = callback.item.geometry.location.lng();
      } else {
        $scope.location = null;
        $log.error('ConfirmFoundLocationController. user address not geocoded');
      }

      if ($scope.location && $scope.location.coords && $scope.location.coords.latitude && $scope.location.coords.longitude) {
        $scope.path = 'https://maps.googleapis.com/maps/api/staticmap?zoom=15&size=' + width + 'x' + height + '&maptype=roadmap&markers=color:blue|' + $scope.location.coords.latitude + ',' + $scope.location.coords.longitude + '&center=' + $scope.location.coords.latitude + ',' + $scope.location.coords.longitude;
      }
    };

    $scope.addressDataCallbackMethod = function (query) {
      return LocationUtil.geocodeAddress(query);
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('ProductController', function ($scope, CategoriesService, AuthenticationService, $ionicLoading, $stateParams,
                                             ProductAddToCartService, CartService, $log, $state) {
    ga_storage._trackPageview('Product');
    $scope._loadData = function () {
      var productId = $stateParams.product_id;
      CategoriesService.getProduct(productId, function (result) {
        $ionicLoading.hide();
        $scope.product = result;
      });
    };

    $scope._handleIsLoggedInChange = function () {
      if (AuthenticationService.isLoggedIn) {
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "loading" | translate}}</p>'
        });
        $scope._loadData();
      }
    };

    $scope._ionicViewEnter = function () {
      if (AuthenticationService.isLoggedIn) {
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "loading" | translate}}</p>'
        });
        $scope._loadData();
      }
    };

    $scope.$on('$ionicView.enter', $scope._ionicViewEnter);

    $scope.$watch(AuthenticationService.isLoggedIn, $scope._handleIsLoggedInChange);

    $scope.handleAddToCartClick = function(){
      ga_storage._trackEvent('ProductController', 'handleAddToCartClick', 'click');
      ProductAddToCartService.open($scope.product, false, true);
    };

    $scope.getCartStringForProduct = function(product){
      return CartService.getStringForCart(product);
    };

    $scope.handleBackClick = function () {
      ga_storage._trackEvent('ProductController', 'handleBackClick', 'click');
      $log.debug('CategoryController.handleBackClick');
      $state.go('categories');
    };
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('CipherUtil', function () {
    var CipherUtil= {};

    // encrypt method, name is obfuscated so it will be harder for attacker to debug it.
    CipherUtil.r = function(data, passPhrase){
      return CryptoJS.AES.encrypt(data, passPhrase).toString();
    };

    // decrypt method, name is obfuscated so it will be harder for attacker to debug it.
    CipherUtil.s = function(encryptedData, key){
      return CryptoJS.AES.decrypt(encryptedData, key).toString(CryptoJS.enc.Utf8);
    };

    // passphrase generation method, name is obfuscated so it will be harder for attacker to debug it.
    CipherUtil.t= function(data){
      return CryptoJS.SHA1(CipherUtil.d(data)).toString();
    };

    // util method for reverse string. name is obfuscated so it will be harder for attacker to debug it.
    CipherUtil.a = function(str){
      var temp = '';
      var i = str.length;

      while (i > 0) {
        temp += str.substring(i - 1, i);
        i--;
      }


      return temp;
    };

    // util method for shifting char codes in a string. name is obfuscated so it will be harder for attacker to debug it.
    CipherUtil.b = function(str, amount){
      var temp = '';
      var i = 0;

      while (i < str.length){
        temp += String.fromCharCode(str.charCodeAt(i) + amount);
        i++;
      }

      return temp;
    };

    // util method for obfuscating a string. name is obfuscated so it will be harder for attacker to debug it.
    CipherUtil.d = function(data){
      return CipherUtil.b(data, 2) + CipherUtil.a(data) + CipherUtil.b(data.substr(2), -1);
    };

    return CipherUtil;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('OngoingOrdersController', function ($scope, $translate, $log, $state, $ionicPopup, OrderService) {
    ga_storage._trackPageview('OngoingOrders');
    $scope.orders = [];

    $scope.handleOrderClick = function (order) {
      $log.debug('OngoingOrdersController.handleOrderClick called for ' + order.id);
      $state.go('order_completed', {order_id: order.id});
    };

    $scope.handleBackClick = function () {
      $log.debug('OngoingOrdersController.handleBackClick called');
      $state.go('categories');
    };

    $scope._handleIonicViewEnter = function () {
      // first check if we already loaded the history and use cache.
      $log.debug('OngoingOrdersController.viewEnter');
      $scope._loadOrders();
    };

    $scope._loadOrders = function() {
      $scope.orders = OrderService.getOngoingOrders();
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .controller('MaintenanceTicketController', function ($scope, $state, $ionicPopup, $ionicLoading, $translate, $log,
                                                       NetworkHelper, $q, CountryCodeExtractor, MaintenanceTicketService,
                                                       AuthenticationService, LocationUtil) {

    ga_storage._trackPageview('MaintenanceTicket');
    $scope.ticket = {};

    $scope.data = {};

    $scope.sending = false;


    $scope._handleIonicViewEnter = function(){
      $log.debug('MaintenanceTicketController.$ionicView.enter called');
      ga_storage._trackEvent('MaintenanceTicketController', 'handleDoneButtonClick', 'click');

      var ticket = MaintenanceTicketService.getTicket();
      if (ticket){
        $log.debug('MaintenanceTicketController. existing ticket with id: ' + ticket.id);
        $scope.trackTicket(ticket);
      } else {
        $scope.data.services = MaintenanceTicketService.getAvailableServices();
        if (AuthenticationService.currentUser()){
          $scope.ticket.phone = AuthenticationService.currentUser().phone;
          $scope.ticket.address = AuthenticationService.currentUser().address;
        }
        $log.debug('MaintenanceTicketController. available services: ' + JSON.stringify($scope.data.services));
      }
    };

    $scope.$on('$ionicView.enter', $scope._handleIonicViewEnter);

    $scope.handleDoneButtonClick = function () {
      ga_storage._trackEvent('MaintenanceTicketController', 'handleDoneButtonClick', 'click');
      $log.debug('MaintenanceTicketController.handleDoneButtonClick');

      if (!$scope.validateForm()) {
        return;
      } else if (!NetworkHelper.validateNetwork()){
        return;
      }

      $scope.sending = true;
      $ionicLoading.show({
        template: '<ion-spinner></ion-spinner><p>{{:: "please_wait" | translate}}</p>'
      });

      MaintenanceTicketService.submitTicket($scope.ticket).then($scope.onTicketSubmitted);
    };

    $scope.handleBackButtonClick = function(){
      $log.debug('MaintenanceTicketController.handleBackButtonClick');
      ga_storage._trackEvent('MaintenanceTicketController', 'handleBackButtonClick', 'click');
      $state.go('categories');
    };

    $scope.onTicketSubmitted = function(result){
      $ionicLoading.hide();
      if (result && result.status === 'ok'){
        $log.debug('MaintenanceTicketController. ticket submitted successfully');
        $scope.trackTicket(result.task);
      } else {
        $scope.handleErrorResponse(result);
      }
    };

    $scope.trackTicket = function(ticket){
      $state.go('order_completed', {order_id: ticket.id});
    };

    $scope.validateForm = function () {
      // form validation
      if (!$scope.ticket || _.isUndefined($scope.ticket)) {
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'), okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm missing params');
        return false;
      }

      var phone = $scope.ticket.phone;
      // make sure it is used and valid
      if (!$scope._applyPhoneValidation(phone, CountryCodeExtractor.getCountryCode())){
        return false;
      }

      // validate other required fields
      if (!$scope.ticket.address || _.isUndefined($scope.ticket.address)) {
        $ionicPopup.alert({template: $translate.instant('error_required_address'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm address is required');
        return false;
      }

      if (!$scope.ticket.service_request || _.isUndefined($scope.ticket.service_request)) {
        $ionicPopup.alert({template: $translate.instant('error_required_service_request'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm service request is required');
        return false;
      }
      $scope.ticket.service_request_id = $scope.ticket.service_request.id;

      if (!$scope.ticket.serial_number || _.isUndefined($scope.ticket.serial_number)) {
        $ionicPopup.alert({template: $translate.instant('error_required_serial_number'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm serial number is required');
        return false;
      }

      if (!$scope.ticket.asset_number || _.isUndefined($scope.ticket.asset_number)) {
        $ionicPopup.alert({template: $translate.instant('error_required_asset_number'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm asset number is required');
        return false;
      }

      return true;
    };

    $scope._applyPhoneValidation = function(phone, countryCode){
      if (!phone || _.isUndefined(phone)) {
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm phone is required');
        return false;
      } else if (!countryCode || _.isUndefined(countryCode)){
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm invalid country code');
        return false;
      } else if (!isValidNumber(phone, countryCode)){
        $ionicPopup.alert({template: $translate.instant('error_invalid_phone'),okText: $translate.instant('ok')});
        $log.error('MaintenanceTicketController.validateForm invalid phone');
        return false;
      } else {
        $scope.ticket.phone = formatE164(countryCode, phone);
        return true;
      }
    };

    $scope.handleErrorResponse = function (result) {
      if (result && result.message) {
        $ionicPopup.alert({title: $translate.instant('error_message_order_failed'), template: result.message, okText: $translate.instant('ok')});
      } else {
        $ionicPopup.alert({title: $translate.instant('error_message_order_failed'), okText: $translate.instant('ok')});
      }
    };

    $scope.selectedLocation = null;
    $scope.addressSelectedCallback = function (callback) {
      $scope.ticket.address = callback.item.formatted_address;
      if (callback.item.geometry && callback.item.geometry.location){
        $scope.ticket.lat = callback.item.geometry.location.lat();
        $scope.ticket.lng = callback.item.geometry.location.lng();
      } else {
        $scope.ticket.lat = null;
        $scope.ticket.lng = null;
        $log.error('user address not geocoded');
      }
    };

    $scope.addressDataCallbackMethod = function (query) {
      return LocationUtil.geocodeAddress(query);
    };
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .constant('STORAGE_KEYS', {
    'CURRENT_TICKET' : 'current_ticket'
  })
  .factory('MaintenanceTicketService', function ($log, OrderService, localStorageService, ConfigurationService,
                                                 STORAGE_KEYS) {
    var MaintenanceTicketService = {};

    MaintenanceTicketService._ticket = null;

    MaintenanceTicketService.submitTicket = function(ticket){
      return OrderService.createMaintenanceTicket(ticket)
        .then(MaintenanceTicketService.onTicketSubmittedSuccessfully, MaintenanceTicketService.onTicketSubmittedFailed);
    };

    MaintenanceTicketService.onTicketSubmittedSuccessfully = function(result){
      if (result && result.status === 'ok') {
        $log.debug('MaintenanceTicketService. ticket submitted with id: ' + result.task_id);
        MaintenanceTicketService._ticket = result.task;
        OrderService.addToOngoing(result.task);
        localStorageService.set(STORAGE_KEYS.CURRENT_TICKET, result.task);
      }

      return result;
    };

    MaintenanceTicketService.getTicket = function(){
      if (!MaintenanceTicketService._ticket){
        MaintenanceTicketService._ticket = localStorageService.get(STORAGE_KEYS.CURRENT_TICKET);
      }
      return MaintenanceTicketService._ticket;
    };

    MaintenanceTicketService.clearTicket = function(){
      $log.debug('MaintenanceTicketService. clear ticket');
      MaintenanceTicketService._ticket = null;
      localStorageService.remove(STORAGE_KEYS.CURRENT_TICKET);
    };

    MaintenanceTicketService.onTicketSubmittedFailed = function(error){
      $log.error('MaintenanceTicketService. ticket submitted failed. error: ' + error);
    };

    MaintenanceTicketService.getAvailableServices = function(){
      return ConfigurationService.getAvailableMaintenanceServices();
    };

    return MaintenanceTicketService;
  });

'use strict';

angular.module('cocaColaCordovaApp')
  .factory('DynamicLocationService', function () {
    var DynamicLocationService = {};

    DynamicLocationService._location = null;
    DynamicLocationService._address = null;

    DynamicLocationService.setCurrentLocation = function(location){
      DynamicLocationService._location = location;
    };

    DynamicLocationService.getCurrentLocation = function () {
      return DynamicLocationService._location;
    };

    DynamicLocationService.setCurrentAddress = function(address){
      DynamicLocationService._address = address;
    };

    DynamicLocationService.getCurrentAddress = function () {
      return DynamicLocationService._address;
    };

    return DynamicLocationService;
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .controller('LocationSelectMapController', function($scope, $log, uiGmapIsReady, $timeout, LocationUtil, $translate,
                                                      LocationSelectMapService, $ionicLoading, $ionicPopup){

    ga_storage._trackPageview('LocationSelectMapController');

    $scope.geocodeDelay = 1000;
    $scope.geocodeTimeout = null;

    $scope.googleMap = {};
    $scope.map = {};

    // =============================

    $scope.getAddress = function(position){
      $scope.geocodeTimeout = null;
      LocationUtil.reverseGeocode({lat: position.lat(), lng: position.lng()}).then($scope._onAddressFound);
    };

    $scope._onAddressFound = function(addresses){
      $ionicLoading.hide();
      if (addresses && addresses.length){
        $log.debug('LocationSelectMapController. address: ' + JSON.stringify(addresses[0]));
        $scope.address = addresses[0].formatted_address;
      } else {
        $log.error('LocationSelectMapController. no geocode results');
      }
    };

    $scope.onMapCenterChanged = function(){
      if ($scope.skipReverseGeocodeOnce){
        $scope.skipReverseGeocodeOnce = false;
        return;
      }

      var map = $scope.googleMap.getGMap();
      if (!map){
        $log.error('LocationSelectMapController.onMapCenterChanged: unable to retrieve map');
        $ionicPopup.alert({
          title: $translate.instant('error_loading_google_maps'),
          okText: $translate.instant('ok')
        }).then(function(){
          LocationSelectMapService.cancel();
        });
        return;
      }

      var position = map.getCenter();
      if (position){
        if ($scope.geocodeTimeout){
          $log.debug('LocationSelectMapController. canceling previous geocode request');
          $timeout.cancel($scope.geocodeTimeout);
        }

        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "locating" | translate}}</p>'
        });

        $scope.geocodeTimeout = $timeout(function () {
          $scope.getAddress(position);
        }, $scope.geocodeDelay);
      }
    };

    $scope.init = function(){
      $log.debug('LocationSelectMapController.init');

      var lat = 0, lng = 0;
      if ($scope.location && $scope.location.coords && $scope.location.coords.latitude && $scope.location.coords.longitude){
        lat = $scope.location.coords.latitude;
        lng = $scope.location.coords.longitude;
      }
      $scope.map = {
        center: {latitude: lat, longitude: lng},
        zoom: 16,
        options: {disableDefaultUI: true, draggable: true},
        events: {
          tilesloaded: function (map) {
            $scope.$apply(function () {
              $scope.mapInstance = map;
            });
          }
        }
      };


      if (!$scope.location || !$scope.mapReady){
        $log.debug('LocationSelectMapController.init not ready yet');
        $ionicLoading.show({
          template: '<ion-spinner></ion-spinner><p>{{:: "locating" | translate}}</p>'
        });
        return;
      }

      $scope.initialized = true;
      $ionicLoading.hide();

      var map = $scope.googleMap.getGMap();

      map.addListener('center_changed', $scope.onMapCenterChanged);

      $('<div/>').addClass('centerMarker').appendTo(map.getDiv());
    };

    $scope.init();

    uiGmapIsReady.promise()
      .then(function () {
        $log.debug('LocationSelectMapController.uiGmapIsReady');
        $scope.loading = false;
        $scope.mapReady = true;
        if (!$scope.initialized){
          $scope.init();
        }
      });


    // ===============================

    $scope.handleCancelButtonClick = function(){
      ga_storage._trackEvent('LocationSelectMapController', 'handleCancelButtonClick', 'click');
      $log.debug('LocationSelectMapController.handleCancelButtonClick');
      LocationSelectMapService.cancel();
    };

    $scope.handleSubmitButtonClick = function(){
      ga_storage._trackEvent('LocationSelectMapController', 'handleSubmitButtonClick', 'click');
      $log.debug('LocationSelectMapController.handleSubmitButtonClick');
      LocationSelectMapService.confirm($scope.location, $scope.address);
    };

    $scope.addressSelectedCallback = function (callback) {
      if (!callback || !callback.item){
        $log.error('LocationSelectMapController. addressSelectedCallback - no callback');
        return;
      }

      $log.debug('LocationSelectMapController. address selected: ' + callback.item.formatted_address);
      $scope.address = callback.item.formatted_address;
      if (callback.item.geometry && callback.item.geometry.location){
        $log.debug('LocationSelectMapController. user address geocoded successfully');
        $scope.location = {coords : {}};
        $scope.location.coords.latitude = callback.item.geometry.location.lat();
        $scope.location.coords.longitude = callback.item.geometry.location.lng();

        $scope.skipReverseGeocodeOnce = true;
        $scope.map.center = {latitude: $scope.location.coords.latitude, longitude: $scope.location.coords.longitude};
      } else {
        $scope.location = null;
        $log.error('LocationSelectMapController. user address not geocoded');
      }
    };

    $scope.addressDataCallbackMethod = function (query) {
      return LocationUtil.geocodeAddress(query);
    };
  });


'use strict';

angular.module('cocaColaCordovaApp')
  .factory('LocationSelectMapService', function($ionicModal, $log, $rootScope, $q){
    var LocationSelectMapService = {};

    LocationSelectMapService.modal = null;
    LocationSelectMapService.deferred = null;

    LocationSelectMapService.open = function(location, addresses, forceApproval){
      $log.debug('LocationSelectMapService.open');
      LocationSelectMapService.deferred = $q.defer();
      var scope = $rootScope.$new();
      scope.location = location;
      scope.address = addresses && addresses.length && addresses.length > 0 ? addresses[0] : null;
      scope.forceApproval = forceApproval;

      $ionicModal.fromTemplateUrl('scripts/core/location_select_map/location-select-map.html', {
        scope: scope,
        animation: 'slide-in-up',
        backdropClickToClose: false,
        hardwareBackButtonClose: true
      }).then(function (modal) {
        LocationSelectMapService.modal = modal;
        LocationSelectMapService.modal.show();
      });

      return LocationSelectMapService.deferred.promise;
    };

    LocationSelectMapService.cancel = function(){
      if(!LocationSelectMapService.modal){
        return;
      }
      $log.debug('LocationSelectMapService.cancel');
      LocationSelectMapService.deferred.reject();
      LocationSelectMapService.modal.remove();
      LocationSelectMapService.modal = null;
      LocationSelectMapService.deferred = null;
    };

    LocationSelectMapService.confirm = function(location, address){
      $log.debug('LocationSelectMapService.confirm');

      // in case location was not successfully obtained (if user entered bad address manually for example)
      if (!location){
        location = {};
      }

      //in case user did not move the map the address changed callback was not fired and so the formatted_address was not extracted
      if (address && address.formatted_address){
        location.address = address.formatted_address;
      } else {
        location.address = address;
      }

      LocationSelectMapService.deferred.resolve(location);
      LocationSelectMapService.cancel();
    };

    return LocationSelectMapService;
  });

